Class: Aws::ECS::Types::AttributeLimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::AttributeLimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
You can apply up to 10 custom attributes for each resource. You can view the attributes of a resource with [ListAttributes]. You can remove existing attributes on a resource with [DeleteAttributes].
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListAttributes.html [2]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteAttributes.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Message that describes the cause of the exception.
Instance Attribute Details
#message ⇒ String
Message that describes the cause of the exception.
242 243 244 245 246 |
# File 'lib/aws-sdk-ecs/types.rb', line 242 class AttributeLimitExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |