Class: Aws::ECS::Types::AutoRepairConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The auto repair configuration for an Amazon ECS Managed Instances capacity provider. When enabled, Amazon ECS automatically replaces container instances that are detected as unhealthy based on container instance health checks, including accelerated compute device and daemon health checks.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actions_statusString

The status of auto repair actions for the capacity provider. When set to ‘ENABLED`, Amazon ECS automatically replaces container instances with an `IMPAIRED` health status. When set to `DISABLED`, Amazon ECS still monitors container instance health but does not automatically replace impaired instances.

Returns:

  • (String)


264
265
266
267
268
# File 'lib/aws-sdk-ecs/types.rb', line 264

class AutoRepairConfiguration < Struct.new(
  :actions_status)
  SENSITIVE = []
  include Aws::Structure
end