Class: Aws::ECS::Types::CapacityProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The details of a capacity provider.

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_providerTypes::AutoScalingGroupProvider

The Auto Scaling group settings for the capacity provider.



279
280
281
282
283
284
285
286
# File 'lib/aws-sdk-ecs/types.rb', line 279

class CapacityProvider < Struct.new(
  :capacity_provider_arn,
  :name,
  :status,
  :auto_scaling_group_provider,
  :tags)
  include Aws::Structure
end

#capacity_provider_arnString

The Amazon Resource Name (ARN) that identifies the capacity provider.

Returns:

  • (String)


279
280
281
282
283
284
285
286
# File 'lib/aws-sdk-ecs/types.rb', line 279

class CapacityProvider < Struct.new(
  :capacity_provider_arn,
  :name,
  :status,
  :auto_scaling_group_provider,
  :tags)
  include Aws::Structure
end

#nameString

The name of the capacity provider.

Returns:

  • (String)


279
280
281
282
283
284
285
286
# File 'lib/aws-sdk-ecs/types.rb', line 279

class CapacityProvider < Struct.new(
  :capacity_provider_arn,
  :name,
  :status,
  :auto_scaling_group_provider,
  :tags)
  include Aws::Structure
end

#statusString

The current status of the capacity provider. Only capacity providers in an ACTIVE state can be used in a cluster.

Returns:

  • (String)


279
280
281
282
283
284
285
286
# File 'lib/aws-sdk-ecs/types.rb', line 279

class CapacityProvider < Struct.new(
  :capacity_provider_arn,
  :name,
  :status,
  :auto_scaling_group_provider,
  :tags)
  include Aws::Structure
end

#tagsArray<Types::Tag>

The metadata that you apply to the capacity provider to help you categorize and organize it. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50

  • For each resource, each tag key must be unique, and each tag key can have only one value.

  • Maximum key length - 128 Unicode characters in UTF-8

  • Maximum value length - 256 Unicode characters in UTF-8

  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.

  • Tag keys and values are case-sensitive.

  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.

Returns:



279
280
281
282
283
284
285
286
# File 'lib/aws-sdk-ecs/types.rb', line 279

class CapacityProvider < Struct.new(
  :capacity_provider_arn,
  :name,
  :status,
  :auto_scaling_group_provider,
  :tags)
  include Aws::Structure
end