Class: Aws::ECS::Types::ClientException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ClientException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
These errors are usually caused by a client action, such as using an action or resource on behalf of a user that doesn’t have permissions to use the action or resource, or specifying an identifier that is not valid.
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
343 344 345 346 |
# File 'lib/aws-sdk-ecs/types.rb', line 343 class ClientException < Struct.new( :message) include Aws::Structure end |