Class: Aws::ECS::Types::ClusterContainsCapacityProviderException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ClusterContainsCapacityProviderException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The cluster contains one or more capacity providers that prevent the requested operation. This exception occurs when you try to delete a cluster that still has active capacity providers, including Amazon ECS Managed Instances capacity providers. You must first delete all capacity providers from the cluster before you can delete the cluster itself.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Message that describes the cause of the exception.
Instance Attribute Details
#message ⇒ String
Message that describes the cause of the exception.
1024 1025 1026 1027 1028 |
# File 'lib/aws-sdk-ecs/types.rb', line 1024 class ClusterContainsCapacityProviderException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |