Class: Aws::ECS::Types::ClusterSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ClusterSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass ClusterSetting data as a hash:
{
name: "containerInsights", # accepts containerInsights
value: "String",
}
The settings to use when creating a cluster. This parameter is used to enable CloudWatch Container Insights for a cluster.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the cluster setting.
-
#value ⇒ String
The value to set for the cluster setting.
Instance Attribute Details
#name ⇒ String
The name of the cluster setting. The only supported value is containerInsights.
557 558 559 560 561 |
# File 'lib/aws-sdk-ecs/types.rb', line 557 class ClusterSetting < Struct.new( :name, :value) include Aws::Structure end |
#value ⇒ String
The value to set for the cluster setting. The supported values are enabled and disabled. If enabled is specified, CloudWatch Container Insights will be enabled for the cluster, otherwise it will be disabled unless the containerInsights account setting is enabled. If a cluster value is specified, it will override the containerInsights value set with PutAccountSetting or PutAccountSettingDefault.
557 558 559 560 561 |
# File 'lib/aws-sdk-ecs/types.rb', line 557 class ClusterSetting < Struct.new( :name, :value) include Aws::Structure end |