Method: Aws::ECS::Types::ContainerInstance#attributes
- Defined in:
- lib/aws-sdk-ecs/types.rb
#attributes ⇒ Array<Types::Attribute>
The attributes set for the container instance, either by the Amazon ECS container agent at instance registration or manually with the PutAttributes operation.
1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 |
# File 'lib/aws-sdk-ecs/types.rb', line 1916 class ContainerInstance < Struct.new( :container_instance_arn, :ec2_instance_id, :capacity_provider_name, :version, :version_info, :remaining_resources, :registered_resources, :status, :status_reason, :agent_connected, :running_tasks_count, :pending_tasks_count, :agent_update_status, :attributes, :registered_at, :attachments, :tags) include Aws::Structure end |