Class: Aws::ECS::Types::ContinueServiceDeploymentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action to take on the paused lifecycle hook. Valid values are:

  • ‘CONTINUE` - Proceeds the deployment to the next lifecycle stage.

  • ‘ROLLBACK` - Rolls back the deployment to the previous service revision.

If no value is specified, the default action is ‘CONTINUE`.

Returns:

  • (String)


2763
2764
2765
2766
2767
2768
2769
# File 'lib/aws-sdk-ecs/types.rb', line 2763

class ContinueServiceDeploymentRequest < Struct.new(
  :service_deployment_arn,
  :hook_id,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#hook_idString

The ID of the paused lifecycle hook to act on. You can find the ‘hookId` by calling [DescribeServiceDeployments] and inspecting the `lifecycleHookDetails` field of the service deployment.

[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServiceDeployments.html

Returns:

  • (String)


2763
2764
2765
2766
2767
2768
2769
# File 'lib/aws-sdk-ecs/types.rb', line 2763

class ContinueServiceDeploymentRequest < Struct.new(
  :service_deployment_arn,
  :hook_id,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#service_deployment_arnString

The ARN of the service deployment to continue or roll back.

Returns:

  • (String)


2763
2764
2765
2766
2767
2768
2769
# File 'lib/aws-sdk-ecs/types.rb', line 2763

class ContinueServiceDeploymentRequest < Struct.new(
  :service_deployment_arn,
  :hook_id,
  :action)
  SENSITIVE = []
  include Aws::Structure
end