Class: Aws::ECS::Types::ContinueServiceDeploymentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ContinueServiceDeploymentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_deployment_arn ⇒ String
The ARN of the service deployment that was continued or rolled back.
Instance Attribute Details
#service_deployment_arn ⇒ String
The ARN of the service deployment that was continued or rolled back.
2782 2783 2784 2785 2786 |
# File 'lib/aws-sdk-ecs/types.rb', line 2782 class ContinueServiceDeploymentResponse < Struct.new( :service_deployment_arn) SENSITIVE = [] include Aws::Structure end |