Class: Aws::ECS::Types::CreateDaemonRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateDaemonRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the capacity providers to associate with the daemon.
-
#client_token ⇒ String
An identifier that you provide to ensure the idempotency of the request.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster to create the daemon in.
-
#daemon_name ⇒ String
The name of the daemon.
-
#daemon_task_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon task definition to use for the daemon.
-
#deployment_configuration ⇒ Types::DaemonDeploymentConfiguration
Optional deployment parameters that control how the daemon rolls out updates, including the drain percentage, alarm-based rollback, and bake time.
-
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to turn on Amazon ECS managed tags for the tasks in the daemon.
-
#enable_execute_command ⇒ Boolean
Determines whether the execute command functionality is turned on for the daemon.
-
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the daemon to the daemon tasks.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the daemon to help you categorize and organize them.
Instance Attribute Details
#capacity_provider_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the capacity providers to associate with the daemon. The daemon deploys tasks on container instances managed by these capacity providers.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
An identifier that you provide to ensure the idempotency of the request. It must be unique and is case sensitive. Up to 36 ASCII characters in the range of 33-126 (inclusive) are allowed.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster to create the daemon in.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#daemon_name ⇒ String
The name of the daemon. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#daemon_task_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon task definition to use for the daemon.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#deployment_configuration ⇒ Types::DaemonDeploymentConfiguration
Optional deployment parameters that control how the daemon rolls out updates, including the drain percentage, alarm-based rollback, and bake time.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to turn on Amazon ECS managed tags for the tasks in the daemon. For more information, see [Tagging your Amazon ECS resources] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#enable_execute_command ⇒ Boolean
Determines whether the execute command functionality is turned on for the daemon. If ‘true`, the execute command functionality is turned on for all tasks in the daemon.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the daemon to the daemon tasks. If you don’t specify a value, the tags aren’t propagated. You can only propagate tags to daemon tasks during task creation. To add tags to a task after task creation, use the
- TagResource][1
-
API action.
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_TagResource.html
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the daemon to help you categorize and organize them. Each tag consists of a key and an optional value. You define both of them.
The following basic restrictions apply to tags:
-
Maximum number of tags per resource - 50
-
For each resource, each tag key must be unique, and each tag key can have only one value.
-
Maximum key length - 128 Unicode characters in UTF-8
-
Maximum value length - 256 Unicode characters in UTF-8
-
If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
-
Tag keys and values are case-sensitive.
-
Do not use ‘aws:`, `AWS:`, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 |
# File 'lib/aws-sdk-ecs/types.rb', line 3069 class CreateDaemonRequest < Struct.new( :daemon_name, :cluster_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :tags, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command, :client_token) SENSITIVE = [] include Aws::Structure end |