Class: Aws::ECS::Types::CreateExpressGatewayServiceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateExpressGatewayServiceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service ⇒ Types::ECSExpressGatewayService
The full description of your Express service following the create operation.
Instance Attribute Details
#service ⇒ Types::ECSExpressGatewayService
The full description of your Express service following the create operation.
2996 2997 2998 2999 3000 |
# File 'lib/aws-sdk-ecs/types.rb', line 2996 class CreateExpressGatewayServiceResponse < Struct.new( :service) SENSITIVE = [] include Aws::Structure end |