Class: Aws::ECS::Types::CreateServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass CreateServiceRequest data as a hash:
{
cluster: "String",
service_name: "String", # required
task_definition: "String",
load_balancers: [
{
target_group_arn: "String",
load_balancer_name: "String",
container_name: "String",
container_port: 1,
},
],
service_registries: [
{
registry_arn: "String",
port: 1,
container_name: "String",
container_port: 1,
},
],
desired_count: 1,
client_token: "String",
launch_type: "EC2", # accepts EC2, FARGATE
capacity_provider_strategy: [
{
capacity_provider: "String", # required
weight: 1,
base: 1,
},
],
platform_version: "String",
role: "String",
deployment_configuration: {
maximum_percent: 1,
minimum_healthy_percent: 1,
},
placement_constraints: [
{
type: "distinctInstance", # accepts distinctInstance, memberOf
expression: "String",
},
],
placement_strategy: [
{
type: "random", # accepts random, spread, binpack
field: "String",
},
],
network_configuration: {
awsvpc_configuration: {
subnets: ["String"], # required
security_groups: ["String"],
assign_public_ip: "ENABLED", # accepts ENABLED, DISABLED
},
},
health_check_grace_period_seconds: 1,
scheduling_strategy: "REPLICA", # accepts REPLICA, DAEMON
deployment_controller: {
type: "ECS", # required, accepts ECS, CODE_DEPLOY, EXTERNAL
},
tags: [
{
key: "TagKey",
value: "TagValue",
},
],
enable_ecs_managed_tags: false,
propagate_tags: "TASK_DEFINITION", # accepts TASK_DEFINITION, SERVICE
}
Instance Attribute Summary collapse
-
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy to use for the service.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster on which to run your service.
-
#deployment_configuration ⇒ Types::DeploymentConfiguration
Optional deployment parameters that control how many tasks run during the deployment and the ordering of stopping and starting tasks.
-
#deployment_controller ⇒ Types::DeploymentController
The deployment controller to use for the service.
-
#desired_count ⇒ Integer
The number of instantiations of the specified task definition to place and keep running on your cluster.
-
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to enable Amazon ECS managed tags for the tasks within the service.
-
#health_check_grace_period_seconds ⇒ Integer
The period of time, in seconds, that the Amazon ECS service scheduler should ignore unhealthy Elastic Load Balancing target health checks after a task has first started.
-
#launch_type ⇒ String
The launch type on which to run your service.
-
#load_balancers ⇒ Array<Types::LoadBalancer>
A load balancer object representing the load balancers to use with your service.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for the service.
-
#placement_constraints ⇒ Array<Types::PlacementConstraint>
An array of placement constraint objects to use for tasks in your service.
-
#placement_strategy ⇒ Array<Types::PlacementStrategy>
The placement strategy objects to use for tasks in your service.
-
#platform_version ⇒ String
The platform version that your tasks in the service are running on.
-
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the task definition or the service to the tasks in the service.
-
#role ⇒ String
The name or full Amazon Resource Name (ARN) of the IAM role that allows Amazon ECS to make calls to your load balancer on your behalf.
-
#scheduling_strategy ⇒ String
The scheduling strategy to use for the service.
-
#service_name ⇒ String
The name of your service.
-
#service_registries ⇒ Array<Types::ServiceRegistry>
The details of the service discovery registries to assign to this service.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the service to help you categorize and organize them.
-
#task_definition ⇒ String
The
familyandrevision(family:revision) or full ARN of the task definition to run in your service.
Instance Attribute Details
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy to use for the service.
A capacity provider strategy consists of one or more capacity providers along with the base and weight to assign to them. A capacity provider must be associated with the cluster to be used in a capacity provider strategy. The PutClusterCapacityProviders API is used to associate a capacity provider with a cluster. Only capacity providers with an ACTIVE or UPDATING status can be used.
If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used.
If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProvider API operation.
To use a AWS Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The AWS Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used.
The PutClusterCapacityProviders API operation is used to update the list of available capacity providers for a cluster after the cluster is created.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 32 ASCII characters are allowed.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster on which to run your service. If you do not specify a cluster, the default cluster is assumed.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#deployment_configuration ⇒ Types::DeploymentConfiguration
Optional deployment parameters that control how many tasks run during the deployment and the ordering of stopping and starting tasks.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#deployment_controller ⇒ Types::DeploymentController
The deployment controller to use for the service.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#desired_count ⇒ Integer
The number of instantiations of the specified task definition to place and keep running on your cluster.
This is required if schedulingStrategy is REPLICA or is not specified. If schedulingStrategy is DAEMON then this is not required.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to enable Amazon ECS managed tags for the tasks within the service. For more information, see [Tagging Your Amazon ECS Resources] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#health_check_grace_period_seconds ⇒ Integer
The period of time, in seconds, that the Amazon ECS service scheduler should ignore unhealthy Elastic Load Balancing target health checks after a task has first started. This is only valid if your service is configured to use a load balancer. If your service’s tasks take a while to start and respond to Elastic Load Balancing health checks, you can specify a health check grace period of up to 2,147,483,647 seconds. During that time, the ECS service scheduler ignores health check status. This grace period can prevent the ECS service scheduler from marking tasks as unhealthy and stopping them before they have time to come up.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#launch_type ⇒ String
The launch type on which to run your service. For more information, see [Amazon ECS Launch Types] in the *Amazon Elastic Container Service Developer Guide*.
If a launchType is specified, the capacityProviderStrategy parameter must be omitted.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#load_balancers ⇒ Array<Types::LoadBalancer>
A load balancer object representing the load balancers to use with your service. For more information, see [Service Load Balancing] in the *Amazon Elastic Container Service Developer Guide*.
If the service is using the rolling update (ECS) deployment controller and using either an Application Load Balancer or Network Load Balancer, you can specify multiple target groups to attach to the service. The service-linked role is required for services that make use of multiple target groups. For more information, see [Using Service-Linked Roles for Amazon ECS] in the *Amazon Elastic Container Service Developer Guide*.
If the service is using the CODE_DEPLOY deployment controller, the service is required to use either an Application Load Balancer or Network Load Balancer. When creating an AWS CodeDeploy deployment group, you specify two target groups (referred to as a targetGroupPair). During a deployment, AWS CodeDeploy determines which task set in your service has the status PRIMARY and associates one target group with it, and then associates the other target group with the replacement task set. The load balancer can also have up to two listeners: a required listener for production traffic and an optional listener that allows you perform validation tests with Lambda functions before routing production traffic to it.
After you create a service using the ECS deployment controller, the load balancer name or target group ARN, container name, and container port specified in the service definition are immutable. If you are using the CODE_DEPLOY deployment controller, these values can be changed when updating the service.
For Application Load Balancers and Network Load Balancers, this object must contain the load balancer target group ARN, the container name (as it appears in a container definition), and the container port to access from the load balancer. When a task from this service is placed on a container instance, the container instance and port combination is registered as a target in the target group specified here.
For Classic Load Balancers, this object must contain the load balancer name, the container name (as it appears in a container definition), and the container port to access from the load balancer. When a task from this service is placed on a container instance, the container instance is registered with the load balancer specified here.
Services with tasks that use the awsvpc network mode (for example, those with the Fargate launch type) only support Application Load Balancers and Network Load Balancers. Classic Load Balancers are not supported. Also, when you create any target groups for these services, you must choose ip as the target type, not instance, because tasks that use the awsvpc network mode are associated with an elastic network interface, not an Amazon EC2 instance.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-load-balancing.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using-service-linked-roles.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for the service. This parameter is required for task definitions that use the awsvpc network mode to receive their own elastic network interface, and it is not supported for other network modes. For more information, see [Task Networking] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#placement_constraints ⇒ Array<Types::PlacementConstraint>
An array of placement constraint objects to use for tasks in your service. You can specify a maximum of 10 constraints per task (this limit includes constraints in the task definition and those specified at runtime).
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#placement_strategy ⇒ Array<Types::PlacementStrategy>
The placement strategy objects to use for tasks in your service. You can specify a maximum of five strategy rules per service.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#platform_version ⇒ String
The platform version that your tasks in the service are running on. A platform version is specified only for tasks using the Fargate launch type. If one isn’t specified, the LATEST platform version is used by default. For more information, see [AWS Fargate Platform Versions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the task definition or the service to the tasks in the service. If no value is specified, the tags are not propagated. Tags can only be propagated to the tasks within the service during service creation. To add tags to a task after service creation, use the TagResource API action.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#role ⇒ String
The name or full Amazon Resource Name (ARN) of the IAM role that allows Amazon ECS to make calls to your load balancer on your behalf. This parameter is only permitted if you are using a load balancer with your service and your task definition does not use the awsvpc network mode. If you specify the role parameter, you must also specify a load balancer object with the loadBalancers parameter.
If your account has already created the Amazon ECS service-linked role, that role is used by default for your service unless you specify a role here. The service-linked role is required if your task definition uses the awsvpc network mode or if the service is configured to use service discovery, an external deployment controller, multiple target groups, or Elastic Inference accelerators in which case you should not specify a role here. For more information, see [Using Service-Linked Roles for Amazon ECS] in the *Amazon Elastic Container Service Developer Guide*.
If your specified role has a path other than /, then you must either specify the full role ARN (this is recommended) or prefix the role name with the path. For example, if a role with the name bar has a path of /foo/ then you would specify /foo/bar as the role name. For more information, see [Friendly Names and Paths] in the *IAM User Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using-service-linked-roles.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-friendly-names
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#scheduling_strategy ⇒ String
The scheduling strategy to use for the service. For more information, see [Services].
There are two service scheduler strategies available:
-
REPLICA-The replica scheduling strategy places and maintains the desired number of tasks across your cluster. By default, the service scheduler spreads tasks across Availability Zones. You can use task placement strategies and constraints to customize task placement decisions. This scheduler strategy is required if the service is using theCODE_DEPLOYorEXTERNALdeployment controller types. -
DAEMON-The daemon scheduling strategy deploys exactly one task on each active container instance that meets all of the task placement constraints that you specify in your cluster. When you’re using this strategy, you don’t need to specify a desired number of tasks, a task placement strategy, or use Service Auto Scaling policies.<note markdown=“1”> Tasks using the Fargate launch type or the
CODE_DEPLOYorEXTERNALdeployment controller types don’t support theDAEMONscheduling strategy.</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#service_name ⇒ String
The name of your service. Up to 255 letters (uppercase and lowercase), numbers, and hyphens are allowed. Service names must be unique within a cluster, but you can have similarly named services in multiple clusters within a Region or across multiple Regions.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#service_registries ⇒ Array<Types::ServiceRegistry>
The details of the service discovery registries to assign to this service. For more information, see [Service Discovery].
<note markdown=“1”> Service discovery is supported for Fargate tasks if you are using platform version v1.1.0 or later. For more information, see [AWS Fargate Platform Versions].
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the service to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. When a service is deleted, the tags are deleted as well.
The following basic restrictions apply to tags:
-
Maximum number of tags per resource - 50
-
For each resource, each tag key must be unique, and each tag key can have only one value.
-
Maximum key length - 128 Unicode characters in UTF-8
-
Maximum value length - 256 Unicode characters in UTF-8
-
If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
-
Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |
#task_definition ⇒ String
The family and revision (family:revision) or full ARN of the task definition to run in your service. If a revision is not specified, the latest ACTIVE revision is used.
A task definition must be specified if the service is using the ECS deployment controller.
2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-ecs/types.rb', line 2718 class CreateServiceRequest < Struct.new( :cluster, :service_name, :task_definition, :load_balancers, :service_registries, :desired_count, :client_token, :launch_type, :capacity_provider_strategy, :platform_version, :role, :deployment_configuration, :placement_constraints, :placement_strategy, :network_configuration, :health_check_grace_period_seconds, :scheduling_strategy, :deployment_controller, :tags, :enable_ecs_managed_tags, :propagate_tags) include Aws::Structure end |