Class: Aws::ECS::Types::CreateTaskSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass CreateTaskSetRequest data as a hash:

{
  service: "String", # required
  cluster: "String", # required
  external_id: "String",
  task_definition: "String", # required
  network_configuration: {
    awsvpc_configuration: {
      subnets: ["String"], # required
      security_groups: ["String"],
      assign_public_ip: "ENABLED", # accepts ENABLED, DISABLED
    },
  },
  load_balancers: [
    {
      target_group_arn: "String",
      load_balancer_name: "String",
      container_name: "String",
      container_port: 1,
    },
  ],
  service_registries: [
    {
      registry_arn: "String",
      port: 1,
      container_name: "String",
      container_port: 1,
    },
  ],
  launch_type: "EC2", # accepts EC2, FARGATE
  capacity_provider_strategy: [
    {
      capacity_provider: "String", # required
      weight: 1,
      base: 1,
    },
  ],
  platform_version: "String",
  scale: {
    value: 1.0,
    unit: "PERCENT", # accepts PERCENT
  },
  client_token: "String",
}

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_provider_strategyArray<Types::CapacityProviderStrategyItem>

The capacity provider strategy to use for the task set.

A capacity provider strategy consists of one or more capacity providers along with the base and weight to assign to them. A capacity provider must be associated with the cluster to be used in a capacity provider strategy. The PutClusterCapacityProviders API is used to associate a capacity provider with a cluster. Only capacity providers with an ACTIVE or UPDATING status can be used.

If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used.

If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProvider API operation.

To use a AWS Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The AWS Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used.

The PutClusterCapacityProviders API operation is used to update the list of available capacity providers for a cluster after the cluster is created.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 32 ASCII characters are allowed.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#external_idString

An optional non-unique tag that identifies this task set in external systems. If the task set is associated with a service discovery registry, the tasks in this task set will have the ECS_TASK_SET_EXTERNAL_ID AWS Cloud Map attribute set to the provided value.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#launch_typeString

The launch type that new tasks in the task set will use. For more information, see [Amazon ECS Launch Types] in the *Amazon Elastic Container Service Developer Guide*.

If a launchType is specified, the capacityProviderStrategy parameter must be omitted.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#load_balancersArray<Types::LoadBalancer>

A load balancer object representing the load balancer to use with the task set. The supported load balancer types are either an Application Load Balancer or a Network Load Balancer.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

An object representing the network configuration for a task or service.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#platform_versionString

The platform version that the tasks in the task set should use. A platform version is specified only for tasks using the Fargate launch type. If one isn’t specified, the LATEST platform version is used by default.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#scaleTypes::Scale

A floating-point percentage of the desired number of tasks to place and keep running in the task set.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#serviceString

The short name or full Amazon Resource Name (ARN) of the service to create the task set in.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#service_registriesArray<Types::ServiceRegistry>

The details of the service discovery registries to assign to this task set. For more information, see [Service Discovery].

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end

#task_definitionString

The task definition for the tasks in the task set to use.

Returns:



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
# File 'lib/aws-sdk-ecs/types.rb', line 2914

class CreateTaskSetRequest < Struct.new(
  :service,
  :cluster,
  :external_id,
  :task_definition,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :scale,
  :client_token)
  include Aws::Structure
end