Method: Aws::ECS::Types::CreateTaskSetResponse#task_set

Defined in:
lib/aws-sdk-ecs/types.rb

#task_setTypes::TaskSet

Information about a set of Amazon ECS tasks in either an CodeDeploy or an EXTERNAL deployment. A task set includes details such as the desired number of tasks, how many tasks are running, and whether the task set serves production traffic.

Returns:



3965
3966
3967
3968
3969
# File 'lib/aws-sdk-ecs/types.rb', line 3965

class CreateTaskSetResponse < Struct.new(
  :task_set)
  SENSITIVE = []
  include Aws::Structure
end