Class: Aws::ECS::Types::CreatedAt
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreatedAt
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The optional filter to narrow the ListServiceDeployment results.
If you do not specify a value, service deployments that were created before the current time are included in the result.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after ⇒ Time
Include service deployments in the result that were created after this time.
-
#before ⇒ Time
Include service deployments in the result that were created before this time.
Instance Attribute Details
#after ⇒ Time
Include service deployments in the result that were created after this time. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ecs/types.rb', line 3780 class CreatedAt < Struct.new( :before, :after) SENSITIVE = [] include Aws::Structure end |
#before ⇒ Time
Include service deployments in the result that were created before this time. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
3780 3781 3782 3783 3784 3785 |
# File 'lib/aws-sdk-ecs/types.rb', line 3780 class CreatedAt < Struct.new( :before, :after) SENSITIVE = [] include Aws::Structure end |