Class: Aws::ECS::Types::DaemonAlarmConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonAlarmConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The CloudWatch alarm configuration for a daemon. When enabled, CloudWatch alarms determine whether a daemon deployment has failed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_names ⇒ Array<String>
The CloudWatch alarm names to monitor during a daemon deployment.
-
#enable ⇒ Boolean
Determines whether to use the CloudWatch alarm option in the daemon deployment process.
Instance Attribute Details
#alarm_names ⇒ Array<String>
The CloudWatch alarm names to monitor during a daemon deployment.
4038 4039 4040 4041 4042 4043 |
# File 'lib/aws-sdk-ecs/types.rb', line 4038 class DaemonAlarmConfiguration < Struct.new( :alarm_names, :enable) SENSITIVE = [] include Aws::Structure end |
#enable ⇒ Boolean
Determines whether to use the CloudWatch alarm option in the daemon deployment process. The default value is ‘false`.
4038 4039 4040 4041 4042 4043 |
# File 'lib/aws-sdk-ecs/types.rb', line 4038 class DaemonAlarmConfiguration < Struct.new( :alarm_names, :enable) SENSITIVE = [] include Aws::Structure end |