Class: Aws::ECS::Types::DaemonCapacityProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about a capacity provider associated with a daemon revision.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the capacity provider.

Returns:

  • (String)


4058
4059
4060
4061
4062
4063
# File 'lib/aws-sdk-ecs/types.rb', line 4058

class DaemonCapacityProvider < Struct.new(
  :arn,
  :running_count)
  SENSITIVE = []
  include Aws::Structure
end

#running_countInteger

The number of daemon tasks running on this capacity provider.

Returns:

  • (Integer)


4058
4059
4060
4061
4062
4063
# File 'lib/aws-sdk-ecs/types.rb', line 4058

class DaemonCapacityProvider < Struct.new(
  :arn,
  :running_count)
  SENSITIVE = []
  include Aws::Structure
end