Class: Aws::ECS::Types::DaemonCircuitBreaker

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about the circuit breaker used to determine when a daemon deployment has failed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_countInteger

The number of times the circuit breaker detected a daemon deployment failure.

Returns:

  • (Integer)


4085
4086
4087
4088
4089
4090
4091
# File 'lib/aws-sdk-ecs/types.rb', line 4085

class DaemonCircuitBreaker < Struct.new(
  :failure_count,
  :status,
  :threshold)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The circuit breaker status. Amazon ECS is not using the circuit breaker for daemon deployment failures when the status is ‘DISABLED`.

Returns:

  • (String)


4085
4086
4087
4088
4089
4090
4091
# File 'lib/aws-sdk-ecs/types.rb', line 4085

class DaemonCircuitBreaker < Struct.new(
  :failure_count,
  :status,
  :threshold)
  SENSITIVE = []
  include Aws::Structure
end

#thresholdInteger

The threshold which determines that the daemon deployment failed.

Returns:

  • (Integer)


4085
4086
4087
4088
4089
4090
4091
# File 'lib/aws-sdk-ecs/types.rb', line 4085

class DaemonCircuitBreaker < Struct.new(
  :failure_count,
  :status,
  :threshold)
  SENSITIVE = []
  include Aws::Structure
end