Class: Aws::ECS::Types::DaemonDeploymentAlarms

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The CloudWatch alarms used to determine a daemon deployment failed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_namesArray<String>

The name of the CloudWatch alarms that determine when a daemon deployment failed.

Returns:

  • (Array<String>)


4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-ecs/types.rb', line 4401

class DaemonDeploymentAlarms < Struct.new(
  :status,
  :alarm_names,
  :triggered_alarm_names)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the alarms check. Amazon ECS is not using alarms for daemon deployment failures when the status is ‘DISABLED`.

Returns:

  • (String)


4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-ecs/types.rb', line 4401

class DaemonDeploymentAlarms < Struct.new(
  :status,
  :alarm_names,
  :triggered_alarm_names)
  SENSITIVE = []
  include Aws::Structure
end

#triggered_alarm_namesArray<String>

One or more CloudWatch alarm names that have been triggered during the daemon deployment.

Returns:

  • (Array<String>)


4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-ecs/types.rb', line 4401

class DaemonDeploymentAlarms < Struct.new(
  :status,
  :alarm_names,
  :triggered_alarm_names)
  SENSITIVE = []
  include Aws::Structure
end