Class: Aws::ECS::Types::DaemonDeploymentCapacityProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about a capacity provider during a daemon deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the capacity provider.

Returns:

  • (String)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-ecs/types.rb', line 4572

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :without_daemon_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#draining_instance_countInteger

The number of instances being drained on this capacity provider during the deployment.

Returns:

  • (Integer)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-ecs/types.rb', line 4572

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :without_daemon_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#running_instance_countInteger

The number of instances running daemon tasks on this capacity provider.

Returns:

  • (Integer)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-ecs/types.rb', line 4572

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :without_daemon_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#without_daemon_instance_countInteger

The number of instances on this capacity provider that are running without the daemon task. This applies to daemons that aren't critical, where the instance remains available for your other tasks even if the daemon task can't start or stops. These instances aren't included in runningInstanceCount.

Returns:

  • (Integer)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-ecs/types.rb', line 4572

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :without_daemon_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end