Class: Aws::ECS::Types::DaemonDeploymentRevisionDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonDeploymentRevisionDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Details about a daemon revision during a deployment, including running and draining instance counts per capacity provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the daemon revision.
-
#capacity_providers ⇒ Array<Types::DaemonDeploymentCapacityProvider>
The capacity providers associated with this daemon revision during the deployment.
-
#total_draining_instance_count ⇒ Integer
The total number of instances being drained for this revision during the deployment.
-
#total_running_instance_count ⇒ Integer
The total number of instances running daemon tasks for this revision.
-
#total_without_daemon_instance_count ⇒ Integer
The total number of instances running without the daemon task for this revision, across all capacity providers.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the daemon revision.
4641 4642 4643 4644 4645 4646 4647 4648 4649 |
# File 'lib/aws-sdk-ecs/types.rb', line 4641 class DaemonDeploymentRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_instance_count, :total_without_daemon_instance_count, :total_draining_instance_count) SENSITIVE = [] include Aws::Structure end |
#capacity_providers ⇒ Array<Types::DaemonDeploymentCapacityProvider>
The capacity providers associated with this daemon revision during the deployment.
4641 4642 4643 4644 4645 4646 4647 4648 4649 |
# File 'lib/aws-sdk-ecs/types.rb', line 4641 class DaemonDeploymentRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_instance_count, :total_without_daemon_instance_count, :total_draining_instance_count) SENSITIVE = [] include Aws::Structure end |
#total_draining_instance_count ⇒ Integer
The total number of instances being drained for this revision during the deployment.
4641 4642 4643 4644 4645 4646 4647 4648 4649 |
# File 'lib/aws-sdk-ecs/types.rb', line 4641 class DaemonDeploymentRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_instance_count, :total_without_daemon_instance_count, :total_draining_instance_count) SENSITIVE = [] include Aws::Structure end |
#total_running_instance_count ⇒ Integer
The total number of instances running daemon tasks for this revision.
4641 4642 4643 4644 4645 4646 4647 4648 4649 |
# File 'lib/aws-sdk-ecs/types.rb', line 4641 class DaemonDeploymentRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_instance_count, :total_without_daemon_instance_count, :total_draining_instance_count) SENSITIVE = [] include Aws::Structure end |
#total_without_daemon_instance_count ⇒ Integer
The total number of instances running without the daemon task for
this revision, across all capacity providers. These instances
aren't included in totalRunningInstanceCount.
4641 4642 4643 4644 4645 4646 4647 4648 4649 |
# File 'lib/aws-sdk-ecs/types.rb', line 4641 class DaemonDeploymentRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_instance_count, :total_without_daemon_instance_count, :total_draining_instance_count) SENSITIVE = [] include Aws::Structure end |