Class: Aws::ECS::Types::DaemonDeploymentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonDeploymentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
A summary of a daemon deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that hosts the daemon.
-
#created_at ⇒ Time
The time the daemon deployment was created.
-
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
-
#daemon_deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment.
-
#finished_at ⇒ Time
The time the daemon deployment finished.
-
#started_at ⇒ Time
The time the daemon deployment started.
-
#status ⇒ String
The status of the daemon deployment.
-
#status_reason ⇒ String
Information about why the daemon deployment is in the current status.
-
#stopped_at ⇒ Time
The time the daemon deployment stopped.
-
#target_daemon_revision_arn ⇒ String
The ARN of the daemon revision being deployed.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that hosts the daemon.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time the daemon deployment was created.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#daemon_deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
The time the daemon deployment finished.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time the daemon deployment started.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon deployment.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Information about why the daemon deployment is in the current status.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The time the daemon deployment stopped.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#target_daemon_revision_arn ⇒ String
The ARN of the daemon revision being deployed.
4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 |
# File 'lib/aws-sdk-ecs/types.rb', line 4599 class DaemonDeploymentSummary < Struct.new( :daemon_deployment_arn, :daemon_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision_arn, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |