Class: Aws::ECS::Types::DaemonLinuxParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonLinuxParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The Linux-specific options that are applied to the daemon container, such as Linux kernel capabilities.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capabilities ⇒ Types::KernelCapabilities
The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
-
#devices ⇒ Array<Types::Device>
Any host devices to expose to the container.
-
#init_process_enabled ⇒ Boolean
Run an ‘init` process inside the container that forwards signals and reaps processes.
-
#tmpfs ⇒ Array<Types::Tmpfs>
The container path, mount options, and size (in MiB) of the tmpfs mount.
Instance Attribute Details
#capabilities ⇒ Types::KernelCapabilities
The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
4628 4629 4630 4631 4632 4633 4634 4635 |
# File 'lib/aws-sdk-ecs/types.rb', line 4628 class DaemonLinuxParameters < Struct.new( :capabilities, :devices, :init_process_enabled, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#devices ⇒ Array<Types::Device>
Any host devices to expose to the container.
4628 4629 4630 4631 4632 4633 4634 4635 |
# File 'lib/aws-sdk-ecs/types.rb', line 4628 class DaemonLinuxParameters < Struct.new( :capabilities, :devices, :init_process_enabled, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#init_process_enabled ⇒ Boolean
Run an ‘init` process inside the container that forwards signals and reaps processes.
4628 4629 4630 4631 4632 4633 4634 4635 |
# File 'lib/aws-sdk-ecs/types.rb', line 4628 class DaemonLinuxParameters < Struct.new( :capabilities, :devices, :init_process_enabled, :tmpfs) SENSITIVE = [] include Aws::Structure end |
#tmpfs ⇒ Array<Types::Tmpfs>
The container path, mount options, and size (in MiB) of the tmpfs mount.
4628 4629 4630 4631 4632 4633 4634 4635 |
# File 'lib/aws-sdk-ecs/types.rb', line 4628 class DaemonLinuxParameters < Struct.new( :capabilities, :devices, :init_process_enabled, :tmpfs) SENSITIVE = [] include Aws::Structure end |