Class: Aws::ECS::Types::DaemonRevision

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about a daemon revision. A daemon revision is a snapshot of the daemon’s configuration at the time a deployment was initiated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_arnString

The Amazon Resource Name (ARN) of the cluster that hosts the daemon.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#container_imagesArray<Types::DaemonContainerImage>

The container images used by the daemon revision.

Returns:



4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The Unix timestamp for the time when the daemon revision was created.

Returns:

  • (Time)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_arnString

The Amazon Resource Name (ARN) of the daemon for this revision.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_revision_arnString

The Amazon Resource Name (ARN) of the daemon revision.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_task_definition_arnString

The Amazon Resource Name (ARN) of the daemon task definition used by this revision.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#enable_ecs_managed_tagsBoolean

Specifies whether Amazon ECS managed tags are turned on for the daemon tasks.

Returns:

  • (Boolean)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#enable_execute_commandBoolean

Specifies whether the execute command functionality is turned on for the daemon tasks.

Returns:

  • (Boolean)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end

#propagate_tagsString

Specifies whether tags are propagated from the daemon to the daemon tasks.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/aws-sdk-ecs/types.rb', line 4723

class DaemonRevision < Struct.new(
  :daemon_revision_arn,
  :cluster_arn,
  :daemon_arn,
  :daemon_task_definition_arn,
  :created_at,
  :container_images,
  :propagate_tags,
  :enable_ecs_managed_tags,
  :enable_execute_command)
  SENSITIVE = []
  include Aws::Structure
end