Class: Aws::ECS::Types::DaemonRevisionDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonRevisionDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Details about a daemon revision, including the running task counts per capacity provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the daemon revision.
-
#capacity_providers ⇒ Array<Types::DaemonCapacityProvider>
The capacity providers associated with this daemon revision.
-
#total_running_count ⇒ Integer
The total number of daemon tasks running for this revision.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the daemon revision.
4754 4755 4756 4757 4758 4759 4760 |
# File 'lib/aws-sdk-ecs/types.rb', line 4754 class DaemonRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_count) SENSITIVE = [] include Aws::Structure end |
#capacity_providers ⇒ Array<Types::DaemonCapacityProvider>
The capacity providers associated with this daemon revision.
4754 4755 4756 4757 4758 4759 4760 |
# File 'lib/aws-sdk-ecs/types.rb', line 4754 class DaemonRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_count) SENSITIVE = [] include Aws::Structure end |
#total_running_count ⇒ Integer
The total number of daemon tasks running for this revision.
4754 4755 4756 4757 4758 4759 4760 |
# File 'lib/aws-sdk-ecs/types.rb', line 4754 class DaemonRevisionDetail < Struct.new( :arn, :capacity_providers, :total_running_count) SENSITIVE = [] include Aws::Structure end |