Class: Aws::ECS::Types::DaemonRollback
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonRollback
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Information about a daemon deployment rollback.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason the rollback happened.
-
#rollback_capacity_providers ⇒ Array<String>
The capacity providers involved in the rollback.
-
#rollback_target_daemon_revision_arn ⇒ String
The ARN of the daemon revision deployed as part of the rollback.
-
#started_at ⇒ Time
The time that the rollback started.
Instance Attribute Details
#reason ⇒ String
The reason the rollback happened. For example, the circuit breaker initiated the rollback operation.
4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-ecs/types.rb', line 4784 class DaemonRollback < Struct.new( :reason, :started_at, :rollback_target_daemon_revision_arn, :rollback_capacity_providers) SENSITIVE = [] include Aws::Structure end |
#rollback_capacity_providers ⇒ Array<String>
The capacity providers involved in the rollback.
4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-ecs/types.rb', line 4784 class DaemonRollback < Struct.new( :reason, :started_at, :rollback_target_daemon_revision_arn, :rollback_capacity_providers) SENSITIVE = [] include Aws::Structure end |
#rollback_target_daemon_revision_arn ⇒ String
The ARN of the daemon revision deployed as part of the rollback.
4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-ecs/types.rb', line 4784 class DaemonRollback < Struct.new( :reason, :started_at, :rollback_target_daemon_revision_arn, :rollback_capacity_providers) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time that the rollback started. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
4784 4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-ecs/types.rb', line 4784 class DaemonRollback < Struct.new( :reason, :started_at, :rollback_target_daemon_revision_arn, :rollback_capacity_providers) SENSITIVE = [] include Aws::Structure end |