Class: Aws::ECS::Types::DaemonSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

A summary of a daemon.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The Unix timestamp for the time when the daemon was created.

Returns:

  • (Time)


4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-ecs/types.rb', line 4813

class DaemonSummary < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_arnString

The Amazon Resource Name (ARN) of the daemon.

Returns:

  • (String)


4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-ecs/types.rb', line 4813

class DaemonSummary < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the daemon.

Returns:

  • (String)


4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-ecs/types.rb', line 4813

class DaemonSummary < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for the time when the daemon was last updated.

Returns:

  • (Time)


4813
4814
4815
4816
4817
4818
4819
4820
# File 'lib/aws-sdk-ecs/types.rb', line 4813

class DaemonSummary < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end