Class: Aws::ECS::Types::DaemonTaskDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The details of a daemon task definition. A daemon task definition is a template that describes the containers that form a daemon. Daemons deploy cross-cutting software agents independently across your Amazon ECS infrastructure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_definitionsArray<Types::DaemonContainerDefinition>

A list of container definitions in JSON format that describe the containers that make up the daemon task.



4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#cpuString

The number of CPU units used by the daemon task.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_task_definition_arnString

The full Amazon Resource Name (ARN) of the daemon task definition.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#delete_requested_atTime

The Unix timestamp for the time when the daemon task definition delete was requested.

Returns:

  • (Time)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#familyString

The name of a family that this daemon task definition is registered to.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#ipc_modeString

The IPC namespace mode for the daemon. The valid values are ‘none` and `shared`. The default is `none`.

If ‘none` is specified or no value is provided, the daemon runs with its own IPC namespace, isolated from other tasks. If `shared` is specified, the daemon joins the host IPC namespace, making it accessible to non-daemon tasks that use `ipcMode: “host”` or other daemons that use `ipcMode: “shared”`.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#memoryString

The amount of memory (in MiB) used by the daemon task.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#pid_modeString

The PID namespace mode for the daemon. The valid values are ‘none` and `shared`. The default is `none`.

If ‘none` is specified or no value is provided, the daemon runs with its own PID namespace, isolated from other tasks. If `shared` is specified, the daemon joins the host PID namespace, making it accessible to non-daemon tasks that use `pidMode: “host”` or other daemons that use `pidMode: “shared”`.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#registered_atTime

The Unix timestamp for the time when the daemon task definition was registered.

Returns:

  • (Time)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#registered_byString

The principal that registered the daemon task definition.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#revisionInteger

The revision of the daemon task in a particular family. The revision is a version number of a daemon task definition in a family. When you register a daemon task definition for the first time, the revision is ‘1`. Each time that you register a new revision of a daemon task definition in the same family, the revision value always increases by one.

Returns:

  • (Integer)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the daemon task definition. The valid values are ‘ACTIVE`, `DELETE_IN_PROGRESS`, and `DELETED`.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The short name or full Amazon Resource Name (ARN) of the IAM role that grants containers in the daemon task permission to call Amazon Web Services APIs on your behalf.

Returns:

  • (String)


4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end

#volumesArray<Types::DaemonVolume>

The list of data volume definitions for the daemon task.

Returns:



4994
4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
5007
5008
5009
5010
5011
5012
# File 'lib/aws-sdk-ecs/types.rb', line 4994

class DaemonTaskDefinition < Struct.new(
  :daemon_task_definition_arn,
  :family,
  :revision,
  :task_role_arn,
  :execution_role_arn,
  :container_definitions,
  :volumes,
  :cpu,
  :memory,
  :status,
  :registered_at,
  :delete_requested_at,
  :registered_by,
  :pid_mode,
  :ipc_mode)
  SENSITIVE = []
  include Aws::Structure
end