Class: Aws::ECS::Types::DaemonTaskDefinitionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonTaskDefinitionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
A summary of a daemon task definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the daemon task definition.
-
#delete_requested_at ⇒ Time
The Unix timestamp for the time when the daemon task definition delete was requested.
-
#registered_at ⇒ Time
The Unix timestamp for the time when the daemon task definition was registered.
-
#registered_by ⇒ String
The principal that registered the daemon task definition.
-
#status ⇒ String
The status of the daemon task definition.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the daemon task definition.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-ecs/types.rb', line 4939 class DaemonTaskDefinitionSummary < Struct.new( :arn, :registered_at, :registered_by, :delete_requested_at, :status) SENSITIVE = [] include Aws::Structure end |
#delete_requested_at ⇒ Time
The Unix timestamp for the time when the daemon task definition delete was requested.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-ecs/types.rb', line 4939 class DaemonTaskDefinitionSummary < Struct.new( :arn, :registered_at, :registered_by, :delete_requested_at, :status) SENSITIVE = [] include Aws::Structure end |
#registered_at ⇒ Time
The Unix timestamp for the time when the daemon task definition was registered.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-ecs/types.rb', line 4939 class DaemonTaskDefinitionSummary < Struct.new( :arn, :registered_at, :registered_by, :delete_requested_at, :status) SENSITIVE = [] include Aws::Structure end |
#registered_by ⇒ String
The principal that registered the daemon task definition.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-ecs/types.rb', line 4939 class DaemonTaskDefinitionSummary < Struct.new( :arn, :registered_at, :registered_by, :delete_requested_at, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon task definition.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-ecs/types.rb', line 4939 class DaemonTaskDefinitionSummary < Struct.new( :arn, :registered_at, :registered_by, :delete_requested_at, :status) SENSITIVE = [] include Aws::Structure end |