Class: Aws::ECS::Types::DeleteServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to delete.
-
#force ⇒ Boolean
If
true, allows you to delete a service even if it wasn’t scaled down to zero tasks. -
#service ⇒ String
The name of the service to delete.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to delete. If you do not specify a cluster, the default cluster is assumed.
3988 3989 3990 3991 3992 3993 3994 |
# File 'lib/aws-sdk-ecs/types.rb', line 3988 class DeleteServiceRequest < Struct.new( :cluster, :service, :force) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
If true, allows you to delete a service even if it wasn’t scaled down to zero tasks. It’s only necessary to use this if the service uses the REPLICA scheduling strategy.
3988 3989 3990 3991 3992 3993 3994 |
# File 'lib/aws-sdk-ecs/types.rb', line 3988 class DeleteServiceRequest < Struct.new( :cluster, :service, :force) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The name of the service to delete.
3988 3989 3990 3991 3992 3993 3994 |
# File 'lib/aws-sdk-ecs/types.rb', line 3988 class DeleteServiceRequest < Struct.new( :cluster, :service, :force) SENSITIVE = [] include Aws::Structure end |