Class: Aws::ECS::Types::DeploymentAlarms

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

One of the methods which provide a way for you to quickly identify when a deployment has failed, and then to optionally roll back the failure to the last working deployment.

When the alarms are generated, Amazon ECS sets the service deployment to failed. Set the rollback parameter to have Amazon ECS to roll back your service to the last completed deployment after a failure.

You can only use the ‘DeploymentAlarms` method to detect failures when the `DeploymentController` is set to `ECS`.

For more information, see [Rolling update] in the Amazon Elastic Container Service Developer Guide .

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-ecs.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_namesArray<String>

One or more CloudWatch alarm names. Use a “,” to separate the alarms.

Returns:

  • (Array<String>)


5669
5670
5671
5672
5673
5674
5675
# File 'lib/aws-sdk-ecs/types.rb', line 5669

class DeploymentAlarms < Struct.new(
  :alarm_names,
  :rollback,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#enableBoolean

Determines whether to use the CloudWatch alarm option in the service deployment process.

Returns:

  • (Boolean)


5669
5670
5671
5672
5673
5674
5675
# File 'lib/aws-sdk-ecs/types.rb', line 5669

class DeploymentAlarms < Struct.new(
  :alarm_names,
  :rollback,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#rollbackBoolean

Determines whether to configure Amazon ECS to roll back the service if a service deployment fails. If rollback is used, when a service deployment fails, the service is rolled back to the last deployment that completed successfully.

Returns:

  • (Boolean)


5669
5670
5671
5672
5673
5674
5675
# File 'lib/aws-sdk-ecs/types.rb', line 5669

class DeploymentAlarms < Struct.new(
  :alarm_names,
  :rollback,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end