Class: Aws::ECS::Types::DeploymentCircuitBreaker
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeploymentCircuitBreaker
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
ECS) deployment type.
The deployment circuit breaker determines whether a service deployment will fail if the service can't reach a steady state. If it is turned on, a service deployment will transition to a failed state and stop launching new tasks. You can also configure Amazon ECS to roll back your service to the last completed deployment after a failure. For more information, see Rolling update in the Amazon Elastic Container Service Developer Guide.
For more information about API failure reasons, see API failure reasons in the Amazon Elastic Container Service Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
Determines whether to use the deployment circuit breaker logic for the service.
-
#reset_on_healthy_task ⇒ Boolean
Specifies whether the deployment circuit breaker resets its failure count when a task reaches a healthy state.
-
#rollback ⇒ Boolean
Determines whether to configure Amazon ECS to roll back the service if a service deployment fails.
-
#threshold_configuration ⇒ Types::ThresholdConfiguration
The threshold configuration that controls when the deployment circuit breaker triggers.
Instance Attribute Details
#enable ⇒ Boolean
Determines whether to use the deployment circuit breaker logic for the service.
5759 5760 5761 5762 5763 5764 5765 5766 |
# File 'lib/aws-sdk-ecs/types.rb', line 5759 class DeploymentCircuitBreaker < Struct.new( :enable, :rollback, :reset_on_healthy_task, :threshold_configuration) SENSITIVE = [] include Aws::Structure end |
#reset_on_healthy_task ⇒ Boolean
Specifies whether the deployment circuit breaker resets its failure
count when a task reaches a healthy state. When set to true, a
task that reaches a healthy state resets the failure count to 0.
When set to false, Amazon ECS does not reset the failure count.
The default is true.
5759 5760 5761 5762 5763 5764 5765 5766 |
# File 'lib/aws-sdk-ecs/types.rb', line 5759 class DeploymentCircuitBreaker < Struct.new( :enable, :rollback, :reset_on_healthy_task, :threshold_configuration) SENSITIVE = [] include Aws::Structure end |
#rollback ⇒ Boolean
Determines whether to configure Amazon ECS to roll back the service if a service deployment fails. If rollback is on, when a service deployment fails, the service is rolled back to the last deployment that completed successfully.
5759 5760 5761 5762 5763 5764 5765 5766 |
# File 'lib/aws-sdk-ecs/types.rb', line 5759 class DeploymentCircuitBreaker < Struct.new( :enable, :rollback, :reset_on_healthy_task, :threshold_configuration) SENSITIVE = [] include Aws::Structure end |
#threshold_configuration ⇒ Types::ThresholdConfiguration
The threshold configuration that controls when the deployment
circuit breaker triggers. The type and value together determine
how many task failures are tolerated before the circuit breaker
activates.
5759 5760 5761 5762 5763 5764 5765 5766 |
# File 'lib/aws-sdk-ecs/types.rb', line 5759 class DeploymentCircuitBreaker < Struct.new( :enable, :rollback, :reset_on_healthy_task, :threshold_configuration) SENSITIVE = [] include Aws::Structure end |