Class: Aws::ECS::Types::DeploymentController

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass DeploymentController data as a hash:

{
  type: "ECS", # required, accepts ECS, CODE_DEPLOY, EXTERNAL
}

The deployment controller to use for the service. For more information, see [Amazon ECS Deployment Types][1] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-types.html

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The deployment controller type to use.

There are three deployment controller types available:

ECS

: The rolling update (ECS) deployment type involves replacing the

current running version of the container with the latest version.
The number of containers Amazon ECS adds or removes from the
service during a rolling update is controlled by adjusting the
minimum and maximum number of healthy tasks allowed during a
service deployment, as specified in the DeploymentConfiguration.

CODE_DEPLOY

: The blue/green (CODE_DEPLOY) deployment type uses the blue/green

deployment model powered by AWS CodeDeploy, which allows you to
verify a new deployment of a service before sending production
traffic to it.

EXTERNAL

: The external (EXTERNAL) deployment type enables you to use any

third-party deployment controller for full control over the
deployment process for an Amazon ECS service.

Returns:

  • (String)


3388
3389
3390
3391
# File 'lib/aws-sdk-ecs/types.rb', line 3388

class DeploymentController < Struct.new(
  :type)
  include Aws::Structure
end