Class: Aws::ECS::Types::DeploymentLifecycleHookDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The details of a deployment lifecycle hook that is active during a service deployment.

You can view lifecycle hook details by calling [DescribeServiceDeployments].

[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServiceDeployments.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expires_atTime

The time when the lifecycle hook times out. If the hook has not been completed by this time, Amazon ECS takes the timeout action.

Returns:

  • (Time)


6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-ecs/types.rb', line 6231

class DeploymentLifecycleHookDetail < Struct.new(
  :hook_id,
  :target_type,
  :target_arn,
  :status,
  :expires_at,
  :timeout_action)
  SENSITIVE = []
  include Aws::Structure
end

#hook_idString

The ID of the lifecycle hook. Use this value when calling ‘ContinueServiceDeployment` to continue or roll back a paused deployment.

Returns:

  • (String)


6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-ecs/types.rb', line 6231

class DeploymentLifecycleHookDetail < Struct.new(
  :hook_id,
  :target_type,
  :target_arn,
  :status,
  :expires_at,
  :timeout_action)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the lifecycle hook. Valid values depend on the hook type:

  • For ‘AWS_LAMBDA` hooks: `IN_PROGRESS`, `SUCCEEDED`, `FAILED`, and `TIMED_OUT`.

  • For ‘PAUSE` hooks: `AWAITING_ACTION`, `SUCCEEDED`, `FAILED`, and `TIMED_OUT`.

Returns:

  • (String)


6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-ecs/types.rb', line 6231

class DeploymentLifecycleHookDetail < Struct.new(
  :hook_id,
  :target_type,
  :target_arn,
  :status,
  :expires_at,
  :timeout_action)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) of the hook target. For ‘AWS_LAMBDA` hooks, this is the Lambda function ARN. For `PAUSE` hooks, this field is not set.

Returns:

  • (String)


6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-ecs/types.rb', line 6231

class DeploymentLifecycleHookDetail < Struct.new(
  :hook_id,
  :target_type,
  :target_arn,
  :status,
  :expires_at,
  :timeout_action)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

The type of action the lifecycle hook performs, such as ‘AWS_LAMBDA` or `PAUSE`.

Returns:

  • (String)


6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-ecs/types.rb', line 6231

class DeploymentLifecycleHookDetail < Struct.new(
  :hook_id,
  :target_type,
  :target_arn,
  :status,
  :expires_at,
  :timeout_action)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_actionString

The action Amazon ECS takes when the lifecycle hook times out. Valid values are ‘CONTINUE` and `ROLLBACK`.

Returns:

  • (String)


6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
# File 'lib/aws-sdk-ecs/types.rb', line 6231

class DeploymentLifecycleHookDetail < Struct.new(
  :hook_id,
  :target_type,
  :target_arn,
  :status,
  :expires_at,
  :timeout_action)
  SENSITIVE = []
  include Aws::Structure
end