Class: Aws::ECS::Types::DeploymentLifecycleHookTimeoutConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The timeout configuration for a deployment lifecycle hook. This determines how long Amazon ECS waits for the hook to complete before taking the specified timeout action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action Amazon ECS takes when the lifecycle hook times out. Valid values are:

  • ‘CONTINUE` - Proceeds the deployment to the next lifecycle stage.

  • ‘ROLLBACK` - Rolls back the deployment to the previous service revision.

Returns:

  • (String)


6263
6264
6265
6266
6267
6268
# File 'lib/aws-sdk-ecs/types.rb', line 6263

class DeploymentLifecycleHookTimeoutConfiguration < Struct.new(
  :timeout_in_minutes,
  :action)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_in_minutesInteger

The number of minutes Amazon ECS waits for the lifecycle hook to complete before taking the timeout action.

Returns:

  • (Integer)


6263
6264
6265
6266
6267
6268
# File 'lib/aws-sdk-ecs/types.rb', line 6263

class DeploymentLifecycleHookTimeoutConfiguration < Struct.new(
  :timeout_in_minutes,
  :action)
  SENSITIVE = []
  include Aws::Structure
end