Class: Aws::ECS::Types::DescribeCapacityProvidersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeCapacityProvidersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_providers ⇒ Array<String>
The short name or full Amazon Resource Name (ARN) of one or more capacity providers.
-
#cluster ⇒ String
The name of the cluster to describe capacity providers for.
-
#include ⇒ Array<String>
Specifies whether or not you want to see the resource tags for the capacity provider.
-
#max_results ⇒ Integer
The maximum number of account setting results returned by
DescribeCapacityProvidersin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedDescribeCapacityProvidersrequest wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#capacity_providers ⇒ Array<String>
The short name or full Amazon Resource Name (ARN) of one or more capacity providers. Up to 100 capacity providers can be described in an action.
4953 4954 4955 4956 4957 4958 4959 4960 4961 |
# File 'lib/aws-sdk-ecs/types.rb', line 4953 class DescribeCapacityProvidersRequest < Struct.new( :capacity_providers, :cluster, :include, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The name of the cluster to describe capacity providers for. When specified, only capacity providers associated with this cluster are returned, including Amazon ECS Managed Instances capacity providers.
4953 4954 4955 4956 4957 4958 4959 4960 4961 |
# File 'lib/aws-sdk-ecs/types.rb', line 4953 class DescribeCapacityProvidersRequest < Struct.new( :capacity_providers, :cluster, :include, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Array<String>
Specifies whether or not you want to see the resource tags for the capacity provider. If TAGS is specified, the tags are included in the response. If this field is omitted, tags aren’t included in the response.
4953 4954 4955 4956 4957 4958 4959 4960 4961 |
# File 'lib/aws-sdk-ecs/types.rb', line 4953 class DescribeCapacityProvidersRequest < Struct.new( :capacity_providers, :cluster, :include, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of account setting results returned by DescribeCapacityProviders in paginated output. When this parameter is used, DescribeCapacityProviders only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeCapacityProviders request with the returned nextToken value. This value can be between 1 and 10. If this parameter is not used, then DescribeCapacityProviders returns up to 10 results and a nextToken value if applicable.
4953 4954 4955 4956 4957 4958 4959 4960 4961 |
# File 'lib/aws-sdk-ecs/types.rb', line 4953 class DescribeCapacityProvidersRequest < Struct.new( :capacity_providers, :cluster, :include, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated DescribeCapacityProviders request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.
<note markdown=“1”> This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
4953 4954 4955 4956 4957 4958 4959 4960 4961 |
# File 'lib/aws-sdk-ecs/types.rb', line 4953 class DescribeCapacityProvidersRequest < Struct.new( :capacity_providers, :cluster, :include, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |