Class: Aws::ECS::Types::DescribeClustersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeClustersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#clusters ⇒ Array<String>
A list of up to 100 cluster names or full cluster Amazon Resource Name (ARN) entries.
-
#include ⇒ Array<String>
Determines whether to include additional information about the clusters in the response.
Instance Attribute Details
#clusters ⇒ Array<String>
A list of up to 100 cluster names or full cluster Amazon Resource Name (ARN) entries. If you do not specify a cluster, the default cluster is assumed.
6571 6572 6573 6574 6575 6576 |
# File 'lib/aws-sdk-ecs/types.rb', line 6571 class DescribeClustersRequest < Struct.new( :clusters, :include) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Array<String>
Determines whether to include additional information about the clusters in the response. If this field is omitted, this information isn't included.
If ATTACHMENTS is specified, the attachments for the container
instances or tasks within the cluster are included, for example the
capacity providers.
If SETTINGS is specified, the settings for the cluster are
included.
If CONFIGURATIONS is specified, the configuration for the cluster
is included.
If STATISTICS is specified, the task and service count is
included, separated by launch type.
If TAGS is specified, the metadata tags associated with the
cluster are included.
6571 6572 6573 6574 6575 6576 |
# File 'lib/aws-sdk-ecs/types.rb', line 6571 class DescribeClustersRequest < Struct.new( :clusters, :include) SENSITIVE = [] include Aws::Structure end |