Class: Aws::ECS::Types::DescribeDaemonResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeDaemonResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#daemon ⇒ Types::DaemonDetail
The full description of the daemon, including the current revisions, deployment ARN, cluster, and status information.
Instance Attribute Details
#daemon ⇒ Types::DaemonDetail
The full description of the daemon, including the current revisions, deployment ARN, cluster, and status information.
6451 6452 6453 6454 6455 |
# File 'lib/aws-sdk-ecs/types.rb', line 6451 class DescribeDaemonResponse < Struct.new( :daemon) SENSITIVE = [] include Aws::Structure end |