Class: Aws::ECS::Types::DescribeDaemonTaskDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeDaemonTaskDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#daemon_task_definition ⇒ String
The ‘family` for the latest `ACTIVE` revision, `family` and `revision` (`family:revision`) for a specific revision in the family, or full Amazon Resource Name (ARN) of the daemon task definition to describe.
Instance Attribute Details
#daemon_task_definition ⇒ String
The ‘family` for the latest `ACTIVE` revision, `family` and `revision` (`family:revision`) for a specific revision in the family, or full Amazon Resource Name (ARN) of the daemon task definition to describe.
6496 6497 6498 6499 6500 |
# File 'lib/aws-sdk-ecs/types.rb', line 6496 class DescribeDaemonTaskDefinitionRequest < Struct.new( :daemon_task_definition) SENSITIVE = [] include Aws::Structure end |