Class: Aws::ECS::Types::DescribeExpressGatewayServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeExpressGatewayServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#include ⇒ Array<String>
Specifies additional information to include in the response.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to describe.
Instance Attribute Details
#include ⇒ Array<String>
Specifies additional information to include in the response. Valid values are TAGS to include resource tags associated with the Express service.
5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-ecs/types.rb', line 5159 class DescribeExpressGatewayServiceRequest < Struct.new( :service_arn, :include) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to describe. The ARN uniquely identifies the service within your Amazon Web Services account and region.
5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-ecs/types.rb', line 5159 class DescribeExpressGatewayServiceRequest < Struct.new( :service_arn, :include) SENSITIVE = [] include Aws::Structure end |