Class: Aws::ECS::Types::DescribeServicesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeServicesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN)the cluster that hosts the service to describe.
-
#include ⇒ Array<String>
Determines whether you want to see the resource tags for the service.
-
#services ⇒ Array<String>
A list of services to describe.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN)the cluster that hosts the service to describe. If you do not specify a cluster, the default cluster is assumed. This parameter is required if the service or services you are describing were launched in any cluster other than the default cluster.
5276 5277 5278 5279 5280 5281 5282 |
# File 'lib/aws-sdk-ecs/types.rb', line 5276 class DescribeServicesRequest < Struct.new( :cluster, :services, :include) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Array<String>
Determines whether you want to see the resource tags for the service. If TAGS is specified, the tags are included in the response. If this field is omitted, tags aren’t included in the response.
5276 5277 5278 5279 5280 5281 5282 |
# File 'lib/aws-sdk-ecs/types.rb', line 5276 class DescribeServicesRequest < Struct.new( :cluster, :services, :include) SENSITIVE = [] include Aws::Structure end |
#services ⇒ Array<String>
A list of services to describe. You may specify up to 10 services to describe in a single operation.
5276 5277 5278 5279 5280 5281 5282 |
# File 'lib/aws-sdk-ecs/types.rb', line 5276 class DescribeServicesRequest < Struct.new( :cluster, :services, :include) SENSITIVE = [] include Aws::Structure end |