Class: Aws::ECS::Types::DescribeTaskDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

<zonbook />

<xhtml />

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#includeArray<String>

Determines whether to see the resource tags for the task definition. If TAGS is specified, the tags are included in the response. If this field is omitted, tags aren’t included in the response.

Returns:

  • (Array<String>)


5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-ecs/types.rb', line 5324

class DescribeTaskDefinitionRequest < Struct.new(
  :task_definition,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#task_definitionString

The family for the latest ACTIVE revision, family and revision (family:revision) for a specific revision in the family, or full Amazon Resource Name (ARN) of the task definition to describe.

Returns:

  • (String)


5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-ecs/types.rb', line 5324

class DescribeTaskDefinitionRequest < Struct.new(
  :task_definition,
  :include)
  SENSITIVE = []
  include Aws::Structure
end