Class: Aws::ECS::Types::Device
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::Device
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
An object representing a container instance host device.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_path ⇒ String
The path inside the container at which to expose the host device.
-
#host_path ⇒ String
The path for the device on the host container instance.
-
#permissions ⇒ Array<String>
The explicit permissions to provide to the container for the device.
Instance Attribute Details
#container_path ⇒ String
The path inside the container at which to expose the host device.
5496 5497 5498 5499 5500 5501 5502 |
# File 'lib/aws-sdk-ecs/types.rb', line 5496 class Device < Struct.new( :host_path, :container_path, :permissions) SENSITIVE = [] include Aws::Structure end |
#host_path ⇒ String
The path for the device on the host container instance.
5496 5497 5498 5499 5500 5501 5502 |
# File 'lib/aws-sdk-ecs/types.rb', line 5496 class Device < Struct.new( :host_path, :container_path, :permissions) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Array<String>
The explicit permissions to provide to the container for the device. By default, the container has permissions for read, write, and mknod for the device.
5496 5497 5498 5499 5500 5501 5502 |
# File 'lib/aws-sdk-ecs/types.rb', line 5496 class Device < Struct.new( :host_path, :container_path, :permissions) SENSITIVE = [] include Aws::Structure end |