Class: Aws::ECS::Types::DiscoverPollEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DiscoverPollEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that the container instance belongs to.
-
#container_instance ⇒ String
The container instance ID or full ARN of the container instance.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that the container instance belongs to.
7147 7148 7149 7150 7151 7152 |
# File 'lib/aws-sdk-ecs/types.rb', line 7147 class DiscoverPollEndpointRequest < Struct.new( :container_instance, :cluster) SENSITIVE = [] include Aws::Structure end |
#container_instance ⇒ String
The container instance ID or full ARN of the container instance. For more information about the ARN format, see Amazon Resource Name (ARN) in the Amazon ECS Developer Guide.
7147 7148 7149 7150 7151 7152 |
# File 'lib/aws-sdk-ecs/types.rb', line 7147 class DiscoverPollEndpointRequest < Struct.new( :container_instance, :cluster) SENSITIVE = [] include Aws::Structure end |