Class: Aws::ECS::Types::EFSAuthorizationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The authorization configuration details for the Amazon EFS file system.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_idString

The Amazon EFS access point ID to use. If an access point is specified, the root directory value specified in the EFSVolumeConfiguration must either be omitted or set to / which will enforce the path set on the EFS access point. If an access point is used, transit encryption must be on in the EFSVolumeConfiguration. For more information, see [Working with Amazon EFS access points] in the *Amazon Elastic File System User Guide*.

[1]: docs.aws.amazon.com/efs/latest/ug/efs-access-points.html



5754
5755
5756
5757
5758
5759
# File 'lib/aws-sdk-ecs/types.rb', line 5754

class EFSAuthorizationConfig < Struct.new(
  :access_point_id,
  :iam)
  SENSITIVE = []
  include Aws::Structure
end

#iamString

Determines whether to use the Amazon ECS task role defined in a task definition when mounting the Amazon EFS file system. If it is turned on, transit encryption must be turned on in the EFSVolumeConfiguration. If this parameter is omitted, the default value of DISABLED is used. For more information, see [Using Amazon EFS access points] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/efs-volumes.html#efs-volume-accesspoints



5754
5755
5756
5757
5758
5759
# File 'lib/aws-sdk-ecs/types.rb', line 5754

class EFSAuthorizationConfig < Struct.new(
  :access_point_id,
  :iam)
  SENSITIVE = []
  include Aws::Structure
end