Class: Aws::ECS::Types::EFSVolumeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass EFSVolumeConfiguration data as a hash:

{
  file_system_id: "String", # required
  root_directory: "String",
}

This parameter is specified when you are using an Amazon Elastic File System (Amazon EFS) file storage. Amazon EFS file systems are only supported when you are using the EC2 launch type.

EFSVolumeConfiguration remains in preview and is a Beta Service as defined by and subject to the Beta Service Participation Service Terms located at [aws.amazon.com/service-terms][1] (“Beta Terms”). These Beta Terms apply to your participation in this preview of EFSVolumeConfiguration.

[1]: aws.amazon.com/service-terms

Instance Attribute Summary collapse

Instance Attribute Details

#file_system_idString

The Amazon EFS file system ID to use.

Returns:

  • (String)


4126
4127
4128
4129
4130
# File 'lib/aws-sdk-ecs/types.rb', line 4126

class EFSVolumeConfiguration < Struct.new(
  :file_system_id,
  :root_directory)
  include Aws::Structure
end

#root_directoryString

The directory within the Amazon EFS file system to mount as the root directory inside the host.

Returns:

  • (String)


4126
4127
4128
4129
4130
# File 'lib/aws-sdk-ecs/types.rb', line 4126

class EFSVolumeConfiguration < Struct.new(
  :file_system_id,
  :root_directory)
  include Aws::Structure
end