Class: Aws::ECS::Types::EphemeralStorage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::EphemeralStorage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on Fargate. For more information, see Using data volumes in tasks in the Amazon ECS Developer Guide;.
-
Linux platform version
1.4.0or later. -
Windows platform version
1.0.0or later.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#size_in_gi_b ⇒ Integer
The total amount, in GiB, of ephemeral storage to set for the task.
Instance Attribute Details
#size_in_gi_b ⇒ Integer
The total amount, in GiB, of ephemeral storage to set for the task.
The minimum supported value is 21 GiB and the maximum supported
value is 200 GiB.
7567 7568 7569 7570 7571 |
# File 'lib/aws-sdk-ecs/types.rb', line 7567 class EphemeralStorage < Struct.new( :size_in_gi_b) SENSITIVE = [] include Aws::Structure end |