Class: Aws::ECS::Types::ExpressGatewayScalingTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ExpressGatewayScalingTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Defines the auto-scaling configuration for an Express service. This determines how the service automatically adjusts the number of running tasks based on demand metrics such as CPU utilization, memory utilization, or request count per target.
Auto-scaling helps ensure your application can handle varying levels of traffic while optimizing costs by scaling down during low-demand periods. You can specify the minimum and maximum number of tasks, the scaling metric, and the target value for that metric.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_metric ⇒ String
The metric used for auto-scaling decisions.
-
#auto_scaling_target_value ⇒ Integer
The target value for the auto-scaling metric.
-
#max_task_count ⇒ Integer
The maximum number of tasks to run in the Express service.
-
#min_task_count ⇒ Integer
The minimum number of tasks to run in the Express service.
Instance Attribute Details
#auto_scaling_metric ⇒ String
The metric used for auto-scaling decisions. The default metric used for an Express service is CPUUtilization.
6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-ecs/types.rb', line 6220 class ExpressGatewayScalingTarget < Struct.new( :min_task_count, :max_task_count, :auto_scaling_metric, :auto_scaling_target_value) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_target_value ⇒ Integer
The target value for the auto-scaling metric. The default value for an Express service is 60.
6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-ecs/types.rb', line 6220 class ExpressGatewayScalingTarget < Struct.new( :min_task_count, :max_task_count, :auto_scaling_metric, :auto_scaling_target_value) SENSITIVE = [] include Aws::Structure end |
#max_task_count ⇒ Integer
The maximum number of tasks to run in the Express service.
6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-ecs/types.rb', line 6220 class ExpressGatewayScalingTarget < Struct.new( :min_task_count, :max_task_count, :auto_scaling_metric, :auto_scaling_target_value) SENSITIVE = [] include Aws::Structure end |
#min_task_count ⇒ Integer
The minimum number of tasks to run in the Express service.
6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-ecs/types.rb', line 6220 class ExpressGatewayScalingTarget < Struct.new( :min_task_count, :max_task_count, :auto_scaling_metric, :auto_scaling_target_value) SENSITIVE = [] include Aws::Structure end |