Class: Aws::ECS::Types::ExpressGatewayServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Represents a specific configuration revision of an Express service, containing all the settings and parameters for that revision.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpuString

The CPU allocation for tasks in this service revision.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_architectureString

The CPU architecture that the tasks in this service revision run on. This is the architecture from the task definition that the service revision uses, so it reflects the default or the previously configured architecture when the request that created the revision didn't specify one.

Valid values:

  • X86_64 - The x86 64-bit architecture.

  • ARM64 - The 64-bit ARM architecture.

This value isn't returned when the task definition for the service revision doesn't specify a runtime platform. Because the architecture comes from each service revision's own task definition, revisions of the same service can report different architectures.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The Unix timestamp for when this service revision was created.

Returns:

  • (Time)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the task execution role for the service revision.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathString

The health check path for this service revision.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#ingress_pathsArray<Types::IngressPathSummary>

The entry point into this service revision.

Returns:



8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#memoryString

The memory allocation for tasks in this service revision.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::ExpressGatewayServiceNetworkConfiguration

The network configuration for tasks in this service revision.



8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ExpressGatewayContainer

The primary container configuration for this service revision.



8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_targetTypes::ExpressGatewayScalingTarget

The auto-scaling configuration for this service revision.



8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_revision_arnString

The ARN of the service revision.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_definition_arnString

The ARN of the task definition used by this service revision. This is present for all Express services and reflects the task definition in use, whether managed by Amazon ECS or provided by the customer.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The ARN of the task role for the service revision.

Returns:

  • (String)


8098
8099
8100
8101
8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
# File 'lib/aws-sdk-ecs/types.rb', line 8098

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :task_definition_arn,
  :cpu,
  :memory,
  :cpu_architecture,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end