Class: Aws::ECS::Types::ExpressGatewayServiceStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

An object that defines the status of Express service creation and information about the status of the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#status_codeString

The status of the Express service.

Returns:

  • (String)


6349
6350
6351
6352
6353
6354
# File 'lib/aws-sdk-ecs/types.rb', line 6349

class ExpressGatewayServiceStatus < Struct.new(
  :status_code,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the Express service is in the current status.

Returns:

  • (String)


6349
6350
6351
6352
6353
6354
# File 'lib/aws-sdk-ecs/types.rb', line 6349

class ExpressGatewayServiceStatus < Struct.new(
  :status_code,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end