Class: Aws::ECS::Types::FSxWindowsFileServerAuthorizationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::FSxWindowsFileServerAuthorizationConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The authorization configuration details for Amazon FSx for Windows File Server file system. See
- FSxWindowsFileServerVolumeConfiguration][1
-
in the *Amazon ECS API
Reference*.
For more information and the input format, see [Amazon FSx for Windows File Server Volumes] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_FSxWindowsFileServerVolumeConfiguration.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/wfsx-volumes.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credentials_parameter ⇒ String
The authorization credential option to use.
-
#domain ⇒ String
A fully qualified domain name hosted by an [Directory Service] Managed Microsoft AD (Active Directory) or self-hosted AD on Amazon EC2.
Instance Attribute Details
#credentials_parameter ⇒ String
The authorization credential option to use. The authorization credential options can be provided using either the Amazon Resource Name (ARN) of an Secrets Manager secret or SSM Parameter Store parameter. The ARN refers to the stored credentials.
6389 6390 6391 6392 6393 6394 |
# File 'lib/aws-sdk-ecs/types.rb', line 6389 class FSxWindowsFileServerAuthorizationConfig < Struct.new( :credentials_parameter, :domain) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
A fully qualified domain name hosted by an [Directory Service] Managed Microsoft AD (Active Directory) or self-hosted AD on Amazon EC2.
[1]: docs.aws.amazon.com/directoryservice/latest/admin-guide/directory_microsoft_ad.html
6389 6390 6391 6392 6393 6394 |
# File 'lib/aws-sdk-ecs/types.rb', line 6389 class FSxWindowsFileServerAuthorizationConfig < Struct.new( :credentials_parameter, :domain) SENSITIVE = [] include Aws::Structure end |