Class: Aws::ECS::Types::FirelensConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The FireLens configuration for the container. This is used to specify and configure a log router for container logs. For more information, see [Custom log routing] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#optionsHash<String,String>

The options to use when configuring the log router. This field is optional and can be used to specify a custom configuration file or to add additional metadata, such as the task, task definition, cluster, and container instance details to the log event. If specified, the syntax to use is ‘“options”:Aws::ECS::Types::FirelensConfiguration.“enable-ecs-log-metadata”:“true|false”,“config-file-type:”s3|file“,”config-file-value“:”arn:aws:s3:“enable-ecs-log-metadata”:“true|false”,“config-file-type:”s3|file“,”config-file-value“:”arn:aws:s3:::mybucket/fluent“enable-ecs-log-metadata”:“true|false”,“config-file-type:”s3|file“,”config-file-value“:”arn:aws:s3:::mybucket/fluent.conf|filepath“`. For more information, see [Creating a task definition that uses a FireLens configuration] in the *Amazon Elastic Container Service Developer Guide*.

<note markdown=“1”> Tasks hosted on Fargate only support the file configuration file type.

</note>

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html#firelens-taskdef



6498
6499
6500
6501
6502
6503
# File 'lib/aws-sdk-ecs/types.rb', line 6498

class FirelensConfiguration < Struct.new(
  :type,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The log router to use. The valid values are fluentd or fluentbit.



6498
6499
6500
6501
6502
6503
# File 'lib/aws-sdk-ecs/types.rb', line 6498

class FirelensConfiguration < Struct.new(
  :type,
  :options)
  SENSITIVE = []
  include Aws::Structure
end