Class: Aws::ECS::Types::HostVolumeProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::HostVolumeProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Details on a container instance bind mount host volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_path ⇒ String
When the
hostparameter is used, specify asourcePathto declare the path on the host container instance that’s presented to the container.
Instance Attribute Details
#source_path ⇒ String
When the host parameter is used, specify a sourcePath to declare the path on the host container instance that’s presented to the container. If this parameter is empty, then the Docker daemon has assigned a host path for you. If the host parameter contains a sourcePath file location, then the data volume persists at the specified location on the host container instance until you delete it manually. If the sourcePath value doesn’t exist on the host container instance, the Docker daemon creates it. If the location does exist, the contents of the source path folder are exported.
If you’re using the Fargate launch type, the sourcePath parameter is not supported.
6824 6825 6826 6827 6828 |
# File 'lib/aws-sdk-ecs/types.rb', line 6824 class HostVolumeProperties < Struct.new( :source_path) SENSITIVE = [] include Aws::Structure end |