Class: Aws::ECS::Types::InferenceAccelerator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Details on an Elastic Inference accelerator. For more information, see Working with Amazon Elastic Inference on Amazon ECS in the Amazon Elastic Container Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#device_nameString

The Elastic Inference accelerator device name. The deviceName must also be referenced in a container definition as a ResourceRequirement.

Returns:

  • (String)


8483
8484
8485
8486
8487
8488
# File 'lib/aws-sdk-ecs/types.rb', line 8483

class InferenceAccelerator < Struct.new(
  :device_name,
  :device_type)
  SENSITIVE = []
  include Aws::Structure
end

#device_typeString

The Elastic Inference accelerator type to use.

Returns:

  • (String)


8483
8484
8485
8486
8487
8488
# File 'lib/aws-sdk-ecs/types.rb', line 8483

class InferenceAccelerator < Struct.new(
  :device_name,
  :device_type)
  SENSITIVE = []
  include Aws::Structure
end