Class: Aws::ECS::Types::InferenceAcceleratorOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::InferenceAcceleratorOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Details on an Elastic Inference accelerator task override. This parameter is used to override the Elastic Inference accelerator specified in the task definition. For more information, see Working with Amazon Elastic Inference on Amazon ECS in the Amazon Elastic Container Service Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_name ⇒ String
The Elastic Inference accelerator device name to override for the task.
-
#device_type ⇒ String
The Elastic Inference accelerator type to use.
Instance Attribute Details
#device_name ⇒ String
The Elastic Inference accelerator device name to override for the
task. This parameter must match a deviceName specified in the task
definition.
8512 8513 8514 8515 8516 8517 |
# File 'lib/aws-sdk-ecs/types.rb', line 8512 class InferenceAcceleratorOverride < Struct.new( :device_name, :device_type) SENSITIVE = [] include Aws::Structure end |
#device_type ⇒ String
The Elastic Inference accelerator type to use.
8512 8513 8514 8515 8516 8517 |
# File 'lib/aws-sdk-ecs/types.rb', line 8512 class InferenceAcceleratorOverride < Struct.new( :device_name, :device_type) SENSITIVE = [] include Aws::Structure end |