Class: Aws::ECS::Types::InstanceHealthCheckResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

An object representing the result of a container instance health status check.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_status_changeTime

The Unix timestamp for when the container instance health status last changed.



6962
6963
6964
6965
6966
6967
6968
6969
# File 'lib/aws-sdk-ecs/types.rb', line 6962

class InstanceHealthCheckResult < Struct.new(
  :type,
  :status,
  :last_updated,
  :last_status_change)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

The Unix timestamp for when the container instance health status was last updated.



6962
6963
6964
6965
6966
6967
6968
6969
# File 'lib/aws-sdk-ecs/types.rb', line 6962

class InstanceHealthCheckResult < Struct.new(
  :type,
  :status,
  :last_updated,
  :last_status_change)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The container instance health status.



6962
6963
6964
6965
6966
6967
6968
6969
# File 'lib/aws-sdk-ecs/types.rb', line 6962

class InstanceHealthCheckResult < Struct.new(
  :type,
  :status,
  :last_updated,
  :last_status_change)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of container instance health status that was verified.



6962
6963
6964
6965
6966
6967
6968
6969
# File 'lib/aws-sdk-ecs/types.rb', line 6962

class InstanceHealthCheckResult < Struct.new(
  :type,
  :status,
  :last_updated,
  :last_status_change)
  SENSITIVE = []
  include Aws::Structure
end