Class: Aws::ECS::Types::InstanceLaunchTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The launch template configuration for Amazon ECS Managed Instances. This defines how Amazon ECS launches Amazon EC2 instances, including the instance profile for your tasks, network and storage configuration, capacity options, and instance requirements for flexible instance type selection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_option_typeString

The capacity option type. This determines whether Amazon ECS launches On-Demand, Spot or Capacity Reservation Instances for your managed instance capacity provider.

Valid values are:

  • ON_DEMAND - Launches standard On-Demand Instances. On-Demand Instances provide predictable pricing and availability.

  • SPOT - Launches Spot Instances that use spare Amazon EC2 capacity at reduced cost. Spot Instances can be interrupted by Amazon EC2 with a two-minute notification when the capacity is needed back.

  • RESERVED - Launches Instances using Amazon EC2 Capacity Reservations. Capacity Reservations allow you to reserve compute capacity for Amazon EC2 instances in a specific Availability Zone.

The default is On-Demand

For more information about Amazon EC2 capacity options, see

Instance purchasing options][1

in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-purchasing-options.html

Returns:

  • (String)


7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_reservationsTypes::CapacityReservationRequest

Capacity reservation specifications. You can specify:

  • Capacity reservation preference

  • Reservation resource group to be used for targeted capacity reservations

Amazon ECS will launch instances according to the specified criteria.



7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instance_profile_arnString

The Amazon Resource Name (ARN) of the instance profile that Amazon ECS applies to Amazon ECS Managed Instances. This instance profile must include the necessary permissions for your tasks to access Amazon Web Services services and resources.

For more information, see [Amazon ECS instance profile for Managed Instances] in the *Amazon ECS Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/managed-instances-instance-profile.html

Returns:

  • (String)


7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#fips_enabledBoolean

Determines whether to enable FIPS 140-2 validated cryptographic modules on EC2 instances launched by the capacity provider. If true, instances use FIPS-compliant cryptographic algorithms and modules for enhanced security compliance. If false, instances use standard cryptographic implementations.

If not specified, instances are launched with FIPS enabled in AWS GovCloud (US) regions and FIPS disabled in other regions.

Returns:

  • (Boolean)


7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#instance_requirementsTypes::InstanceRequirementsRequest

The instance requirements. You can specify:

  • The instance types

  • Instance requirements such as vCPU count, memory, network performance, and accelerator specifications

Amazon ECS automatically selects the instances that match the specified criteria.



7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#monitoringString

CloudWatch provides two categories of monitoring: basic monitoring and detailed monitoring. By default, your managed instance is configured for basic monitoring. You can optionally enable detailed monitoring to help you more quickly identify and act on operational issues. You can enable or turn off detailed monitoring at launch or when the managed instance is running or stopped. For more information, see [Detailed monitoring for Amazon ECS Managed Instances] in the Amazon ECS Developer Guide.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/detailed-monitoring-managed-instances.html

Returns:

  • (String)


7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::ManagedInstancesNetworkConfiguration

The network configuration for Amazon ECS Managed Instances. This specifies the subnets and security groups that instances use for network connectivity.



7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configurationTypes::ManagedInstancesStorageConfiguration

The storage configuration for Amazon ECS Managed Instances. This defines the root volume size and type for the instances.



7083
7084
7085
7086
7087
7088
7089
7090
7091
7092
7093
7094
# File 'lib/aws-sdk-ecs/types.rb', line 7083

class InstanceLaunchTemplate < Struct.new(
  :ec2_instance_profile_arn,
  :network_configuration,
  :storage_configuration,
  :monitoring,
  :capacity_option_type,
  :instance_requirements,
  :fips_enabled,
  :capacity_reservations)
  SENSITIVE = []
  include Aws::Structure
end