Class: Aws::ECS::Types::LinuxParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass LinuxParameters data as a hash:

{
  capabilities: {
    add: ["String"],
    drop: ["String"],
  },
  devices: [
    {
      host_path: "String", # required
      container_path: "String",
      permissions: ["read"], # accepts read, write, mknod
    },
  ],
  init_process_enabled: false,
  shared_memory_size: 1,
  tmpfs: [
    {
      container_path: "String", # required
      size: 1, # required
      mount_options: ["String"],
    },
  ],
  max_swap: 1,
  swappiness: 1,
}

Linux-specific options that are applied to the container, such as Linux KernelCapabilities.

Instance Attribute Summary collapse

Instance Attribute Details

#capabilitiesTypes::KernelCapabilities

The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.

<note markdown=“1”> If you are using tasks that use the Fargate launch type, capabilities is supported but the add parameter is not supported.

</note>


4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end

#devicesArray<Types::Device>

Any host devices to expose to the container. This parameter maps to Devices in the [Create a container] section of the [Docker Remote API] and the --device option to [docker run].

<note markdown=“1”> If you are using tasks that use the Fargate launch type, the devices parameter is not supported.

</note>

[1]: docs.docker.com/engine/api/v1.35/#operation/ContainerCreate [2]: docs.docker.com/engine/api/v1.35/ [3]: docs.docker.com/engine/reference/run/

Returns:



4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end

#init_process_enabledBoolean

Run an init process inside the container that forwards signals and reaps processes. This parameter maps to the --init option to [docker run]. This parameter requires version 1.25 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ‘sudo docker version –format ’Aws::ECS::Types::LinuxParameters.{{.Server{.Server.APIVersion}‘`

[1]: docs.docker.com/engine/reference/run/

Returns:

  • (Boolean)


4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end

#max_swapInteger

The total amount of swap memory (in MiB) a container can use. This parameter will be translated to the --memory-swap option to

docker run][1

where the value would be the sum of the container

memory plus the maxSwap value.

If a maxSwap value of 0 is specified, the container will not use swap. Accepted values are 0 or any positive integer. If the maxSwap parameter is omitted, the container will use the swap configuration for the container instance it is running on. A maxSwap value must be set for the swappiness parameter to be used.

<note markdown=“1”> If you are using tasks that use the Fargate launch type, the maxSwap parameter is not supported.

</note>

[1]: docs.docker.com/engine/reference/run/

Returns:

  • (Integer)


4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end

#shared_memory_sizeInteger

The value for the size (in MiB) of the /dev/shm volume. This parameter maps to the --shm-size option to [docker run].

<note markdown=“1”> If you are using tasks that use the Fargate launch type, the sharedMemorySize parameter is not supported.

</note>

[1]: docs.docker.com/engine/reference/run/

Returns:

  • (Integer)


4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end

#swappinessInteger

This allows you to tune a container’s memory swappiness behavior. A swappiness value of 0 will cause swapping to not happen unless absolutely necessary. A swappiness value of 100 will cause pages to be swapped very aggressively. Accepted values are whole numbers between 0 and 100. If the swappiness parameter is not specified, a default value of 60 is used. If a value is not specified for maxSwap then this parameter is ignored. This parameter maps to the --memory-swappiness option to [docker run].

<note markdown=“1”> If you are using tasks that use the Fargate launch type, the swappiness parameter is not supported.

</note>

[1]: docs.docker.com/engine/reference/run/

Returns:

  • (Integer)


4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end

#tmpfsArray<Types::Tmpfs>

The container path, mount options, and size (in MiB) of the tmpfs mount. This parameter maps to the --tmpfs option to [docker run].

<note markdown=“1”> If you are using tasks that use the Fargate launch type, the tmpfs parameter is not supported.

</note>

[1]: docs.docker.com/engine/reference/run/

Returns:



4681
4682
4683
4684
4685
4686
4687
4688
4689
4690
# File 'lib/aws-sdk-ecs/types.rb', line 4681

class LinuxParameters < Struct.new(
  :capabilities,
  :devices,
  :init_process_enabled,
  :shared_memory_size,
  :tmpfs,
  :max_swap,
  :swappiness)
  include Aws::Structure
end