Class: Aws::ECS::Types::ListAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The name of the attribute to filter the results with.
-
#attribute_value ⇒ String
The value of the attribute to filter results with.
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster to list attributes.
-
#max_results ⇒ Integer
The maximum number of cluster results that
ListAttributesreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListAttributesrequest indicating that more results are available to fulfill the request and further calls are needed. -
#target_type ⇒ String
The type of the target to list attributes with.
Instance Attribute Details
#attribute_name ⇒ String
The name of the attribute to filter the results with.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-ecs/types.rb', line 7763 class ListAttributesRequest < Struct.new( :cluster, :target_type, :attribute_name, :attribute_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#attribute_value ⇒ String
The value of the attribute to filter results with. You must also specify an attribute name to use this parameter.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-ecs/types.rb', line 7763 class ListAttributesRequest < Struct.new( :cluster, :target_type, :attribute_name, :attribute_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster to list attributes. If you do not specify a cluster, the default cluster is assumed.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-ecs/types.rb', line 7763 class ListAttributesRequest < Struct.new( :cluster, :target_type, :attribute_name, :attribute_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of cluster results that ListAttributes returned in paginated output. When this parameter is used, ListAttributes only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListAttributes request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then ListAttributes returns up to 100 results and a nextToken value if applicable.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-ecs/types.rb', line 7763 class ListAttributesRequest < Struct.new( :cluster, :target_type, :attribute_name, :attribute_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListAttributes request indicating that more results are available to fulfill the request and further calls are needed. If maxResults was provided, it’s possible the number of results to be fewer than maxResults.
<note markdown=“1”> This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-ecs/types.rb', line 7763 class ListAttributesRequest < Struct.new( :cluster, :target_type, :attribute_name, :attribute_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The type of the target to list attributes with.
7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 |
# File 'lib/aws-sdk-ecs/types.rb', line 7763 class ListAttributesRequest < Struct.new( :cluster, :target_type, :attribute_name, :attribute_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |