Class: Aws::ECS::Types::ListAttributesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListAttributesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Types::Attribute>
A list of attribute objects that meet the criteria of the request.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListAttributesrequest.
Instance Attribute Details
#attributes ⇒ Array<Types::Attribute>
A list of attribute objects that meet the criteria of the request.
7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-ecs/types.rb', line 7792 class ListAttributesResponse < Struct.new( :attributes, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future ListAttributes request. When the results of a ListAttributes request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
7792 7793 7794 7795 7796 7797 |
# File 'lib/aws-sdk-ecs/types.rb', line 7792 class ListAttributesResponse < Struct.new( :attributes, :next_token) SENSITIVE = [] include Aws::Structure end |