Class: Aws::ECS::Types::ListClustersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListClustersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of cluster results that
ListClustersreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListClustersrequest indicating that more results are available to fulfill the request and further calls are needed.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of cluster results that ListClusters returned
in paginated output. When this parameter is used, ListClusters
only returns maxResults results in a single page along with a
nextToken response element. The remaining results of the initial
request can be seen by sending another ListClusters request with
the returned nextToken value. This value can be between 1 and 100.
If this parameter isn't used, then ListClusters returns up to 100
results and a nextToken value if applicable.
9705 9706 9707 9708 9709 9710 |
# File 'lib/aws-sdk-ecs/types.rb', line 9705 class ListClustersRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListClusters request
indicating that more results are available to fulfill the request
and further calls are needed. If maxResults was provided, it's
possible the number of results to be fewer than maxResults.
9705 9706 9707 9708 9709 9710 |
# File 'lib/aws-sdk-ecs/types.rb', line 9705 class ListClustersRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |