Class: Aws::ECS::Types::ListContainerInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListContainerInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the container instances to list.
-
#filter ⇒ String
You can filter the results of a
ListContainerInstancesoperation with cluster query language statements. -
#max_results ⇒ Integer
The maximum number of container instance results that
ListContainerInstancesreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListContainerInstancesrequest indicating that more results are available to fulfill the request and further calls are needed. -
#status ⇒ String
Filters the container instances by status.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the container instances to list. If you do not specify a cluster, the default cluster is assumed.
9798 9799 9800 9801 9802 9803 9804 9805 9806 |
# File 'lib/aws-sdk-ecs/types.rb', line 9798 class ListContainerInstancesRequest < Struct.new( :cluster, :filter, :next_token, :max_results, :status) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ String
You can filter the results of a ListContainerInstances operation
with cluster query language statements. For more information, see
Cluster Query Language in the Amazon Elastic Container Service
Developer Guide.
9798 9799 9800 9801 9802 9803 9804 9805 9806 |
# File 'lib/aws-sdk-ecs/types.rb', line 9798 class ListContainerInstancesRequest < Struct.new( :cluster, :filter, :next_token, :max_results, :status) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of container instance results that
ListContainerInstances returned in paginated output. When this
parameter is used, ListContainerInstances only returns
maxResults results in a single page along with a nextToken
response element. The remaining results of the initial request can
be seen by sending another ListContainerInstances request with the
returned nextToken value. This value can be between 1 and 100. If
this parameter isn't used, then ListContainerInstances returns up
to 100 results and a nextToken value if applicable.
9798 9799 9800 9801 9802 9803 9804 9805 9806 |
# File 'lib/aws-sdk-ecs/types.rb', line 9798 class ListContainerInstancesRequest < Struct.new( :cluster, :filter, :next_token, :max_results, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListContainerInstances
request indicating that more results are available to fulfill the
request and further calls are needed. If maxResults was provided,
it's possible the number of results to be fewer than maxResults.
9798 9799 9800 9801 9802 9803 9804 9805 9806 |
# File 'lib/aws-sdk-ecs/types.rb', line 9798 class ListContainerInstancesRequest < Struct.new( :cluster, :filter, :next_token, :max_results, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filters the container instances by status. For example, if you
specify the DRAINING status, the results include only container
instances that have been set to DRAINING using
UpdateContainerInstancesState. If you don't specify this
parameter, the The default is to include container instances set to
all states other than INACTIVE.
9798 9799 9800 9801 9802 9803 9804 9805 9806 |
# File 'lib/aws-sdk-ecs/types.rb', line 9798 class ListContainerInstancesRequest < Struct.new( :cluster, :filter, :next_token, :max_results, :status) SENSITIVE = [] include Aws::Structure end |