Class: Aws::ECS::Types::ListContainerInstancesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListContainerInstancesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_instance_arns ⇒ Array<String>
The list of container instances with full ARN entries for each container instance associated with the specified cluster.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListContainerInstancesrequest.
Instance Attribute Details
#container_instance_arns ⇒ Array<String>
The list of container instances with full ARN entries for each container instance associated with the specified cluster.
9827 9828 9829 9830 9831 9832 |
# File 'lib/aws-sdk-ecs/types.rb', line 9827 class ListContainerInstancesResponse < Struct.new( :container_instance_arns, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future
ListContainerInstances request. When the results of a
ListContainerInstances request exceed maxResults, this value can
be used to retrieve the next page of results. This value is null
when there are no more results to return.
9827 9828 9829 9830 9831 9832 |
# File 'lib/aws-sdk-ecs/types.rb', line 9827 class ListContainerInstancesResponse < Struct.new( :container_instance_arns, :next_token) SENSITIVE = [] include Aws::Structure end |