Class: Aws::ECS::Types::ListDaemonDeploymentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTypes::CreatedAt

An optional filter to narrow the ListDaemonDeployments results by creation time. If you don't specify a time range, all deployments are returned.

Returns:



9879
9880
9881
9882
9883
9884
9885
9886
9887
# File 'lib/aws-sdk-ecs/types.rb', line 9879

class ListDaemonDeploymentsRequest < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_arnString

The Amazon Resource Name (ARN) of the daemon to list deployments for.

Returns:

  • (String)


9879
9880
9881
9882
9883
9884
9885
9886
9887
# File 'lib/aws-sdk-ecs/types.rb', line 9879

class ListDaemonDeploymentsRequest < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of daemon deployment results that ListDaemonDeployments returned in paginated output. When this parameter is used, ListDaemonDeployments only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListDaemonDeployments request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then ListDaemonDeployments returns up to 20 results and a nextToken value if applicable.

Returns:

  • (Integer)


9879
9880
9881
9882
9883
9884
9885
9886
9887
# File 'lib/aws-sdk-ecs/types.rb', line 9879

class ListDaemonDeploymentsRequest < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a ListDaemonDeployments request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it's possible for the number of results to be fewer than maxResults.

This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


9879
9880
9881
9882
9883
9884
9885
9886
9887
# File 'lib/aws-sdk-ecs/types.rb', line 9879

class ListDaemonDeploymentsRequest < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusArray<String>

An optional filter to narrow the ListDaemonDeployments results by deployment status. If you don't specify a status, all deployments are returned.

Returns:

  • (Array<String>)


9879
9880
9881
9882
9883
9884
9885
9886
9887
# File 'lib/aws-sdk-ecs/types.rb', line 9879

class ListDaemonDeploymentsRequest < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end