Class: Aws::ECS::Types::ListDaemonsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_provider_arnsArray<String>

The Amazon Resource Names (ARNs) of the capacity providers to filter daemons by. Only daemons associated with the specified capacity providers are returned.

Returns:

  • (Array<String>)


10040
10041
10042
10043
10044
10045
10046
10047
# File 'lib/aws-sdk-ecs/types.rb', line 10040

class ListDaemonsRequest < Struct.new(
  :cluster_arn,
  :capacity_provider_arns,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) of the cluster to filter daemons by. If you do not specify a cluster, the default cluster is assumed.

Returns:

  • (String)


10040
10041
10042
10043
10044
10045
10046
10047
# File 'lib/aws-sdk-ecs/types.rb', line 10040

class ListDaemonsRequest < Struct.new(
  :cluster_arn,
  :capacity_provider_arns,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of daemon results that ListDaemons returned in paginated output. When this parameter is used, ListDaemons only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListDaemons request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn't used, then ListDaemons returns up to 100 results and a nextToken value if applicable.

Returns:

  • (Integer)


10040
10041
10042
10043
10044
10045
10046
10047
# File 'lib/aws-sdk-ecs/types.rb', line 10040

class ListDaemonsRequest < Struct.new(
  :cluster_arn,
  :capacity_provider_arns,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a ListDaemons request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it's possible for the number of results to be fewer than maxResults.

This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


10040
10041
10042
10043
10044
10045
10046
10047
# File 'lib/aws-sdk-ecs/types.rb', line 10040

class ListDaemonsRequest < Struct.new(
  :cluster_arn,
  :capacity_provider_arns,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end