Class: Aws::ECS::Types::ListServiceDeploymentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListServiceDeploymentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListServiceDeploymentsrequest. -
#service_deployments ⇒ Array<Types::ServiceDeploymentBrief>
An overview of the service deployment, including the following properties:.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future
ListServiceDeployments request. When the results of a
ListServiceDeployments request exceed maxResults, this value can
be used to retrieve the next page of results. This value is null
when there are no more results to return.
10158 10159 10160 10161 10162 10163 |
# File 'lib/aws-sdk-ecs/types.rb', line 10158 class ListServiceDeploymentsResponse < Struct.new( :service_deployments, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_deployments ⇒ Array<Types::ServiceDeploymentBrief>
An overview of the service deployment, including the following properties:
-
The ARN of the service deployment.
-
The ARN of the service being deployed.
-
The ARN of the cluster that hosts the service in the service deployment.
-
The time that the service deployment started.
-
The time that the service deployment completed.
-
The service deployment status.
-
Information about why the service deployment is in the current state.
-
The ARN of the service revision that is being deployed.
10158 10159 10160 10161 10162 10163 |
# File 'lib/aws-sdk-ecs/types.rb', line 10158 class ListServiceDeploymentsResponse < Struct.new( :service_deployments, :next_token) SENSITIVE = [] include Aws::Structure end |