Class: Aws::ECS::Types::ListServicesByNamespaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The nextToken value to include in a future ListServicesByNamespace request. When the results of a ListServicesByNamespace request exceed maxResults, this value can be used to retrieve the next page of results. When there are no more results to return, this value is null.



8162
8163
8164
8165
8166
8167
# File 'lib/aws-sdk-ecs/types.rb', line 8162

class ListServicesByNamespaceResponse < Struct.new(
  :service_arns,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnsArray<String>

The list of full ARN entries for each service that’s associated with the specified namespace.



8162
8163
8164
8165
8166
8167
# File 'lib/aws-sdk-ecs/types.rb', line 8162

class ListServicesByNamespaceResponse < Struct.new(
  :service_arns,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end