Class: Aws::ECS::Types::ListServicesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListServicesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster to use when filtering the
ListServicesresults. -
#launch_type ⇒ String
The launch type to use when filtering the
ListServicesresults. -
#max_results ⇒ Integer
The maximum number of service results that
ListServicesreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListServicesrequest indicating that more results are available to fulfill the request and further calls will be needed. -
#resource_management_type ⇒ String
The resourceManagementType type to use when filtering the
ListServicesresults. -
#scheduling_strategy ⇒ String
The scheduling strategy to use when filtering the
ListServicesresults.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster to
use when filtering the ListServices results. If you do not specify
a cluster, the default cluster is assumed.
9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 |
# File 'lib/aws-sdk-ecs/types.rb', line 9819 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#launch_type ⇒ String
The launch type to use when filtering the ListServices results.
9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 |
# File 'lib/aws-sdk-ecs/types.rb', line 9819 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of service results that ListServices returned
in paginated output. When this parameter is used, ListServices
only returns maxResults results in a single page along with a
nextToken response element. The remaining results of the initial
request can be seen by sending another ListServices request with
the returned nextToken value. This value can be between 1 and 100.
If this parameter isn't used, then ListServices returns up to 10
results and a nextToken value if applicable.
9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 |
# File 'lib/aws-sdk-ecs/types.rb', line 9819 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListServices request
indicating that more results are available to fulfill the request
and further calls will be needed. If maxResults was provided, it
is possible the number of results to be fewer than maxResults.
9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 |
# File 'lib/aws-sdk-ecs/types.rb', line 9819 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#resource_management_type ⇒ String
The resourceManagementType type to use when filtering the
ListServices results.
9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 |
# File 'lib/aws-sdk-ecs/types.rb', line 9819 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#scheduling_strategy ⇒ String
The scheduling strategy to use when filtering the ListServices
results.
9819 9820 9821 9822 9823 9824 9825 9826 9827 9828 |
# File 'lib/aws-sdk-ecs/types.rb', line 9819 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |