Class: Aws::ECS::Types::ListTaskDefinitionFamiliesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListTaskDefinitionFamiliesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#family_prefix ⇒ String
The
familyPrefixis a string that's used to filter the results ofListTaskDefinitionFamilies. -
#max_results ⇒ Integer
The maximum number of task definition family results that
ListTaskDefinitionFamiliesreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListTaskDefinitionFamiliesrequest indicating that more results are available to fulfill the request and further calls will be needed. -
#status ⇒ String
The task definition family status to filter the
ListTaskDefinitionFamiliesresults with.
Instance Attribute Details
#family_prefix ⇒ String
The familyPrefix is a string that's used to filter the results of
ListTaskDefinitionFamilies. If you specify a familyPrefix, only
task definition family names that begin with the familyPrefix
string are returned.
10399 10400 10401 10402 10403 10404 10405 10406 |
# File 'lib/aws-sdk-ecs/types.rb', line 10399 class ListTaskDefinitionFamiliesRequest < Struct.new( :family_prefix, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of task definition family results that
ListTaskDefinitionFamilies returned in paginated output. When this
parameter is used, ListTaskDefinitions only returns maxResults
results in a single page along with a nextToken response element.
The remaining results of the initial request can be seen by sending
another ListTaskDefinitionFamilies request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListTaskDefinitionFamilies returns up
to 100 results and a nextToken value if applicable.
10399 10400 10401 10402 10403 10404 10405 10406 |
# File 'lib/aws-sdk-ecs/types.rb', line 10399 class ListTaskDefinitionFamiliesRequest < Struct.new( :family_prefix, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListTaskDefinitionFamilies
request indicating that more results are available to fulfill the
request and further calls will be needed. If maxResults was
provided, it is possible the number of results to be fewer than
maxResults.
10399 10400 10401 10402 10403 10404 10405 10406 |
# File 'lib/aws-sdk-ecs/types.rb', line 10399 class ListTaskDefinitionFamiliesRequest < Struct.new( :family_prefix, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The task definition family status to filter the
ListTaskDefinitionFamilies results with. By default, both ACTIVE
and INACTIVE task definition families are listed. If this
parameter is set to ACTIVE, only task definition families that
have an ACTIVE task definition revision are returned. If this
parameter is set to INACTIVE, only task definition families that
do not have any ACTIVE task definition revisions are returned. If
you paginate the resulting output, be sure to keep the status
value constant in each subsequent request.
10399 10400 10401 10402 10403 10404 10405 10406 |
# File 'lib/aws-sdk-ecs/types.rb', line 10399 class ListTaskDefinitionFamiliesRequest < Struct.new( :family_prefix, :status, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |