Class: Aws::ECS::Types::ListTaskDefinitionFamiliesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListTaskDefinitionFamiliesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#families ⇒ Array<String>
The list of task definition family names that match the
ListTaskDefinitionFamiliesrequest. -
#next_token ⇒ String
The
nextTokenvalue to include in a futureListTaskDefinitionFamiliesrequest.
Instance Attribute Details
#families ⇒ Array<String>
The list of task definition family names that match the
ListTaskDefinitionFamilies request.
10427 10428 10429 10430 10431 10432 |
# File 'lib/aws-sdk-ecs/types.rb', line 10427 class ListTaskDefinitionFamiliesResponse < Struct.new( :families, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future
ListTaskDefinitionFamilies request. When the results of a
ListTaskDefinitionFamilies request exceed maxResults, this value
can be used to retrieve the next page of results. This value is
null when there are no more results to return.
10427 10428 10429 10430 10431 10432 |
# File 'lib/aws-sdk-ecs/types.rb', line 10427 class ListTaskDefinitionFamiliesResponse < Struct.new( :families, :next_token) SENSITIVE = [] include Aws::Structure end |