Class: Aws::ECS::Types::ListTaskDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListTaskDefinitionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#family_prefix ⇒ String
The full family name to filter the
ListTaskDefinitionsresults with. -
#max_results ⇒ Integer
The maximum number of task definition results that
ListTaskDefinitionsreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListTaskDefinitionsrequest indicating that more results are available to fulfill the request and further calls will be needed. -
#sort ⇒ String
The order to sort the results in.
-
#status ⇒ String
The task definition status to filter the
ListTaskDefinitionsresults with.
Instance Attribute Details
#family_prefix ⇒ String
The full family name to filter the ListTaskDefinitions results
with. Specifying a familyPrefix limits the listed task definitions
to task definition revisions that belong to that family.
10490 10491 10492 10493 10494 10495 10496 10497 10498 |
# File 'lib/aws-sdk-ecs/types.rb', line 10490 class ListTaskDefinitionsRequest < Struct.new( :family_prefix, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of task definition results that
ListTaskDefinitions returned in paginated output. When this
parameter is used, ListTaskDefinitions only returns maxResults
results in a single page along with a nextToken response element.
The remaining results of the initial request can be seen by sending
another ListTaskDefinitions request with the returned nextToken
value. This value can be between 1 and 100. If this parameter isn't
used, then ListTaskDefinitions returns up to 100 results and a
nextToken value if applicable.
10490 10491 10492 10493 10494 10495 10496 10497 10498 |
# File 'lib/aws-sdk-ecs/types.rb', line 10490 class ListTaskDefinitionsRequest < Struct.new( :family_prefix, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListTaskDefinitions request
indicating that more results are available to fulfill the request
and further calls will be needed. If maxResults was provided, it
is possible the number of results to be fewer than maxResults.
10490 10491 10492 10493 10494 10495 10496 10497 10498 |
# File 'lib/aws-sdk-ecs/types.rb', line 10490 class ListTaskDefinitionsRequest < Struct.new( :family_prefix, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ String
The order to sort the results in. Valid values are ASC and DESC.
By default, (ASC) task definitions are listed lexicographically by
family name and in ascending numerical order by revision so that the
newest task definitions in a family are listed last. Setting this
parameter to DESC reverses the sort order on family name and
revision. This is so that the newest task definitions in a family
are listed first.
10490 10491 10492 10493 10494 10495 10496 10497 10498 |
# File 'lib/aws-sdk-ecs/types.rb', line 10490 class ListTaskDefinitionsRequest < Struct.new( :family_prefix, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The task definition status to filter the ListTaskDefinitions
results with. By default, only ACTIVE task definitions are listed.
By setting this parameter to INACTIVE, you can view task
definitions that are INACTIVE as long as an active task or service
still references them. If you paginate the resulting output, be sure
to keep the status value constant in each subsequent request.
10490 10491 10492 10493 10494 10495 10496 10497 10498 |
# File 'lib/aws-sdk-ecs/types.rb', line 10490 class ListTaskDefinitionsRequest < Struct.new( :family_prefix, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |