Class: Aws::ECS::Types::ListTasksResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListTasksResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListTasksrequest. -
#task_arns ⇒ Array<String>
The list of task ARN entries for the
ListTasksrequest.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future ListTasks request. When the results of a ListTasks request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
8532 8533 8534 8535 8536 8537 |
# File 'lib/aws-sdk-ecs/types.rb', line 8532 class ListTasksResponse < Struct.new( :task_arns, :next_token) SENSITIVE = [] include Aws::Structure end |
#task_arns ⇒ Array<String>
The list of task ARN entries for the ListTasks request.
8532 8533 8534 8535 8536 8537 |
# File 'lib/aws-sdk-ecs/types.rb', line 8532 class ListTasksResponse < Struct.new( :task_arns, :next_token) SENSITIVE = [] include Aws::Structure end |