Class: Aws::ECS::Types::LoadBalancer
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::LoadBalancer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass LoadBalancer data as a hash:
{
target_group_arn: "String",
load_balancer_name: "String",
container_name: "String",
container_port: 1,
}
Details on the load balancer or load balancers to use with a service or task set.
Instance Attribute Summary collapse
-
#container_name ⇒ String
The name of the container (as it appears in a container definition) to associate with the load balancer.
-
#container_port ⇒ Integer
The port on the container to associate with the load balancer.
-
#load_balancer_name ⇒ String
The name of the load balancer to associate with the Amazon ECS service or task set.
-
#target_group_arn ⇒ String
The full Amazon Resource Name (ARN) of the Elastic Load Balancing target group or groups associated with a service or task set.
Instance Attribute Details
#container_name ⇒ String
The name of the container (as it appears in a container definition) to associate with the load balancer.
5511 5512 5513 5514 5515 5516 5517 |
# File 'lib/aws-sdk-ecs/types.rb', line 5511 class LoadBalancer < Struct.new( :target_group_arn, :load_balancer_name, :container_name, :container_port) include Aws::Structure end |
#container_port ⇒ Integer
The port on the container to associate with the load balancer. This port must correspond to a containerPort in the task definition the tasks in the service are using. For tasks that use the EC2 launch type, the container instance they are launched on must allow ingress traffic on the hostPort of the port mapping.
5511 5512 5513 5514 5515 5516 5517 |
# File 'lib/aws-sdk-ecs/types.rb', line 5511 class LoadBalancer < Struct.new( :target_group_arn, :load_balancer_name, :container_name, :container_port) include Aws::Structure end |
#load_balancer_name ⇒ String
The name of the load balancer to associate with the Amazon ECS service or task set.
A load balancer name is only specified when using a Classic Load Balancer. If you are using an Application Load Balancer or a Network Load Balancer this should be omitted.
5511 5512 5513 5514 5515 5516 5517 |
# File 'lib/aws-sdk-ecs/types.rb', line 5511 class LoadBalancer < Struct.new( :target_group_arn, :load_balancer_name, :container_name, :container_port) include Aws::Structure end |
#target_group_arn ⇒ String
The full Amazon Resource Name (ARN) of the Elastic Load Balancing target group or groups associated with a service or task set.
A target group ARN is only specified when using an Application Load Balancer or Network Load Balancer. If you are using a Classic Load Balancer this should be omitted.
For services using the ECS deployment controller, you can specify one or multiple target groups. For more information, see
- Registering Multiple Target Groups with a Service][1
-
in the
*Amazon Elastic Container Service Developer Guide*.
For services using the CODE_DEPLOY deployment controller, you are required to define two target groups for the load balancer. For more information, see [Blue/Green Deployment with CodeDeploy] in the *Amazon Elastic Container Service Developer Guide*.
If your service’s task definition uses the awsvpc network mode (which is required for the Fargate launch type), you must choose ip as the target type, not instance, when creating your target groups because tasks that use the awsvpc network mode are associated with an elastic network interface, not an Amazon EC2 instance.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/register-multiple-targetgroups.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-bluegreen.html
5511 5512 5513 5514 5515 5516 5517 |
# File 'lib/aws-sdk-ecs/types.rb', line 5511 class LoadBalancer < Struct.new( :target_group_arn, :load_balancer_name, :container_name, :container_port) include Aws::Structure end |