Class: Aws::ECS::Types::LogConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::LogConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass LogConfiguration data as a hash:
{
log_driver: "json-file", # required, accepts json-file, syslog, journald, gelf, fluentd, awslogs, splunk, awsfirelens
options: {
"String" => "String",
},
secret_options: [
{
name: "String", # required
value_from: "String", # required
},
],
}
The log configuration specification for the container.
This parameter maps to LogConfig in the [Create a container] section of the [Docker Remote API] and the --log-driver option to [ ‘docker run` ][3]. By default, containers use the same logging driver that the Docker daemon uses; however the container may use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance (or on a different log server for remote logging options). For more information on the options for different supported log drivers, see [Configure logging drivers] in the Docker documentation.
The following should be noted when specifying a log configuration for your containers:
-
Amazon ECS currently supports a subset of the logging drivers available to the Docker daemon (shown in the valid values below). Additional log drivers may be available in future releases of the Amazon ECS container agent.
-
This parameter requires version 1.18 of the Docker Remote API or greater on your container instance.
-
For tasks using the EC2 launch type, the Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the
ECS_AVAILABLE_LOGGING_DRIVERSenvironment variable before containers placed on that instance can use these log configuration options. For more information, see- Amazon ECS Container Agent Configuration][5
-
in the *Amazon Elastic
Container Service Developer Guide*.
-
For tasks using the Fargate launch type, because you do not have access to the underlying infrastructure your tasks are hosted on, any additional software needed will have to be installed outside of the task. For example, the Fluentd output aggregators or a remote host running Logstash to send Gelf logs to.
[1]: docs.docker.com/engine/api/v1.35/#operation/ContainerCreate [2]: docs.docker.com/engine/api/v1.35/ [3]: docs.docker.com/engine/reference/commandline/run/ [4]: docs.docker.com/engine/admin/logging/overview/ [5]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html
Instance Attribute Summary collapse
-
#log_driver ⇒ String
The log driver to use for the container.
-
#options ⇒ Hash<String,String>
The configuration options to send to the log driver.
-
#secret_options ⇒ Array<Types::Secret>
The secrets to pass to the log configuration.
Instance Attribute Details
#log_driver ⇒ String
The log driver to use for the container. The valid values listed earlier are log drivers that the Amazon ECS container agent can communicate with by default.
For tasks using the Fargate launch type, the supported log drivers are awslogs, splunk, and awsfirelens.
For tasks using the EC2 launch type, the supported log drivers are awslogs, fluentd, gelf, json-file, journald, logentries,syslog, splunk, and awsfirelens.
For more information about using the awslogs log driver, see
- Using the awslogs Log Driver][1
-
in the *Amazon Elastic Container
Service Developer Guide*.
For more information about using the awsfirelens log driver, see
- Custom Log Routing][2
-
in the *Amazon Elastic Container Service
Developer Guide*.
<note markdown=“1”> If you have a custom driver that is not listed, you can fork the Amazon ECS container agent project that is [available on GitHub] and customize it to work with that driver. We encourage you to submit pull requests for changes that you would like to have included. However, we do not currently provide support for running modified copies of this software.
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using_awslogs.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html [3]: github.com/aws/amazon-ecs-agent
5639 5640 5641 5642 5643 5644 |
# File 'lib/aws-sdk-ecs/types.rb', line 5639 class LogConfiguration < Struct.new( :log_driver, :options, :secret_options) include Aws::Structure end |
#options ⇒ Hash<String,String>
The configuration options to send to the log driver. This parameter requires version 1.19 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ‘sudo docker version –format ’Aws::ECS::Types::LogConfiguration.{{.Server{.Server.APIVersion}‘`
5639 5640 5641 5642 5643 5644 |
# File 'lib/aws-sdk-ecs/types.rb', line 5639 class LogConfiguration < Struct.new( :log_driver, :options, :secret_options) include Aws::Structure end |
#secret_options ⇒ Array<Types::Secret>
The secrets to pass to the log configuration. For more information, see [Specifying Sensitive Data] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html
5639 5640 5641 5642 5643 5644 |
# File 'lib/aws-sdk-ecs/types.rb', line 5639 class LogConfiguration < Struct.new( :log_driver, :options, :secret_options) include Aws::Structure end |