Class: Aws::ECS::Types::ManagedApplicationAutoScalingPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ManagedApplicationAutoScalingPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The Application Auto Scaling policy created by Amazon ECS when you create an Express service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the Application Auto Scaling policy associated with the Express service.
-
#metric ⇒ String
The metric used for auto scaling decisions.
-
#policy_type ⇒ String
The type of Application Auto Scaling policy associated with the Express service.
-
#status ⇒ String
The status of Application Auto Scaling policy creation.
-
#status_reason ⇒ String
Information about why the Application Auto Scaling policy is in the current status.
-
#target_value ⇒ Float
The target value for the auto scaling metric.
-
#updated_at ⇒ Time
The Unix timestamp for when the Application Auto Scaling policy was last updated.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the Application Auto Scaling policy associated with the Express service.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
The metric used for auto scaling decisions. The available metrics are ECSServiceAverageCPUUtilization, ECSServiceAverageMemoryUtilization, and ALBRequestCOuntPerTarget.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |
#policy_type ⇒ String
The type of Application Auto Scaling policy associated with the Express service. Valid values are TargetTrackingScaling, StepScaling, and PredictiveScaling.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of Application Auto Scaling policy creation.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Information about why the Application Auto Scaling policy is in the current status.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |
#target_value ⇒ Float
The target value for the auto scaling metric.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The Unix timestamp for when the Application Auto Scaling policy was last updated.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/aws-sdk-ecs/types.rb', line 9092 class ManagedApplicationAutoScalingPolicy < Struct.new( :arn, :status, :status_reason, :updated_at, :policy_type, :target_value, :metric) SENSITIVE = [] include Aws::Structure end |