Class: Aws::ECS::Types::ManagedInstancesNetworkConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ManagedInstancesNetworkConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The network configuration for Amazon ECS Managed Instances. This specifies the VPC subnets and security groups that instances use for network connectivity. Amazon ECS Managed Instances support multiple network modes including awsvpc (instances receive ENIs for task isolation), host (instances share network namespace with tasks), and none (no external network connectivity), ensuring backward compatibility for migrating workloads from Fargate or Amazon EC2.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_groups ⇒ Array<String>
The list of security group IDs to apply to Amazon ECS Managed Instances.
-
#subnets ⇒ Array<String>
The list of subnet IDs where Amazon ECS can launch Amazon ECS Managed Instances.
Instance Attribute Details
#security_groups ⇒ Array<String>
The list of security group IDs to apply to Amazon ECS Managed Instances. These security groups control the network traffic allowed to and from the instances.
9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-ecs/types.rb', line 9127 class ManagedInstancesNetworkConfiguration < Struct.new( :subnets, :security_groups) SENSITIVE = [] include Aws::Structure end |
#subnets ⇒ Array<String>
The list of subnet IDs where Amazon ECS can launch Amazon ECS Managed Instances. Instances are distributed across the specified subnets for high availability. All subnets must be in the same VPC.
9127 9128 9129 9130 9131 9132 |
# File 'lib/aws-sdk-ecs/types.rb', line 9127 class ManagedInstancesNetworkConfiguration < Struct.new( :subnets, :security_groups) SENSITIVE = [] include Aws::Structure end |