Class: Aws::ECS::Types::ManagedLoadBalancer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The Application Load Balancer associated with the Express service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the load balancer.

Returns:

  • (String)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#schemeString

The scheme of the load balancer. By default, the scheme of the load balancer is internet-facing.

Returns:

  • (String)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The IDs of the security groups associated with the load balancer.

Returns:

  • (Array<String>)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the load balancer.

Returns:

  • (String)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the load balancer is in the current status.

Returns:

  • (String)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The IDs of the subnets associated with the load balancer.

Returns:

  • (Array<String>)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for when this load balancer was most recently updated.

Returns:

  • (Time)


9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
# File 'lib/aws-sdk-ecs/types.rb', line 9308

class ManagedLoadBalancer < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :scheme,
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end