Class: Aws::ECS::Types::ManagedLogGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The Cloudwatch Log Group created by Amazon ECS for an Express service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the Cloudwatch Log Group associated with the Express service.



9451
9452
9453
9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-ecs/types.rb', line 9451

class ManagedLogGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the Cloudwatch Log Group associated with the Express service.



9451
9452
9453
9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-ecs/types.rb', line 9451

class ManagedLogGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Cloudwatch LogGroup.



9451
9452
9453
9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-ecs/types.rb', line 9451

class ManagedLogGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the Cloudwatch LogGroup is in the current status.



9451
9452
9453
9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-ecs/types.rb', line 9451

class ManagedLogGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for when the Cloudwatch LogGroup was last updated



9451
9452
9453
9454
9455
9456
9457
9458
9459
# File 'lib/aws-sdk-ecs/types.rb', line 9451

class ManagedLogGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end