Class: Aws::ECS::Types::MetricConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::MetricConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The configuration for a specific set of metrics to collect for a service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_names ⇒ Array<String>
The list of metric names to configure.
-
#resolution_seconds ⇒ Integer
The resolution, in seconds, at which to collect the metrics.
Instance Attribute Details
#metric_names ⇒ Array<String>
The list of metric names to configure. The supported metric names
are CPUUtilization and MemoryUtilization.
11720 11721 11722 11723 11724 11725 |
# File 'lib/aws-sdk-ecs/types.rb', line 11720 class MetricConfiguration < Struct.new( :metric_names, :resolution_seconds) SENSITIVE = [] include Aws::Structure end |
#resolution_seconds ⇒ Integer
The resolution, in seconds, at which to collect the metrics. The
valid values are 20 and 60.
11720 11721 11722 11723 11724 11725 |
# File 'lib/aws-sdk-ecs/types.rb', line 11720 class MetricConfiguration < Struct.new( :metric_names, :resolution_seconds) SENSITIVE = [] include Aws::Structure end |