Class: Aws::ECS::Types::MissingVersionException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::MissingVersionException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Amazon ECS can't determine the current version of the Amazon ECS container agent on the container instance and doesn't have enough information to proceed with an update. This could be because the agent running on the container instance is a previous or custom version that doesn't use our version information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Message that describes the cause of the exception.
Instance Attribute Details
#message ⇒ String
Message that describes the cause of the exception.
11739 11740 11741 11742 11743 |
# File 'lib/aws-sdk-ecs/types.rb', line 11739 class MissingVersionException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |