Class: Aws::ECS::Types::PlatformDevice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The devices that are available on the container instance. The supported device types are GPUs and Neuron devices.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The ID for the GPU or Neuron device on the container instance. For GPUs, the available GPU IDs can also be obtained on the container instance in the /var/lib/ecs/gpu/nvidia_gpu_info.json file. For Neuron devices, the ID corresponds to the device index (for example, 0 for /dev/neuron0).

Returns:

  • (String)


12115
12116
12117
12118
12119
12120
# File 'lib/aws-sdk-ecs/types.rb', line 12115

class PlatformDevice < Struct.new(
  :id,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of device that's available on the container instance. The supported values are GPU and NEURON_DEVICE.

Returns:

  • (String)


12115
12116
12117
12118
12119
12120
# File 'lib/aws-sdk-ecs/types.rb', line 12115

class PlatformDevice < Struct.new(
  :id,
  :type)
  SENSITIVE = []
  include Aws::Structure
end