Class: Aws::ECS::Types::PutAccountSettingDefaultRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass PutAccountSettingDefaultRequest data as a hash:

{
  name: "serviceLongArnFormat", # required, accepts serviceLongArnFormat, taskLongArnFormat, containerInstanceLongArnFormat, awsvpcTrunking, containerInsights
  value: "String", # required
}

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The resource name for which to modify the account setting. If serviceLongArnFormat is specified, the ARN for your Amazon ECS services is affected. If taskLongArnFormat is specified, the ARN and resource ID for your Amazon ECS tasks is affected. If containerInstanceLongArnFormat is specified, the ARN and resource ID for your Amazon ECS container instances is affected. If awsvpcTrunking is specified, the ENI limit for your Amazon ECS container instances is affected. If containerInsights is specified, the default setting for CloudWatch Container Insights for your clusters is affected.

Returns:

  • (String)


6167
6168
6169
6170
6171
# File 'lib/aws-sdk-ecs/types.rb', line 6167

class PutAccountSettingDefaultRequest < Struct.new(
  :name,
  :value)
  include Aws::Structure
end

#valueString

The account setting value for the specified principal ARN. Accepted values are enabled and disabled.

Returns:

  • (String)


6167
6168
6169
6170
6171
# File 'lib/aws-sdk-ecs/types.rb', line 6167

class PutAccountSettingDefaultRequest < Struct.new(
  :name,
  :value)
  include Aws::Structure
end