Class: Aws::ECS::Types::RepositoryCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::RepositoryCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The repository credentials for private registry authentication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credentials_parameter ⇒ String
The Amazon Resource Name (ARN) of the secret containing the private repository credentials.
Instance Attribute Details
#credentials_parameter ⇒ String
The Amazon Resource Name (ARN) of the secret containing the private repository credentials.
<note markdown=“1”> When you use the Amazon ECS API, CLI, or Amazon Web Services SDK, if the secret exists in the same Region as the task that you’re launching then you can use either the full ARN or the name of the secret. When you use the Amazon Web Services Management Console, you must specify the full ARN of the secret.
</note>
11398 11399 11400 11401 11402 |
# File 'lib/aws-sdk-ecs/types.rb', line 11398 class RepositoryCredentials < Struct.new( :credentials_parameter) SENSITIVE = [] include Aws::Structure end |