Class: Aws::ECS::Types::Resource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Describes the resources available for a container instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#double_valueFloat

When the doubleValue type is set, the value of the resource must be a double precision floating-point type.



11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-ecs/types.rb', line 11500

class Resource < Struct.new(
  :name,
  :type,
  :double_value,
  :long_value,
  :integer_value,
  :string_set_value)
  SENSITIVE = []
  include Aws::Structure
end

#integer_valueInteger

When the integerValue type is set, the value of the resource must be an integer.



11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-ecs/types.rb', line 11500

class Resource < Struct.new(
  :name,
  :type,
  :double_value,
  :long_value,
  :integer_value,
  :string_set_value)
  SENSITIVE = []
  include Aws::Structure
end

#long_valueInteger

When the longValue type is set, the value of the resource must be an extended precision floating-point type.



11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-ecs/types.rb', line 11500

class Resource < Struct.new(
  :name,
  :type,
  :double_value,
  :long_value,
  :integer_value,
  :string_set_value)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource, such as CPU, MEMORY, PORTS, PORTS_UDP, or a user-defined resource.



11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-ecs/types.rb', line 11500

class Resource < Struct.new(
  :name,
  :type,
  :double_value,
  :long_value,
  :integer_value,
  :string_set_value)
  SENSITIVE = []
  include Aws::Structure
end

#string_set_valueArray<String>

When the stringSetValue type is set, the value of the resource must be a string type.



11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-ecs/types.rb', line 11500

class Resource < Struct.new(
  :name,
  :type,
  :double_value,
  :long_value,
  :integer_value,
  :string_set_value)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the resource. Valid values: INTEGER, DOUBLE, LONG, or STRINGSET.



11500
11501
11502
11503
11504
11505
11506
11507
11508
11509
# File 'lib/aws-sdk-ecs/types.rb', line 11500

class Resource < Struct.new(
  :name,
  :type,
  :double_value,
  :long_value,
  :integer_value,
  :string_set_value)
  SENSITIVE = []
  include Aws::Structure
end