Class: Aws::ECS::Types::ResourceRequirement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The type and amount of a resource to assign to a container. The supported resource types are GPUs, Neuron devices, and Elastic Inference accelerators. For more information, see [Working with GPUs on Amazon ECS] or [Working with Amazon Elastic Inference on Amazon ECS] in the *Amazon Elastic Container Service Developer Guide*

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-gpu.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-inference.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The type of resource to assign to a container.

Returns:

  • (String)


13565
13566
13567
13568
13569
13570
# File 'lib/aws-sdk-ecs/types.rb', line 13565

class ResourceRequirement < Struct.new(
  :value,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value for the specified resource type.

When the type is ‘GPU`, the value is the number of physical `GPUs` the Amazon ECS container agent reserves for the container. The number of GPUs that’s reserved for all containers in a task can’t exceed the number of available GPUs on the container instance that the task is launched on. You can also specify ‘ALL` to allocate all available GPUs on the instance to the container.

When the type is ‘NeuronDevice`, the value must be `ALL`. This allocates all available Neuron devices on the instance to the container. Only one container in a task can specify `NeuronDevice` resources. This resource type is only supported on Managed Instances.

When the type is ‘InferenceAccelerator`, the `value` matches the `deviceName` for an [InferenceAccelerator] specified in a task definition.

[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_InferenceAccelerator.html

Returns:

  • (String)


13565
13566
13567
13568
13569
13570
# File 'lib/aws-sdk-ecs/types.rb', line 13565

class ResourceRequirement < Struct.new(
  :value,
  :type)
  SENSITIVE = []
  include Aws::Structure
end