Method: Aws::ECS::Types::RunTaskRequest#group

Defined in:
lib/aws-sdk-ecs/types.rb

#groupString

The name of the task group to associate with the task. The default value is the family name of the task definition (for example, family:my-family-name).

Returns:

  • (String)


7456
7457
7458
7459
7460
7461
7462
7463
7464
7465
7466
7467
7468
7469
7470
7471
7472
7473
7474
# File 'lib/aws-sdk-ecs/types.rb', line 7456

class RunTaskRequest < Struct.new(
  :capacity_provider_strategy,
  :cluster,
  :count,
  :enable_ecs_managed_tags,
  :group,
  :launch_type,
  :network_configuration,
  :overrides,
  :placement_constraints,
  :placement_strategy,
  :platform_version,
  :propagate_tags,
  :reference_id,
  :started_by,
  :tags,
  :task_definition)
  include Aws::Structure
end