Class: Aws::ECS::Types::RunTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::RunTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failures ⇒ Array<Types::Failure>
Any failures associated with the call.
-
#tasks ⇒ Array<Types::Task>
A full description of the tasks that were run.
Instance Attribute Details
#failures ⇒ Array<Types::Failure>
Any failures associated with the call.
For information about how to address failures, see Service event messages and API failure reasons in the Amazon Elastic Container Service Developer Guide.
14248 14249 14250 14251 14252 14253 |
# File 'lib/aws-sdk-ecs/types.rb', line 14248 class RunTaskResponse < Struct.new( :tasks, :failures) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<Types::Task>
A full description of the tasks that were run. The tasks that were successfully placed on your cluster are described here.
14248 14249 14250 14251 14252 14253 |
# File 'lib/aws-sdk-ecs/types.rb', line 14248 class RunTaskResponse < Struct.new( :tasks, :failures) SENSITIVE = [] include Aws::Structure end |