Class: Aws::ECS::Types::S3FilesVolumeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

This parameter is specified when you’re using an Amazon S3 Files file system for task storage. For more information, see [Amazon S3 Files volumes] in the *Amazon Elastic Container Service Developer Guide*.

Your task definition must include a Task IAM Role. See [ IAM role for attaching your file system to AWS compute resources] for required permissions.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/s3files-volumes.html [2]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-files-prereq-policies.html#s3-files-prereq-iam-compute-role

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_arnString

The full ARN of the S3 Files access point to use. If an access point is specified, the root directory value specified in the ‘S3FilesVolumeConfiguration` must either be omitted or set to `/` which will enforce the path set on the S3 Files access point. For more information, see [Creating S3 Files access points].

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-files-access-points-creating.html

Returns:

  • (String)


13835
13836
13837
13838
13839
13840
13841
13842
# File 'lib/aws-sdk-ecs/types.rb', line 13835

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_arnString

The full ARN of the S3 Files file system to mount.

Returns:

  • (String)


13835
13836
13837
13838
13839
13840
13841
13842
# File 'lib/aws-sdk-ecs/types.rb', line 13835

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#root_directoryString

The directory within the Amazon S3 Files file system to mount as the root directory. If this parameter is omitted, the root of the Amazon S3 Files file system will be used. Specifying ‘/` will have the same effect as omitting this parameter.

If a S3 Files access point is specified in the ‘accessPointArn`, the root directory parameter must either be omitted or set to `/` which will enforce the path set on the S3 Files access point.

Returns:

  • (String)


13835
13836
13837
13838
13839
13840
13841
13842
# File 'lib/aws-sdk-ecs/types.rb', line 13835

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#transit_encryption_portInteger

The port to use for sending encrypted data between the ECS host and the S3 Files file system. If you do not specify a transit encryption port, it will use the port selection strategy that the Amazon S3 Files mount helper uses. For more information, see [S3 Files mount helper].

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/s3-files-mounting.html

Returns:

  • (Integer)


13835
13836
13837
13838
13839
13840
13841
13842
# File 'lib/aws-sdk-ecs/types.rb', line 13835

class S3FilesVolumeConfiguration < Struct.new(
  :file_system_arn,
  :root_directory,
  :transit_encryption_port,
  :access_point_arn)
  SENSITIVE = []
  include Aws::Structure
end