Class: Aws::ECS::Types::Secret
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::Secret
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
An object representing the secret to expose to your container. Secrets can be exposed to a container in the following ways:
-
To inject sensitive data into your containers as environment variables, use the
secretscontainer definition parameter. -
To reference sensitive information in the log configuration of a container, use the
secretOptionscontainer definition parameter.
For more information, see [Specifying sensitive data] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the secret.
-
#value_from ⇒ String
The secret to expose to the container.
Instance Attribute Details
#name ⇒ String
The name of the secret.
11979 11980 11981 11982 11983 11984 |
# File 'lib/aws-sdk-ecs/types.rb', line 11979 class Secret < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |
#value_from ⇒ String
The secret to expose to the container. The supported values are either the full ARN of the Secrets Manager secret or the full ARN of the parameter in the SSM Parameter Store.
For information about the require Identity and Access Management permissions, see [Required IAM permissions for Amazon ECS secrets] (for Secrets Manager) or [Required IAM permissions for Amazon ECS secrets] (for Systems Manager Parameter store) in the *Amazon Elastic Container Service Developer Guide*.
<note markdown=“1”> If the SSM Parameter Store parameter exists in the same Region as the task you’re launching, then you can use either the full ARN or name of the parameter. If the parameter exists in a different Region, then the full ARN must be specified.
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data-secrets.html#secrets-iam [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data-parameters.html
11979 11980 11981 11982 11983 11984 |
# File 'lib/aws-sdk-ecs/types.rb', line 11979 class Secret < Struct.new( :name, :value_from) SENSITIVE = [] include Aws::Structure end |