Class: Aws::ECS::Types::ServiceConnectTestTrafficRules
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ServiceConnectTestTrafficRules
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The test traffic routing configuration for Amazon ECS blue/green deployments. This configuration allows you to define rules for routing specific traffic to the new service revision during the deployment process, allowing for safe testing before full production traffic shift.
For more information, see [Service Connect for Amazon ECS blue/green deployments] in the Amazon Elastic Container Service Developer Guide.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect-blue-green.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#header ⇒ Types::ServiceConnectTestTrafficHeaderRules
The HTTP header-based routing rules that determine which requests should be routed to the new service version during blue/green deployment testing.
Instance Attribute Details
#header ⇒ Types::ServiceConnectTestTrafficHeaderRules
The HTTP header-based routing rules that determine which requests should be routed to the new service version during blue/green deployment testing. These rules provide fine-grained control over test traffic routing based on request headers.
14878 14879 14880 14881 14882 |
# File 'lib/aws-sdk-ecs/types.rb', line 14878 class ServiceConnectTestTrafficRules < Struct.new( :header) SENSITIVE = [] include Aws::Structure end |