Class: Aws::ECS::Types::ServiceCurrentRevisionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The summary of the current service revision configuration

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the current service revision.

Returns:

  • (String)


12771
12772
12773
12774
12775
12776
12777
12778
# File 'lib/aws-sdk-ecs/types.rb', line 12771

class ServiceCurrentRevisionSummary < Struct.new(
  :arn,
  :requested_task_count,
  :running_task_count,
  :pending_task_count)
  SENSITIVE = []
  include Aws::Structure
end

#pending_task_countInteger

The number of pending tasks in the current service revision

Returns:

  • (Integer)


12771
12772
12773
12774
12775
12776
12777
12778
# File 'lib/aws-sdk-ecs/types.rb', line 12771

class ServiceCurrentRevisionSummary < Struct.new(
  :arn,
  :requested_task_count,
  :running_task_count,
  :pending_task_count)
  SENSITIVE = []
  include Aws::Structure
end

#requested_task_countInteger

The number of requested tasks in the current service revision

Returns:

  • (Integer)


12771
12772
12773
12774
12775
12776
12777
12778
# File 'lib/aws-sdk-ecs/types.rb', line 12771

class ServiceCurrentRevisionSummary < Struct.new(
  :arn,
  :requested_task_count,
  :running_task_count,
  :pending_task_count)
  SENSITIVE = []
  include Aws::Structure
end

#running_task_countInteger

The number of running tasks of the current service revision

Returns:

  • (Integer)


12771
12772
12773
12774
12775
12776
12777
12778
# File 'lib/aws-sdk-ecs/types.rb', line 12771

class ServiceCurrentRevisionSummary < Struct.new(
  :arn,
  :requested_task_count,
  :running_task_count,
  :pending_task_count)
  SENSITIVE = []
  include Aws::Structure
end