Class: Aws::ECS::Types::ServiceDeploymentAlarms

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The CloudWatch alarms used to determine a service deployment failed.

Amazon ECS considers the service deployment as failed when any of the alarms move to the ALARM state. For more information, see How CloudWatch alarms detect Amazon ECS deployment failures in the Amazon ECS Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_namesArray<String>

The name of the CloudWatch alarms that determine when a service deployment failed. A "," separates the alarms.

Returns:

  • (Array<String>)


15327
15328
15329
15330
15331
15332
15333
# File 'lib/aws-sdk-ecs/types.rb', line 15327

class ServiceDeploymentAlarms < Struct.new(
  :status,
  :alarm_names,
  :triggered_alarm_names)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the alarms check. Amazon ECS is not using alarms for service deployment failures when the status is DISABLED.

Returns:

  • (String)


15327
15328
15329
15330
15331
15332
15333
# File 'lib/aws-sdk-ecs/types.rb', line 15327

class ServiceDeploymentAlarms < Struct.new(
  :status,
  :alarm_names,
  :triggered_alarm_names)
  SENSITIVE = []
  include Aws::Structure
end

#triggered_alarm_namesArray<String>

One or more CloudWatch alarm names that have been triggered during the service deployment. A "," separates the alarm names.

Returns:

  • (Array<String>)


15327
15328
15329
15330
15331
15332
15333
# File 'lib/aws-sdk-ecs/types.rb', line 15327

class ServiceDeploymentAlarms < Struct.new(
  :status,
  :alarm_names,
  :triggered_alarm_names)
  SENSITIVE = []
  include Aws::Structure
end