Class: Aws::ECS::Types::ServiceRevision
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ServiceRevision
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Information about the service revision.
A service revision contains a record of the workload configuration Amazon ECS is attempting to deploy. Whenever you create or deploy a service, Amazon ECS automatically creates and captures the configuration that you’re trying to deploy in the service revision. For information about service revisions, see [Amazon ECS service revisions] in the Amazon Elastic Container Service Developer Guide .
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-revision.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy the service revision uses.
-
#cluster_arn ⇒ String
The ARN of the cluster that hosts the service.
-
#container_images ⇒ Array<Types::ContainerImage>
The container images the service revision uses.
-
#created_at ⇒ Time
The time that the service revision was created.
-
#ecs_managed_resources ⇒ Types::ECSManagedResources
The resources created and managed by Amazon ECS when you create an Express service for Amazon ECS.
-
#fargate_ephemeral_storage ⇒ Types::DeploymentEphemeralStorage
The amount of ephemeral storage to allocate for the deployment.
-
#guard_duty_enabled ⇒ Boolean
Indicates whether Runtime Monitoring is turned on.
-
#launch_type ⇒ String
The launch type the service revision uses.
-
#load_balancers ⇒ Array<Types::LoadBalancer>
The load balancers the service revision uses.
-
#monitoring ⇒ Types::MonitoringConfiguration
The optional monitoring configuration for the service, which defines the resolution for the service-level ‘CPUUtilization` and `MemoryUtilization` Amazon CloudWatch metrics.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for a task or service.
-
#platform_family ⇒ String
The platform family the service revision uses.
-
#platform_version ⇒ String
For the Fargate launch type, the platform version the service revision uses.
-
#resolved_configuration ⇒ Types::ResolvedConfiguration
The resolved configuration for the service revision which contains the actual resources your service revision uses, such as which target groups serve traffic.
-
#service_arn ⇒ String
The ARN of the service for the service revision.
-
#service_connect_configuration ⇒ Types::ServiceConnectConfiguration
The Service Connect configuration of your Amazon ECS service.
-
#service_registries ⇒ Array<Types::ServiceRegistry>
The service registries (for Service Discovery) the service revision uses.
-
#service_revision_arn ⇒ String
The ARN of the service revision.
-
#task_definition ⇒ String
The task definition the service revision uses.
-
#volume_configurations ⇒ Array<Types::ServiceVolumeConfiguration>
The volumes that are configured at deployment that the service revision uses.
-
#vpc_lattice_configurations ⇒ Array<Types::VpcLatticeConfiguration>
The VPC Lattice configuration for the service revision.
Instance Attribute Details
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The ARN of the cluster that hosts the service.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#container_images ⇒ Array<Types::ContainerImage>
The container images the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time that the service revision was created. The format is yyyy-mm-dd HH:mm:ss.SSSSS.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#ecs_managed_resources ⇒ Types::ECSManagedResources
The resources created and managed by Amazon ECS when you create an Express service for Amazon ECS.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#fargate_ephemeral_storage ⇒ Types::DeploymentEphemeralStorage
The amount of ephemeral storage to allocate for the deployment.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#guard_duty_enabled ⇒ Boolean
Indicates whether Runtime Monitoring is turned on.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#launch_type ⇒ String
The launch type the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#load_balancers ⇒ Array<Types::LoadBalancer>
The load balancers the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#monitoring ⇒ Types::MonitoringConfiguration
The optional monitoring configuration for the service, which defines the resolution for the service-level ‘CPUUtilization` and `MemoryUtilization` Amazon CloudWatch metrics. When not specified, Amazon ECS uses the default resolution of `60` seconds.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for a task or service.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#platform_family ⇒ String
The platform family the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#platform_version ⇒ String
For the Fargate launch type, the platform version the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#resolved_configuration ⇒ Types::ResolvedConfiguration
The resolved configuration for the service revision which contains the actual resources your service revision uses, such as which target groups serve traffic.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN of the service for the service revision.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#service_connect_configuration ⇒ Types::ServiceConnectConfiguration
The Service Connect configuration of your Amazon ECS service. The configuration for this service to discover and connect to services, and be discovered by, and connected from, other services within a namespace.
Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see [Service Connect] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#service_registries ⇒ Array<Types::ServiceRegistry>
The service registries (for Service Discovery) the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#service_revision_arn ⇒ String
The ARN of the service revision.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#task_definition ⇒ String
The task definition the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#volume_configurations ⇒ Array<Types::ServiceVolumeConfiguration>
The volumes that are configured at deployment that the service revision uses.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |
#vpc_lattice_configurations ⇒ Array<Types::VpcLatticeConfiguration>
The VPC Lattice configuration for the service revision.
15912 15913 15914 15915 15916 15917 15918 15919 15920 15921 15922 15923 15924 15925 15926 15927 15928 15929 15930 15931 15932 15933 15934 15935 15936 |
# File 'lib/aws-sdk-ecs/types.rb', line 15912 class ServiceRevision < Struct.new( :service_revision_arn, :service_arn, :cluster_arn, :task_definition, :capacity_provider_strategy, :launch_type, :platform_version, :platform_family, :load_balancers, :service_registries, :network_configuration, :container_images, :guard_duty_enabled, :service_connect_configuration, :volume_configurations, :fargate_ephemeral_storage, :created_at, :vpc_lattice_configurations, :resolved_configuration, :ecs_managed_resources, :monitoring) SENSITIVE = [] include Aws::Structure end |