Class: Aws::ECS::Types::Session
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::Session
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The details for the execute command session.
Constant Summary collapse
- SENSITIVE =
[:token_value]
Instance Attribute Summary collapse
-
#session_id ⇒ String
The ID of the execute command session.
-
#stream_url ⇒ String
A URL to the managed agent on the container that the SSM Session Manager client uses to send commands and receive output from the container.
-
#token_value ⇒ String
An encrypted token value containing session and caller information.
Instance Attribute Details
#session_id ⇒ String
The ID of the execute command session.
15998 15999 16000 16001 16002 16003 16004 |
# File 'lib/aws-sdk-ecs/types.rb', line 15998 class Session < Struct.new( :session_id, :stream_url, :token_value) SENSITIVE = [:token_value] include Aws::Structure end |
#stream_url ⇒ String
A URL to the managed agent on the container that the SSM Session Manager client uses to send commands and receive output from the container.
15998 15999 16000 16001 16002 16003 16004 |
# File 'lib/aws-sdk-ecs/types.rb', line 15998 class Session < Struct.new( :session_id, :stream_url, :token_value) SENSITIVE = [:token_value] include Aws::Structure end |
#token_value ⇒ String
An encrypted token value containing session and caller information. It’s used to authenticate the connection to the container.
15998 15999 16000 16001 16002 16003 16004 |
# File 'lib/aws-sdk-ecs/types.rb', line 15998 class Session < Struct.new( :session_id, :stream_url, :token_value) SENSITIVE = [:token_value] include Aws::Structure end |