Class: Aws::ECS::Types::Setting
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::Setting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The current account setting for a resource.
Instance Attribute Summary collapse
-
#name ⇒ String
The Amazon ECS resource name.
-
#principal_arn ⇒ String
The ARN of the principal, which can be an IAM user, IAM role, or the root user.
-
#value ⇒ String
Whether the account setting is enabled or disabled for the specified resource.
Instance Attribute Details
#name ⇒ String
The Amazon ECS resource name.
7950 7951 7952 7953 7954 7955 |
# File 'lib/aws-sdk-ecs/types.rb', line 7950 class Setting < Struct.new( :name, :value, :principal_arn) include Aws::Structure end |
#principal_arn ⇒ String
The ARN of the principal, which can be an IAM user, IAM role, or the root user. If this field is omitted, the authenticated user is assumed.
7950 7951 7952 7953 7954 7955 |
# File 'lib/aws-sdk-ecs/types.rb', line 7950 class Setting < Struct.new( :name, :value, :principal_arn) include Aws::Structure end |
#value ⇒ String
Whether the account setting is enabled or disabled for the specified resource.
7950 7951 7952 7953 7954 7955 |
# File 'lib/aws-sdk-ecs/types.rb', line 7950 class Setting < Struct.new( :name, :value, :principal_arn) include Aws::Structure end |