Class: Aws::ECS::Types::StartTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::StartTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass StartTaskRequest data as a hash:
{
cluster: "String",
container_instances: ["String"], # required
enable_ecs_managed_tags: false,
group: "String",
network_configuration: {
awsvpc_configuration: {
subnets: ["String"], # required
security_groups: ["String"],
assign_public_ip: "ENABLED", # accepts ENABLED, DISABLED
},
},
overrides: {
container_overrides: [
{
name: "String",
command: ["String"],
environment: [
{
name: "String",
value: "String",
},
],
cpu: 1,
memory: 1,
memory_reservation: 1,
resource_requirements: [
{
value: "String", # required
type: "GPU", # required, accepts GPU, InferenceAccelerator
},
],
},
],
cpu: "String",
inference_accelerator_overrides: [
{
device_name: "String",
device_type: "String",
},
],
execution_role_arn: "String",
memory: "String",
task_role_arn: "String",
},
propagate_tags: "TASK_DEFINITION", # accepts TASK_DEFINITION, SERVICE
reference_id: "String",
started_by: "String",
tags: [
{
key: "TagKey",
value: "TagValue",
},
],
task_definition: "String", # required
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster on which to start your task.
-
#container_instances ⇒ Array<String>
The container instance IDs or full ARN entries for the container instances on which you would like to place your task.
-
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to enable Amazon ECS managed tags for the task.
-
#group ⇒ String
The name of the task group to associate with the task.
-
#network_configuration ⇒ Types::NetworkConfiguration
The VPC subnet and security group configuration for tasks that receive their own elastic network interface by using the
awsvpcnetworking mode. -
#overrides ⇒ Types::TaskOverride
A list of container overrides in JSON format that specify the name of a container in the specified task definition and the overrides it should receive.
-
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the task definition or the service to the task.
-
#reference_id ⇒ String
The reference ID to use for the task.
-
#started_by ⇒ String
An optional tag specified when a task is started.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task to help you categorize and organize them.
-
#task_definition ⇒ String
The
familyandrevision(family:revision) or full ARN of the task definition to start.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster on which to start your task. If you do not specify a cluster, the default cluster is assumed.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#container_instances ⇒ Array<String>
The container instance IDs or full ARN entries for the container instances on which you would like to place your task. You can specify up to 10 container instances.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to enable Amazon ECS managed tags for the task. For more information, see [Tagging Your Amazon ECS Resources] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#group ⇒ String
The name of the task group to associate with the task. The default value is the family name of the task definition (for example, family:my-family-name).
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The VPC subnet and security group configuration for tasks that receive their own elastic network interface by using the awsvpc networking mode.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#overrides ⇒ Types::TaskOverride
A list of container overrides in JSON format that specify the name of a container in the specified task definition and the overrides it should receive. You can override the default command for a container (that is specified in the task definition or Docker image) with a command override. You can also override existing environment variables (that are specified in the task definition or Docker image) on a container or add new environment variables to it with an environment override.
<note markdown=“1”> A total of 8192 characters are allowed for overrides. This limit includes the JSON formatting characters of the override structure.
</note>
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the task definition or the service to the task. If no value is specified, the tags are not propagated.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#reference_id ⇒ String
The reference ID to use for the task.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#started_by ⇒ String
An optional tag specified when a task is started. For example, if you automatically trigger a task to run a batch process job, you could apply a unique identifier for that job to your task with the startedBy parameter. You can then identify which tasks belong to that job by filtering the results of a ListTasks call with the startedBy value. Up to 36 letters (uppercase and lowercase), numbers, hyphens, and underscores are allowed.
If a task is started by an Amazon ECS service, then the startedBy parameter contains the deployment ID of the service that starts it.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.
The following basic restrictions apply to tags:
-
Maximum number of tags per resource - 50
-
For each resource, each tag key must be unique, and each tag key can have only one value.
-
Maximum key length - 128 Unicode characters in UTF-8
-
Maximum value length - 256 Unicode characters in UTF-8
-
If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
-
Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |
#task_definition ⇒ String
The family and revision (family:revision) or full ARN of the task definition to start. If a revision is not specified, the latest ACTIVE revision is used.
8129 8130 8131 8132 8133 8134 8135 8136 8137 8138 8139 8140 8141 8142 |
# File 'lib/aws-sdk-ecs/types.rb', line 8129 class StartTaskRequest < Struct.new( :cluster, :container_instances, :enable_ecs_managed_tags, :group, :network_configuration, :overrides, :propagate_tags, :reference_id, :started_by, :tags, :task_definition) include Aws::Structure end |