Class: Aws::ECS::Types::StopTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::StopTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task to stop.
-
#reason ⇒ String
An optional message specified when a task is stopped.
-
#task ⇒ String
Thefull Amazon Resource Name (ARN) of the task.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task to stop. If you do not specify a cluster, the default cluster is assumed.
16355 16356 16357 16358 16359 16360 16361 |
# File 'lib/aws-sdk-ecs/types.rb', line 16355 class StopTaskRequest < Struct.new( :cluster, :task, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
An optional message specified when a task is stopped. For example, if you're using a custom scheduler, you can use this parameter to specify the reason for stopping the task here, and the message appears in subsequent DescribeTasks> API operations on this task.
16355 16356 16357 16358 16359 16360 16361 |
# File 'lib/aws-sdk-ecs/types.rb', line 16355 class StopTaskRequest < Struct.new( :cluster, :task, :reason) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
Thefull Amazon Resource Name (ARN) of the task.
16355 16356 16357 16358 16359 16360 16361 |
# File 'lib/aws-sdk-ecs/types.rb', line 16355 class StopTaskRequest < Struct.new( :cluster, :task, :reason) SENSITIVE = [] include Aws::Structure end |