Class: Aws::ECS::Types::SubmitAttachmentStateChangesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::SubmitAttachmentStateChangesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass SubmitAttachmentStateChangesRequest data as a hash:
{
cluster: "String",
attachments: [ # required
{
attachment_arn: "String", # required
status: "String", # required
},
],
}
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Types::AttachmentStateChange>
Any attachments associated with the state change request.
-
#cluster ⇒ String
The short name or full ARN of the cluster that hosts the container instance the attachment belongs to.
Instance Attribute Details
#attachments ⇒ Array<Types::AttachmentStateChange>
Any attachments associated with the state change request.
8232 8233 8234 8235 8236 |
# File 'lib/aws-sdk-ecs/types.rb', line 8232 class SubmitAttachmentStateChangesRequest < Struct.new( :cluster, :attachments) include Aws::Structure end |
#cluster ⇒ String
The short name or full ARN of the cluster that hosts the container instance the attachment belongs to.
8232 8233 8234 8235 8236 |
# File 'lib/aws-sdk-ecs/types.rb', line 8232 class SubmitAttachmentStateChangesRequest < Struct.new( :cluster, :attachments) include Aws::Structure end |