Class: Aws::ECS::Types::SubmitTaskStateChangeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachmentsArray<Types::AttachmentStateChange>

Any attachments associated with the state change request.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#containersArray<Types::ContainerStateChange>

Any containers that's associated with the state change request.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_stopped_atTime

The Unix timestamp for the time when the task execution stopped.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#managed_agentsArray<Types::ManagedAgentStateChange>

The details for the managed agent that's associated with the task.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#pull_started_atTime

The Unix timestamp for the time when the container image pull started.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#pull_stopped_atTime

The Unix timestamp for the time when the container image pull completed.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason for the state change request.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the state change request.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#taskString

The task ID or full ARN of the task in the state change request.



16748
16749
16750
16751
16752
16753
16754
16755
16756
16757
16758
16759
16760
16761
# File 'lib/aws-sdk-ecs/types.rb', line 16748

class SubmitTaskStateChangeRequest < Struct.new(
  :cluster,
  :task,
  :status,
  :reason,
  :containers,
  :attachments,
  :managed_agents,
  :pull_started_at,
  :pull_stopped_at,
  :execution_stopped_at)
  SENSITIVE = []
  include Aws::Structure
end