Class: Aws::ECS::Types::SystemControl

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

A list of namespaced kernel parameters to set in the container. This parameter maps to Sysctls in the docker container create command and the --sysctl option to docker run. For example, you can configure net.ipv4.tcp_keepalive_time setting to maintain longer lived connections.

We don’t recommend that you specify network-related systemControls parameters for multiple containers in a single task that also uses either the awsvpc or host network mode. Doing this has the following disadvantages:

  • For tasks that use the awsvpc network mode including Fargate, if you set systemControls for any container, it applies to all containers in the task. If you set different systemControls for multiple containers in a single task, the container that’s started last determines which systemControls take effect.

  • For tasks that use the host network mode, the network namespace systemControls aren’t supported.

If you’re setting an IPC resource namespace to use for the containers in the task, the following conditions apply to your system controls. For more information, see [IPC mode].

  • For tasks that use the host IPC mode, IPC namespace systemControls aren’t supported.

  • For tasks that use the task IPC mode, IPC namespace systemControls values apply to all containers within a task.

<note markdown=“1”> This parameter is not supported for Windows containers.

</note>

<note markdown=“1”> This parameter is only supported for tasks that are hosted on Fargate if the tasks are using platform version 1.4.0 or later (Linux). This isn’t supported for Windows containers on Fargate.

</note>

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html#task_definition_ipcmode

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namespaceString

The namespaced kernel parameter to set a value for.

Returns:

  • (String)


14250
14251
14252
14253
14254
14255
# File 'lib/aws-sdk-ecs/types.rb', line 14250

class SystemControl < Struct.new(
  :namespace,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The namespaced kernel parameter to set a value for.

Valid IPC namespace values: ‘“kernel.msgmax” | “kernel.msgmnb” | “kernel.msgmni” | “kernel.sem” | “kernel.shmall” | “kernel.shmmax” | “kernel.shmmni” | “kernel.shm_rmid_forced”`, and Sysctls that start with `“fs.mqueue.*”`

Valid network namespace values: Sysctls that start with ‘“net.*”`. Only namespaced Sysctls that exist within the container starting with “net.* are accepted.

All of these values are supported by Fargate.

Returns:

  • (String)


14250
14251
14252
14253
14254
14255
# File 'lib/aws-sdk-ecs/types.rb', line 14250

class SystemControl < Struct.new(
  :namespace,
  :value)
  SENSITIVE = []
  include Aws::Structure
end