Class: Aws::ECS::Types::TargetNotConnectedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The execute command cannot run. This error can be caused by any of the following configuration issues:

  • Incorrect IAM permissions

  • The SSM agent is not installed or is not running

  • There is an interface Amazon VPC endpoint for Amazon ECS, but there is not one for Systems Manager Session Manager

For information about how to troubleshoot the issues, see Troubleshooting issues with ECS Exec in the Amazon Elastic Container Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Message that describes the cause of the exception.

Returns:

  • (String)


16820
16821
16822
16823
16824
# File 'lib/aws-sdk-ecs/types.rb', line 16820

class TargetNotConnectedException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end