Class: Aws::ECS::Types::Task
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::Task
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Details on a task in a cluster.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Types::Attachment>
The Elastic Network Adapter associated with the task if the task uses the
awsvpcnetwork mode. -
#attributes ⇒ Array<Types::Attribute>
The attributes of the task.
-
#availability_zone ⇒ String
The availability zone of the task.
-
#capacity_provider_name ⇒ String
The capacity provider associated with the task.
-
#cluster_arn ⇒ String
The ARN of the cluster that hosts the task.
-
#connectivity ⇒ String
The connectivity status of a task.
-
#connectivity_at ⇒ Time
The Unix timestamp for when the task last went into
CONNECTEDstatus. -
#container_instance_arn ⇒ String
The ARN of the container instances that host the task.
-
#containers ⇒ Array<Types::Container>
The containers associated with the task.
-
#cpu ⇒ String
The number of CPU units used by the task as expressed in a task definition.
-
#created_at ⇒ Time
The Unix timestamp for when the task was created (the task entered the
PENDINGstate). -
#desired_status ⇒ String
The desired status of the task.
-
#execution_stopped_at ⇒ Time
The Unix timestamp for when the task execution stopped.
-
#group ⇒ String
The name of the task group associated with the task.
-
#health_status ⇒ String
The health status for the task, which is determined by the health of the essential containers in the task.
-
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerator associated with the task.
-
#last_status ⇒ String
The last known status of the task.
-
#launch_type ⇒ String
The launch type on which your task is running.
-
#memory ⇒ String
The amount of memory (in MiB) used by the task as expressed in a task definition.
-
#overrides ⇒ Types::TaskOverride
One or more container overrides.
-
#platform_version ⇒ String
The platform version on which your task is running.
-
#pull_started_at ⇒ Time
The Unix timestamp for when the container image pull began.
-
#pull_stopped_at ⇒ Time
The Unix timestamp for when the container image pull completed.
-
#started_at ⇒ Time
The Unix timestamp for when the task started (the task transitioned from the
PENDINGstate to theRUNNINGstate). -
#started_by ⇒ String
The tag specified when a task is started.
-
#stop_code ⇒ String
The stop code indicating why a task was stopped.
-
#stopped_at ⇒ Time
The Unix timestamp for when the task was stopped (the task transitioned from the
RUNNINGstate to theSTOPPEDstate). -
#stopped_reason ⇒ String
The reason that the task was stopped.
-
#stopping_at ⇒ Time
The Unix timestamp for when the task stops (transitions from the
RUNNINGstate toSTOPPED). -
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task to help you categorize and organize them.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task.
-
#task_definition_arn ⇒ String
The ARN of the task definition that creates the task.
-
#version ⇒ Integer
The version counter for the task.
Instance Attribute Details
#attachments ⇒ Array<Types::Attachment>
The Elastic Network Adapter associated with the task if the task uses the awsvpc network mode.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#attributes ⇒ Array<Types::Attribute>
The attributes of the task
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#availability_zone ⇒ String
The availability zone of the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#capacity_provider_name ⇒ String
The capacity provider associated with the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#cluster_arn ⇒ String
The ARN of the cluster that hosts the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#connectivity ⇒ String
The connectivity status of a task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#connectivity_at ⇒ Time
The Unix timestamp for when the task last went into CONNECTED status.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#container_instance_arn ⇒ String
The ARN of the container instances that host the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#containers ⇒ Array<Types::Container>
The containers associated with the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#cpu ⇒ String
The number of CPU units used by the task as expressed in a task definition. It can be expressed as an integer using CPU units, for example 1024. It can also be expressed as a string using vCPUs, for example ‘1 vCPU` or `1 vcpu`. String values are converted to an integer indicating the CPU units when the task definition is registered.
If you are using the EC2 launch type, this field is optional. Supported values are between 128 CPU units (0.125 vCPUs) and 10240 CPU units (10 vCPUs).
If you are using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of supported values for the memory parameter:
-
256 (.25 vCPU) - Available
memoryvalues: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) -
512 (.5 vCPU) - Available
memoryvalues: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) -
1024 (1 vCPU) - Available
memoryvalues: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) -
2048 (2 vCPU) - Available
memoryvalues: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) -
4096 (4 vCPU) - Available
memoryvalues: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#created_at ⇒ Time
The Unix timestamp for when the task was created (the task entered the PENDING state).
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#desired_status ⇒ String
The desired status of the task. For more information, see [Task Lifecycle].
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-lifecycle.html
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#execution_stopped_at ⇒ Time
The Unix timestamp for when the task execution stopped.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#group ⇒ String
The name of the task group associated with the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#health_status ⇒ String
The health status for the task, which is determined by the health of the essential containers in the task. If all essential containers in the task are reporting as HEALTHY, then the task status also reports as HEALTHY. If any essential containers in the task are reporting as UNHEALTHY or UNKNOWN, then the task status also reports as UNHEALTHY or UNKNOWN, accordingly.
<note markdown=“1”> The Amazon ECS container agent does not monitor or report on Docker health checks that are embedded in a container image (such as those specified in a parent image or from the image’s Dockerfile) and not specified in the container definition. Health check parameters that are specified in a container definition override any Docker health checks that exist in the container image.
</note>
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerator associated with the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#last_status ⇒ String
The last known status of the task. For more information, see [Task Lifecycle].
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-lifecycle.html
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#launch_type ⇒ String
The launch type on which your task is running. For more information, see [Amazon ECS Launch Types] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#memory ⇒ String
The amount of memory (in MiB) used by the task as expressed in a task definition. It can be expressed as an integer using MiB, for example 1024. It can also be expressed as a string using GB, for example 1GB or ‘1 GB`. String values are converted to an integer indicating the MiB when the task definition is registered.
If you are using the EC2 launch type, this field is optional.
If you are using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of supported values for the cpu parameter:
-
512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available
cpuvalues: 256 (.25 vCPU) -
1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available
cpuvalues: 512 (.5 vCPU) -
2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available
cpuvalues: 1024 (1 vCPU) -
Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 2048 (2 vCPU)
-
-
Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 4096 (4 vCPU)
-
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#overrides ⇒ Types::TaskOverride
One or more container overrides.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#platform_version ⇒ String
The platform version on which your task is running. A platform version is only specified for tasks using the Fargate launch type. If one is not specified, the LATEST platform version is used by default. For more information, see [AWS Fargate Platform Versions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#pull_started_at ⇒ Time
The Unix timestamp for when the container image pull began.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#pull_stopped_at ⇒ Time
The Unix timestamp for when the container image pull completed.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#started_at ⇒ Time
The Unix timestamp for when the task started (the task transitioned from the PENDING state to the RUNNING state).
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#started_by ⇒ String
The tag specified when a task is started. If the task is started by an Amazon ECS service, then the startedBy parameter contains the deployment ID of the service that starts it.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#stop_code ⇒ String
The stop code indicating why a task was stopped. The stoppedReason may contain additional details.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#stopped_at ⇒ Time
The Unix timestamp for when the task was stopped (the task transitioned from the RUNNING state to the STOPPED state).
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#stopped_reason ⇒ String
The reason that the task was stopped.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#stopping_at ⇒ Time
The Unix timestamp for when the task stops (transitions from the RUNNING state to STOPPED).
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.
The following basic restrictions apply to tags:
-
Maximum number of tags per resource - 50
-
For each resource, each tag key must be unique, and each tag key can have only one value.
-
Maximum key length - 128 Unicode characters in UTF-8
-
Maximum value length - 256 Unicode characters in UTF-8
-
If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
-
Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#task_definition_arn ⇒ String
The ARN of the task definition that creates the task.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |
#version ⇒ Integer
The version counter for the task. Every time a task experiences a change that triggers a CloudWatch event, the version counter is incremented. If you are replicating your Amazon ECS task state with CloudWatch Events, you can compare the version of a task reported by the Amazon ECS API actions with the version reported in CloudWatch Events for the task (inside the detail object) to verify that the version in your event stream is current.
8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 8880 8881 8882 8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 |
# File 'lib/aws-sdk-ecs/types.rb', line 8869 class Task < Struct.new( :attachments, :attributes, :availability_zone, :capacity_provider_name, :cluster_arn, :connectivity, :connectivity_at, :container_instance_arn, :containers, :cpu, :created_at, :desired_status, :execution_stopped_at, :group, :health_status, :inference_accelerators, :last_status, :launch_type, :memory, :overrides, :platform_version, :pull_started_at, :pull_stopped_at, :started_at, :started_by, :stop_code, :stopped_at, :stopped_reason, :stopping_at, :tags, :task_arn, :task_definition_arn, :version) include Aws::Structure end |