Class: Aws::ECS::Types::TaskDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The details of a task definition which describes the container and volume definitions of an Amazon Elastic Container Service task. You can specify which Docker images to use, the required resources, and other configurations related to launching the task definition through an Amazon ECS service or task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compatibilities ⇒ Array<String>
The task launch types the task definition validated against during task definition registration.
-
#container_definitions ⇒ Array<Types::ContainerDefinition>
A list of container definitions in JSON format that describe the different containers that make up your task.
-
#cpu ⇒ String
The number of
cpuunits used by the task. -
#deregistered_at ⇒ Time
The Unix timestamp for the time when the task definition was deregistered.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The ephemeral storage settings to use for tasks run with the task definition.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf.
-
#family ⇒ String
The name of a family that this task definition is registered to.
-
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerator that’s associated with the task.
-
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task.
-
#memory ⇒ String
The amount (in MiB) of memory used by the task.
-
#network_mode ⇒ String
The Docker networking mode to use for the containers in the task.
-
#pid_mode ⇒ String
The process namespace to use for the containers in the task.
-
#placement_constraints ⇒ Array<Types::TaskDefinitionPlacementConstraint>
An array of placement constraint objects to use for tasks.
-
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration details for the App Mesh proxy.
-
#registered_at ⇒ Time
The Unix timestamp for the time when the task definition was registered.
-
#registered_by ⇒ String
The principal that registered the task definition.
-
#requires_attributes ⇒ Array<Types::Attribute>
The container instance attributes required by your task.
-
#requires_compatibilities ⇒ Array<String>
The task launch types the task definition was validated against.
-
#revision ⇒ Integer
The revision of the task in a particular family.
-
#runtime_platform ⇒ Types::RuntimePlatform
The operating system that your task definitions are running on.
-
#status ⇒ String
The status of the task definition.
-
#task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the task definition.
-
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the Identity and Access Management role that grants containers in the task permission to call Amazon Web Services APIs on your behalf.
-
#volumes ⇒ Array<Types::Volume>
The list of data volume definitions for the task.
Instance Attribute Details
#compatibilities ⇒ Array<String>
The task launch types the task definition validated against during task definition registration. For more information, see [Amazon ECS launch types] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#container_definitions ⇒ Array<Types::ContainerDefinition>
A list of container definitions in JSON format that describe the different containers that make up your task. For more information about container definition parameters and defaults, see [Amazon ECS Task Definitions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_defintions.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#cpu ⇒ String
The number of cpu units used by the task. If you use the EC2 launch type, this field is optional. Any value can be used. If you use the Fargate launch type, this field is required. You must use one of the following values. The value that you choose determines your range of valid values for the memory parameter.
The CPU units cannot be less than 1 vCPU when you use Windows containers on Fargate.
-
256 (.25 vCPU) - Available
memoryvalues: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) -
512 (.5 vCPU) - Available
memoryvalues: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) -
1024 (1 vCPU) - Available
memoryvalues: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) -
2048 (2 vCPU) - Available
memoryvalues: 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) -
4096 (4 vCPU) - Available
memoryvalues: 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) -
8192 (8 vCPU) - Available
memoryvalues: 16 GB and 60 GB in 4 GB incrementsThis option requires Linux platform
1.4.0or later. -
16384 (16vCPU) - Available
memoryvalues: 32GB and 120 GB in 8 GB incrementsThis option requires Linux platform
1.4.0or later.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#deregistered_at ⇒ Time
The Unix timestamp for the time when the task definition was deregistered.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The ephemeral storage settings to use for tasks run with the task definition.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf. The task execution IAM role is required depending on the requirements of your task. For more information, see [Amazon ECS task execution IAM role] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_execution_IAM_role.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#family ⇒ String
The name of a family that this task definition is registered to. Up to 255 characters are allowed. Letters (both uppercase and lowercase letters), numbers, hyphens (-), and underscores (_) are allowed.
A family groups multiple versions of a task definition. Amazon ECS gives the first task definition that you registered to a family a revision number of 1. Amazon ECS gives sequential revision numbers to each task definition that you add.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerator that’s associated with the task.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task. The valid values are host, task, or none. If host is specified, then all containers within the tasks that specified the host IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same IPC resources. If none is specified, then IPC resources within the containers of a task are private and not shared with other containers in a task or on the container instance. If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see [IPC settings] in the *Docker run reference*.
If the host IPC mode is used, be aware that there is a heightened risk of undesired IPC namespace expose. For more information, see [Docker security].
If you are setting namespaced kernel parameters using systemControls for the containers in the task, the following will apply to your IPC resource namespace. For more information, see
- System Controls][3
-
in the *Amazon Elastic Container Service
Developer Guide*.
-
For tasks that use the
hostIPC mode, IPC namespace relatedsystemControlsare not supported. -
For tasks that use the
taskIPC mode, IPC namespace relatedsystemControlswill apply to all containers within a task.
<note markdown=“1”> This parameter is not supported for Windows containers or tasks run on Fargate.
</note>
[1]: docs.docker.com/engine/reference/run/#ipc-settings—ipc [2]: docs.docker.com/engine/security/security/ [3]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The amount (in MiB) of memory used by the task.
If your tasks runs on Amazon EC2 instances, you must specify either a task-level memory value or a container-level memory value. This field is optional and any value can be used. If a task-level memory value is specified, the container-level memory value is optional. For more information regarding container-level memory and memory reservation, see [ContainerDefinition].
If your tasks runs on Fargate, this field is required. You must use one of the following values. The value you choose determines your range of valid values for the cpu parameter.
-
512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available
cpuvalues: 256 (.25 vCPU) -
1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available
cpuvalues: 512 (.5 vCPU) -
2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available
cpuvalues: 1024 (1 vCPU) -
Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 2048 (2 vCPU)
-
-
Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 4096 (4 vCPU)
-
-
Between 16 GB and 60 GB in 4 GB increments - Available
cpuvalues: 8192 (8 vCPU)This option requires Linux platform
1.4.0or later. -
Between 32GB and 120 GB in 8 GB increments - Available
cpuvalues: 16384 (16 vCPU)This option requires Linux platform
1.4.0or later.
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ContainerDefinition.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#network_mode ⇒ String
The Docker networking mode to use for the containers in the task. The valid values are none, bridge, awsvpc, and host. If no network mode is specified, the default is bridge.
For Amazon ECS tasks on Fargate, the awsvpc network mode is required. For Amazon ECS tasks on Amazon EC2 Linux instances, any network mode can be used. For Amazon ECS tasks on Amazon EC2 Windows instances, ‘<default>` or awsvpc can be used. If the network mode is set to none, you cannot specify port mappings in your container definitions, and the tasks containers do not have external connectivity. The host and awsvpc network modes offer the highest networking performance for containers because they use the EC2 network stack instead of the virtualized network stack provided by the bridge mode.
With the host and awsvpc network modes, exposed container ports are mapped directly to the corresponding host port (for the host network mode) or the attached elastic network interface port (for the awsvpc network mode), so you cannot take advantage of dynamic host port mappings.
When using the host network mode, you should not run containers using the root user (UID 0). It is considered best practice to use a non-root user.
If the network mode is awsvpc, the task is allocated an elastic network interface, and you must specify a NetworkConfiguration value when you create a service or run a task with the task definition. For more information, see [Task Networking] in the *Amazon Elastic Container Service Developer Guide*.
If the network mode is host, you cannot run multiple instantiations of the same task on a single container instance when port mappings are used.
For more information, see [Network settings] in the *Docker run reference*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html [2]: docs.docker.com/engine/reference/run/#network-settings
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#pid_mode ⇒ String
The process namespace to use for the containers in the task. The valid values are host or task. On Fargate for Linux containers, the only valid value is task. For example, monitoring sidecars might need pidMode to access information about other containers running in the same task.
If host is specified, all containers within the tasks that specified the host PID mode on the same container instance share the same process namespace with the host Amazon EC2 instance.
If task is specified, all containers within the specified task share the same process namespace.
If no value is specified, the default is a private namespace for each container. For more information, see [PID settings] in the *Docker run reference*.
If the host PID mode is used, there’s a heightened risk of undesired process namespace exposure. For more information, see [Docker security].
<note markdown=“1”> This parameter is not supported for Windows containers.
</note>
<note markdown=“1”> This parameter is only supported for tasks that are hosted on Fargate if the tasks are using platform version 1.4.0 or later (Linux). This isn’t supported for Windows containers on Fargate.
</note>
[1]: docs.docker.com/engine/reference/run/#pid-settings—pid [2]: docs.docker.com/engine/security/security/
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#placement_constraints ⇒ Array<Types::TaskDefinitionPlacementConstraint>
An array of placement constraint objects to use for tasks.
<note markdown=“1”> This parameter isn’t supported for tasks run on Fargate.
</note>
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration details for the App Mesh proxy.
Your Amazon ECS container instances require at least version 1.26.0 of the container agent and at least version 1.26.0-1 of the ecs-init package to use a proxy configuration. If your container instances are launched from the Amazon ECS optimized AMI version 20190301 or later, they contain the required versions of the container agent and ecs-init. For more information, see [Amazon ECS-optimized Linux AMI] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#registered_at ⇒ Time
The Unix timestamp for the time when the task definition was registered.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#registered_by ⇒ String
The principal that registered the task definition.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#requires_attributes ⇒ Array<Types::Attribute>
The container instance attributes required by your task. When an Amazon EC2 instance is registered to your cluster, the Amazon ECS container agent assigns some standard attributes to the instance. You can apply custom attributes. These are specified as key-value pairs using the Amazon ECS console or the PutAttributes API. These attributes are used when determining task placement for tasks hosted on Amazon EC2 instances. For more information, see [Attributes] in the *Amazon Elastic Container Service Developer Guide*.
<note markdown=“1”> This parameter isn’t supported for tasks run on Fargate.
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html#attributes
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#requires_compatibilities ⇒ Array<String>
The task launch types the task definition was validated against. The valid values are EC2, FARGATE, and EXTERNAL. For more information, see [Amazon ECS launch types] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Integer
The revision of the task in a particular family. The revision is a version number of a task definition in a family. When you register a task definition for the first time, the revision is 1. Each time that you register a new revision of a task definition in the same family, the revision value always increases by one. This is even if you deregistered previous revisions in this family.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#runtime_platform ⇒ Types::RuntimePlatform
The operating system that your task definitions are running on. A platform family is specified only for tasks using the Fargate launch type.
When you specify a task in a service, this value must match the runtimePlatform value of the service.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the task definition.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the task definition.
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the Identity and Access Management role that grants containers in the task permission to call Amazon Web Services APIs on your behalf. For more information, see [Amazon ECS Task Role] in the *Amazon Elastic Container Service Developer Guide*.
IAM roles for tasks on Windows require that the -EnableTaskIAMRole option is set when you launch the Amazon ECS-optimized Windows AMI. Your containers must also run some configuration code to use the feature. For more information, see [Windows IAM roles for tasks] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/windows_task_IAM_roles.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
The list of data volume definitions for the task. For more information, see [Using data volumes in tasks] in the *Amazon Elastic Container Service Developer Guide*.
<note markdown=“1”> The host and sourcePath parameters aren’t supported for tasks run on Fargate.
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/using_data_volumes.html
11227 11228 11229 11230 11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 11252 11253 11254 |
# File 'lib/aws-sdk-ecs/types.rb', line 11227 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :runtime_platform, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration, :registered_at, :deregistered_at, :registered_by, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |