Class: Aws::ECS::Types::TaskDefinitionPlacementConstraint
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskDefinitionPlacementConstraint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass TaskDefinitionPlacementConstraint data as a hash:
{
type: "memberOf", # accepts memberOf
expression: "String",
}
An object representing a constraint on task placement in the task definition. For more information, see [Task Placement Constraints] in the *Amazon Elastic Container Service Developer Guide*.
<note markdown=“1”> If you are using the Fargate launch type, task placement constraints are not supported.
</note>
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html
Instance Attribute Summary collapse
-
#expression ⇒ String
A cluster query language expression to apply to the constraint.
-
#type ⇒ String
The type of constraint.
Instance Attribute Details
#expression ⇒ String
A cluster query language expression to apply to the constraint. For more information, see [Cluster Query Language] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html
9268 9269 9270 9271 9272 |
# File 'lib/aws-sdk-ecs/types.rb', line 9268 class TaskDefinitionPlacementConstraint < Struct.new( :type, :expression) include Aws::Structure end |
#type ⇒ String
The type of constraint. The MemberOf constraint restricts selection to be from a group of valid candidates.
9268 9269 9270 9271 9272 |
# File 'lib/aws-sdk-ecs/types.rb', line 9268 class TaskDefinitionPlacementConstraint < Struct.new( :type, :expression) include Aws::Structure end |