Class: Aws::ECS::Types::TaskOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The overrides that are associated with a task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_overrides ⇒ Array<Types::ContainerOverride>
One or more container overrides that are sent to a task.
-
#cpu ⇒ String
The CPU override for the task.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The ephemeral storage setting override for the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role override for the task.
-
#inference_accelerator_overrides ⇒ Array<Types::InferenceAcceleratorOverride>
The Elastic Inference accelerator override for the task.
-
#memory ⇒ String
The memory override for the task.
-
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that containers in this task can assume.
Instance Attribute Details
#container_overrides ⇒ Array<Types::ContainerOverride>
One or more container overrides that are sent to a task.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#cpu ⇒ String
The CPU override for the task.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The ephemeral storage setting override for the task.
-
Linux platform version
1.4.0or later. -
Windows platform version
1.0.0or later.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role override for the task. For more information, see Amazon ECS task execution IAM role in the Amazon Elastic Container Service Developer Guide.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#inference_accelerator_overrides ⇒ Array<Types::InferenceAcceleratorOverride>
The Elastic Inference accelerator override for the task.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The memory override for the task.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role. For more information, see IAM Role for Tasks in the Amazon Elastic Container Service Developer Guide.
17948 17949 17950 17951 17952 17953 17954 17955 17956 17957 17958 |
# File 'lib/aws-sdk-ecs/types.rb', line 17948 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |