Class: Aws::ECS::Types::TaskSet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about a set of Amazon ECS tasks in either an AWS CodeDeploy or an EXTERNAL deployment. An Amazon ECS task set includes details such as the desired number of tasks, how many tasks are running, and whether the task set serves production traffic.

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_provider_strategyArray<Types::CapacityProviderStrategyItem>

The capacity provider strategy associated with the task set.



9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) of the cluster that the service that hosts the task set exists in.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#computed_desired_countInteger

The computed desired count for the task set. This is calculated by multiplying the service’s desiredCount by the task set’s scale percentage. The result is always rounded up. For example, if the computed desired count is 1.2, it rounds up to 2 tasks.

Returns:

  • (Integer)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#created_atTime

The Unix timestamp for when the task set was created.

Returns:

  • (Time)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#external_idString

The external ID associated with the task set.

If a task set is created by an AWS CodeDeploy deployment, the externalId parameter contains the AWS CodeDeploy deployment ID.

If a task set is created for an external deployment and is associated with a service discovery registry, the externalId parameter contains the ECS_TASK_SET_EXTERNAL_ID AWS Cloud Map attribute.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#idString

The ID of the task set.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#launch_typeString

The launch type the tasks in the task set are using. For more information, see [Amazon ECS Launch Types] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#load_balancersArray<Types::LoadBalancer>

Details on a load balancer that is used with a task set.

Returns:



9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

The network configuration for the task set.



9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#pending_countInteger

The number of tasks in the task set that are in the PENDING status during a deployment. A task in the PENDING state is preparing to enter the RUNNING state. A task set enters the PENDING status when it launches for the first time or when it is restarted after being in the STOPPED state.

Returns:

  • (Integer)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#platform_versionString

The platform version on which the tasks in the task set are running. A platform version is only specified for tasks using the Fargate launch type. If one is not specified, the LATEST platform version is used by default. For more information, see [AWS Fargate Platform Versions] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#running_countInteger

The number of tasks in the task set that are in the RUNNING status during a deployment. A task in the RUNNING state is running and ready for use.

Returns:

  • (Integer)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#scaleTypes::Scale

A floating-point percentage of the desired number of tasks to place and keep running in the task set.

Returns:



9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#service_arnString

The Amazon Resource Name (ARN) of the service the task set exists in.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#service_registriesArray<Types::ServiceRegistry>

The details of the service discovery registries to assign to this task set. For more information, see [Service Discovery].

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html

Returns:



9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#stability_statusString

The stability status, which indicates whether the task set has reached a steady state. If the following conditions are met, the task set will be in STEADY_STATE:

  • The task runningCount is equal to the computedDesiredCount.

  • The pendingCount is 0.

  • There are no tasks running on container instances in the DRAINING status.

  • All tasks are reporting a healthy status from the load balancers, service discovery, and container health checks.

If any of those conditions are not met, the stability status returns STABILIZING.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#stability_status_atTime

The Unix timestamp for when the task set stability status was retrieved.

Returns:

  • (Time)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#started_byString

The tag specified when a task set is started. If the task set is created by an AWS CodeDeploy deployment, the startedBy parameter is CODE_DEPLOY. For a task set created for an external deployment, the startedBy field isn’t used.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#statusString

The status of the task set. The following describes each state:

PRIMARY

: The task set is serving production traffic.

ACTIVE

: The task set is not serving production traffic.

DRAINING

: The tasks in the task set are being stopped and their

corresponding targets are being deregistered from their target
group.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#task_definitionString

The task definition the task set is using.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#task_set_arnString

The Amazon Resource Name (ARN) of the task set.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for when the task set was last updated.

Returns:

  • (Time)


9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
# File 'lib/aws-sdk-ecs/types.rb', line 9520

class TaskSet < Struct.new(
  :id,
  :task_set_arn,
  :service_arn,
  :cluster_arn,
  :started_by,
  :external_id,
  :status,
  :task_definition,
  :computed_desired_count,
  :pending_count,
  :running_count,
  :created_at,
  :updated_at,
  :launch_type,
  :capacity_provider_strategy,
  :platform_version,
  :network_configuration,
  :load_balancers,
  :service_registries,
  :scale,
  :stability_status,
  :stability_status_at)
  include Aws::Structure
end