Class: Aws::ECS::Types::TaskSetNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskSetNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The specified task set wasn't found. You can view your available task sets with DescribeTaskSets. Task sets are specific to each cluster, service and Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Message that describes the cause of the exception.
Instance Attribute Details
#message ⇒ String
Message that describes the cause of the exception.
18165 18166 18167 18168 18169 |
# File 'lib/aws-sdk-ecs/types.rb', line 18165 class TaskSetNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |