Class: Aws::ECS::Types::ThresholdConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ThresholdConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Defines the failure threshold that the deployment circuit breaker uses
to monitor a deployment. The type and value together determine the
number of task failures that are tolerated before the circuit breaker
triggers.
By default, the threshold configuration uses a type of
BOUNDED_PERCENT with a value of 50.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
Determines how Amazon ECS uses
valueto calculate the failure threshold. -
#value ⇒ Integer
Specifies the integer that Amazon ECS uses to calculate the failure threshold.
Instance Attribute Details
#type ⇒ String
Determines how Amazon ECS uses value to calculate the failure
threshold. For the percentage types (BOUNDED_PERCENT and
UNBOUNDED_PERCENT), Amazon ECS multiplies value by the latest
service desired count. For COUNT, Amazon ECS uses value directly
as the threshold. The default is BOUNDED_PERCENT.
18271 18272 18273 18274 18275 18276 |
# File 'lib/aws-sdk-ecs/types.rb', line 18271 class ThresholdConfiguration < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Integer
Specifies the integer that Amazon ECS uses to calculate the failure
threshold. When type is COUNT, this value is the failure
threshold itself. When type is a percentage type, Amazon ECS
multiplies this value by the latest service desired count to produce
the failure threshold. The default is 50.
18271 18272 18273 18274 18275 18276 |
# File 'lib/aws-sdk-ecs/types.rb', line 18271 class ThresholdConfiguration < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |