Class: Aws::ECS::Types::TotalLocalStorageGBRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The minimum and maximum total local storage in gigabytes (GB) for instance types with local storage. This is useful for workloads that require local storage for temporary data or caching.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maxFloat

The maximum total local storage in GB. Instance types with more local storage are excluded from selection.

Returns:

  • (Float)


18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-ecs/types.rb', line 18312

class TotalLocalStorageGBRequest < Struct.new(
  :min,
  :max)
  SENSITIVE = []
  include Aws::Structure
end

#minFloat

The minimum total local storage in GB. Instance types with less local storage are excluded from selection.

Returns:

  • (Float)


18312
18313
18314
18315
18316
18317
# File 'lib/aws-sdk-ecs/types.rb', line 18312

class TotalLocalStorageGBRequest < Struct.new(
  :min,
  :max)
  SENSITIVE = []
  include Aws::Structure
end