Class: Aws::ECS::Types::UpdateCapacityProviderRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_group_providerTypes::AutoScalingGroupProviderUpdate

An object that represent the parameters to update for the Auto Scaling group capacity provider.



16080
16081
16082
16083
16084
16085
16086
16087
# File 'lib/aws-sdk-ecs/types.rb', line 16080

class UpdateCapacityProviderRequest < Struct.new(
  :name,
  :cluster,
  :auto_scaling_group_provider,
  :managed_instances_provider)
  SENSITIVE = []
  include Aws::Structure
end

#clusterString

The name of the cluster that contains the capacity provider to update. Managed instances capacity providers are cluster-scoped and can only be updated within their associated cluster.

Returns:

  • (String)


16080
16081
16082
16083
16084
16085
16086
16087
# File 'lib/aws-sdk-ecs/types.rb', line 16080

class UpdateCapacityProviderRequest < Struct.new(
  :name,
  :cluster,
  :auto_scaling_group_provider,
  :managed_instances_provider)
  SENSITIVE = []
  include Aws::Structure
end

#managed_instances_providerTypes::UpdateManagedInstancesProviderConfiguration

The updated configuration for the Amazon ECS Managed Instances provider. You can modify the infrastructure role, instance launch template, and tag propagation settings. Changes take effect for new instances launched after the update.



16080
16081
16082
16083
16084
16085
16086
16087
# File 'lib/aws-sdk-ecs/types.rb', line 16080

class UpdateCapacityProviderRequest < Struct.new(
  :name,
  :cluster,
  :auto_scaling_group_provider,
  :managed_instances_provider)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the capacity provider to update.

Returns:

  • (String)


16080
16081
16082
16083
16084
16085
16086
16087
# File 'lib/aws-sdk-ecs/types.rb', line 16080

class UpdateCapacityProviderRequest < Struct.new(
  :name,
  :cluster,
  :auto_scaling_group_provider,
  :managed_instances_provider)
  SENSITIVE = []
  include Aws::Structure
end