Class: Aws::ECS::Types::UpdateClusterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateClusterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The name of the cluster to modify the settings for.
-
#configuration ⇒ Types::ClusterConfiguration
The execute command configuration for the cluster.
-
#service_connect_defaults ⇒ Types::ClusterServiceConnectDefaultsRequest
Use this parameter to set a default Service Connect namespace.
-
#settings ⇒ Array<Types::ClusterSetting>
The cluster settings for your cluster.
Instance Attribute Details
#cluster ⇒ String
The name of the cluster to modify the settings for.
18527 18528 18529 18530 18531 18532 18533 18534 |
# File 'lib/aws-sdk-ecs/types.rb', line 18527 class UpdateClusterRequest < Struct.new( :cluster, :settings, :configuration, :service_connect_defaults) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::ClusterConfiguration
The execute command configuration for the cluster.
18527 18528 18529 18530 18531 18532 18533 18534 |
# File 'lib/aws-sdk-ecs/types.rb', line 18527 class UpdateClusterRequest < Struct.new( :cluster, :settings, :configuration, :service_connect_defaults) SENSITIVE = [] include Aws::Structure end |
#service_connect_defaults ⇒ Types::ClusterServiceConnectDefaultsRequest
Use this parameter to set a default Service Connect namespace. After
you set a default Service Connect namespace, any new services with
Service Connect turned on that are created in the cluster are added
as client services in the namespace. This setting only applies to
new services that set the enabled parameter to true in the
ServiceConnectConfiguration. You can set the namespace of each
service individually in the ServiceConnectConfiguration to
override this default parameter.
Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see Service Connect in the Amazon Elastic Container Service Developer Guide.
18527 18528 18529 18530 18531 18532 18533 18534 |
# File 'lib/aws-sdk-ecs/types.rb', line 18527 class UpdateClusterRequest < Struct.new( :cluster, :settings, :configuration, :service_connect_defaults) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Array<Types::ClusterSetting>
The cluster settings for your cluster.
18527 18528 18529 18530 18531 18532 18533 18534 |
# File 'lib/aws-sdk-ecs/types.rb', line 18527 class UpdateClusterRequest < Struct.new( :cluster, :settings, :configuration, :service_connect_defaults) SENSITIVE = [] include Aws::Structure end |