Class: Aws::ECS::Types::UpdateClusterSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateClusterSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The name of the cluster to modify the settings for.
-
#settings ⇒ Array<Types::ClusterSetting>
The setting to use by default for a cluster.
Instance Attribute Details
#cluster ⇒ String
The name of the cluster to modify the settings for.
18136 18137 18138 18139 18140 18141 |
# File 'lib/aws-sdk-ecs/types.rb', line 18136 class UpdateClusterSettingsRequest < Struct.new( :cluster, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Array<Types::ClusterSetting>
The setting to use by default for a cluster. This parameter is used to turn on CloudWatch Container Insights for a cluster. If this value is specified, it overrides the ‘containerInsights` value set with [PutAccountSetting] or [PutAccountSettingDefault].
Currently, if you delete an existing cluster that does not have Container Insights turned on, and then create a new cluster with the same name with Container Insights tuned on, Container Insights will not actually be turned on. If you want to preserve the same name for your existing cluster and turn on Container Insights, you must wait 7 days before you can re-create it.
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSetting.html [2]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSettingDefault.html
18136 18137 18138 18139 18140 18141 |
# File 'lib/aws-sdk-ecs/types.rb', line 18136 class UpdateClusterSettingsRequest < Struct.new( :cluster, :settings) SENSITIVE = [] include Aws::Structure end |