Class: Aws::ECS::Types::UpdateDaemonResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The Unix timestamp for the time when the daemon was created.

Returns:

  • (Time)


18332
18333
18334
18335
18336
18337
18338
18339
18340
# File 'lib/aws-sdk-ecs/types.rb', line 18332

class UpdateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_arnString

The Amazon Resource Name (ARN) of the daemon.

Returns:

  • (String)


18332
18333
18334
18335
18336
18337
18338
18339
18340
# File 'lib/aws-sdk-ecs/types.rb', line 18332

class UpdateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_arnString

The Amazon Resource Name (ARN) of the daemon deployment that was triggered by the update.

Returns:

  • (String)


18332
18333
18334
18335
18336
18337
18338
18339
18340
# File 'lib/aws-sdk-ecs/types.rb', line 18332

class UpdateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the daemon.

Returns:

  • (String)


18332
18333
18334
18335
18336
18337
18338
18339
18340
# File 'lib/aws-sdk-ecs/types.rb', line 18332

class UpdateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for the time when the daemon was last updated.

Returns:

  • (Time)


18332
18333
18334
18335
18336
18337
18338
18339
18340
# File 'lib/aws-sdk-ecs/types.rb', line 18332

class UpdateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end