Class: Aws::ECS::Types::UpdateInProgressException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

There’s already a current Amazon ECS container agent update in progress on the container instance that’s specified. If the container agent becomes disconnected while it’s in a transitional stage, such as ‘PENDING` or `STAGING`, the update process can get stuck in that state. However, when the agent reconnects, it resumes where it stopped previously.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Message that describes the cause of the exception.

Returns:

  • (String)


18425
18426
18427
18428
18429
# File 'lib/aws-sdk-ecs/types.rb', line 18425

class UpdateInProgressException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end