Class: Aws::ECS::Types::UpdateManagedInstancesProviderConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateManagedInstancesProviderConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The updated configuration for a Amazon ECS Managed Instances provider. You can modify the infrastructure role, instance launch template, and tag propagation settings. Changes apply to new instances launched after the update.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#infrastructure_optimization ⇒ Types::InfrastructureOptimization
The updated infrastructure optimization configuration.
-
#infrastructure_role_arn ⇒ String
The updated Amazon Resource Name (ARN) of the infrastructure role.
-
#instance_launch_template ⇒ Types::InstanceLaunchTemplateUpdate
The updated launch template configuration.
-
#propagate_tags ⇒ String
The updated tag propagation setting.
Instance Attribute Details
#infrastructure_optimization ⇒ Types::InfrastructureOptimization
The updated infrastructure optimization configuration. Changes to this setting affect how Amazon ECS optimizes instances going forward.
16374 16375 16376 16377 16378 16379 16380 16381 |
# File 'lib/aws-sdk-ecs/types.rb', line 16374 class UpdateManagedInstancesProviderConfiguration < Struct.new( :infrastructure_role_arn, :instance_launch_template, :propagate_tags, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |
#infrastructure_role_arn ⇒ String
The updated Amazon Resource Name (ARN) of the infrastructure role. The new role must have the necessary permissions to manage instances and access required Amazon Web Services services.
For more information, see [Amazon ECS infrastructure IAM role] in the *Amazon ECS Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/infrastructure_IAM_role.html
16374 16375 16376 16377 16378 16379 16380 16381 |
# File 'lib/aws-sdk-ecs/types.rb', line 16374 class UpdateManagedInstancesProviderConfiguration < Struct.new( :infrastructure_role_arn, :instance_launch_template, :propagate_tags, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |
#instance_launch_template ⇒ Types::InstanceLaunchTemplateUpdate
The updated launch template configuration. Changes to the launch template affect new instances launched after the update, while existing instances continue to use their original configuration.
16374 16375 16376 16377 16378 16379 16380 16381 |
# File 'lib/aws-sdk-ecs/types.rb', line 16374 class UpdateManagedInstancesProviderConfiguration < Struct.new( :infrastructure_role_arn, :instance_launch_template, :propagate_tags, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |
#propagate_tags ⇒ String
The updated tag propagation setting. When changed, this affects only new instances launched after the update.
16374 16375 16376 16377 16378 16379 16380 16381 |
# File 'lib/aws-sdk-ecs/types.rb', line 16374 class UpdateManagedInstancesProviderConfiguration < Struct.new( :infrastructure_role_arn, :instance_launch_template, :propagate_tags, :infrastructure_optimization) SENSITIVE = [] include Aws::Structure end |