Class: Aws::ECS::Types::UpdateServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass UpdateServiceRequest data as a hash:

{
  cluster: "String",
  service: "String", # required
  desired_count: 1,
  task_definition: "String",
  capacity_provider_strategy: [
    {
      capacity_provider: "String", # required
      weight: 1,
      base: 1,
    },
  ],
  deployment_configuration: {
    maximum_percent: 1,
    minimum_healthy_percent: 1,
  },
  network_configuration: {
    awsvpc_configuration: {
      subnets: ["String"], # required
      security_groups: ["String"],
      assign_public_ip: "ENABLED", # accepts ENABLED, DISABLED
    },
  },
  platform_version: "String",
  force_new_deployment: false,
  health_check_grace_period_seconds: 1,
}

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_provider_strategyArray<Types::CapacityProviderStrategyItem>

The capacity provider strategy to update the service to use.

If the service is using the default capacity provider strategy for the cluster, the service can be updated to use one or more capacity providers. However, when a service is using a non-default capacity provider strategy, the service cannot be updated to use the cluster’s default capacity provider strategy.



9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that your service is running on. If you do not specify a cluster, the default cluster is assumed.

Returns:

  • (String)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#deployment_configurationTypes::DeploymentConfiguration

Optional deployment parameters that control how many tasks run during the deployment and the ordering of stopping and starting tasks.



9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#desired_countInteger

The number of instantiations of the task to place and keep running in your service.

Returns:

  • (Integer)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#force_new_deploymentBoolean

Whether to force a new deployment of the service. Deployments are not forced by default. You can use this option to trigger a new deployment with no service definition changes. For example, you can update a service’s tasks to use a newer Docker image with the same image/tag combination (my_image:latest) or to roll Fargate tasks onto a newer platform version.

Returns:

  • (Boolean)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#health_check_grace_period_secondsInteger

The period of time, in seconds, that the Amazon ECS service scheduler should ignore unhealthy Elastic Load Balancing target health checks after a task has first started. This is only valid if your service is configured to use a load balancer. If your service’s tasks take a while to start and respond to Elastic Load Balancing health checks, you can specify a health check grace period of up to 2,147,483,647 seconds. During that time, the Amazon ECS service scheduler ignores the Elastic Load Balancing health check status. This grace period can prevent the ECS service scheduler from marking tasks as unhealthy and stopping them before they have time to come up.

Returns:

  • (Integer)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#network_configurationTypes::NetworkConfiguration

An object representing the network configuration for a task or service.



9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#platform_versionString

The platform version on which your tasks in the service are running. A platform version is only specified for tasks using the Fargate launch type. If a platform version is not specified, the LATEST platform version is used by default. For more information, see [AWS Fargate Platform Versions] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html

Returns:

  • (String)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#serviceString

The name of the service to update.

Returns:

  • (String)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end

#task_definitionString

The family and revision (family:revision) or full ARN of the task definition to run in your service. If a revision is not specified, the latest ACTIVE revision is used. If you modify the task definition with UpdateService, Amazon ECS spawns a task with the new version of the task definition and then stops an old task after the new version is running.

Returns:

  • (String)


9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
# File 'lib/aws-sdk-ecs/types.rb', line 9950

class UpdateServiceRequest < Struct.new(
  :cluster,
  :service,
  :desired_count,
  :task_definition,
  :capacity_provider_strategy,
  :deployment_configuration,
  :network_configuration,
  :platform_version,
  :force_new_deployment,
  :health_check_grace_period_seconds)
  include Aws::Structure
end