Class: Aws::ECS::Types::UpdateServiceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

<zonbook />

<xhtml />

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#serviceTypes::Service

The full description of your service following the update call.

The response includes a ‘lifecycleHookDetails` field, which is an empty array when the service is created or updated. The values are populated when a lifecycle hook executes and are available as part of the service deployment details ([DescribeServiceDeployments]).

[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServiceDeployments.html

Returns:



19097
19098
19099
19100
19101
# File 'lib/aws-sdk-ecs/types.rb', line 19097

class UpdateServiceResponse < Struct.new(
  :service)
  SENSITIVE = []
  include Aws::Structure
end