Class: Aws::ECS::Types::UpdateTaskProtectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateTaskProtectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
-
#expires_in_minutes ⇒ Integer
If you set
protectionEnabledtotrue, you can specify the duration for task protection in minutes. -
#protection_enabled ⇒ Boolean
Specify
trueto mark a task for protection andfalseto unset protection, making it eligible for termination. -
#tasks ⇒ Array<String>
A list of up to 10 task IDs or full ARN entries.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
16789 16790 16791 16792 16793 16794 16795 16796 |
# File 'lib/aws-sdk-ecs/types.rb', line 16789 class UpdateTaskProtectionRequest < Struct.new( :cluster, :tasks, :protection_enabled, :expires_in_minutes) SENSITIVE = [] include Aws::Structure end |
#expires_in_minutes ⇒ Integer
If you set protectionEnabled to true, you can specify the duration for task protection in minutes. You can specify a value from 1 minute to up to 2,880 minutes (48 hours). During this time, your task will not be terminated by scale-in events from Service Auto Scaling or deployments. After this time period lapses, protectionEnabled will be reset to false.
If you don’t specify the time, then the task is automatically protected for 120 minutes (2 hours).
16789 16790 16791 16792 16793 16794 16795 16796 |
# File 'lib/aws-sdk-ecs/types.rb', line 16789 class UpdateTaskProtectionRequest < Struct.new( :cluster, :tasks, :protection_enabled, :expires_in_minutes) SENSITIVE = [] include Aws::Structure end |
#protection_enabled ⇒ Boolean
Specify true to mark a task for protection and false to unset protection, making it eligible for termination.
16789 16790 16791 16792 16793 16794 16795 16796 |
# File 'lib/aws-sdk-ecs/types.rb', line 16789 class UpdateTaskProtectionRequest < Struct.new( :cluster, :tasks, :protection_enabled, :expires_in_minutes) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<String>
A list of up to 10 task IDs or full ARN entries.
16789 16790 16791 16792 16793 16794 16795 16796 |
# File 'lib/aws-sdk-ecs/types.rb', line 16789 class UpdateTaskProtectionRequest < Struct.new( :cluster, :tasks, :protection_enabled, :expires_in_minutes) SENSITIVE = [] include Aws::Structure end |