Class: Aws::ECS::Types::VpcLatticeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::VpcLatticeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The VPC Lattice configuration for your service that holds the information for the target group(s) Amazon ECS tasks will be registered to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#port_name ⇒ String
The name of the port mapping to register in the VPC Lattice target group.
-
#role_arn ⇒ String
The ARN of the IAM role to associate with this VPC Lattice configuration.
-
#target_group_arn ⇒ String
The full Amazon Resource Name (ARN) of the target group or groups associated with the VPC Lattice configuration that the Amazon ECS tasks will be registered to.
Instance Attribute Details
#port_name ⇒ String
The name of the port mapping to register in the VPC Lattice target group. This is the name of the ‘portMapping` you defined in your task definition.
19646 19647 19648 19649 19650 19651 19652 |
# File 'lib/aws-sdk-ecs/types.rb', line 19646 class VpcLatticeConfiguration < Struct.new( :role_arn, :target_group_arn, :port_name) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role to associate with this VPC Lattice configuration. This is the Amazon ECS infrastructure IAM role that is used to manage your VPC Lattice infrastructure.
19646 19647 19648 19649 19650 19651 19652 |
# File 'lib/aws-sdk-ecs/types.rb', line 19646 class VpcLatticeConfiguration < Struct.new( :role_arn, :target_group_arn, :port_name) SENSITIVE = [] include Aws::Structure end |
#target_group_arn ⇒ String
The full Amazon Resource Name (ARN) of the target group or groups associated with the VPC Lattice configuration that the Amazon ECS tasks will be registered to.
19646 19647 19648 19649 19650 19651 19652 |
# File 'lib/aws-sdk-ecs/types.rb', line 19646 class VpcLatticeConfiguration < Struct.new( :role_arn, :target_group_arn, :port_name) SENSITIVE = [] include Aws::Structure end |