Class: Aws::ECS::Waiters::DaemonActive
- Inherits:
-
Object
- Object
- Aws::ECS::Waiters::DaemonActive
- Defined in:
- lib/aws-sdk-ecs/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DaemonActive
constructor
A new instance of DaemonActive.
-
#wait(params = {}) ⇒ Types::DescribeDaemonResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DaemonActive
Returns a new instance of DaemonActive.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 92 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 8, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_daemon, acceptors: [ { "matcher" => "path", "argument" => "daemon.status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "daemon.status", "state" => "failure", "expected" => "DELETE_IN_PROGRESS" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
124 125 126 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 124 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeDaemonResponse
Returns a response object which responds to the following methods:
-
#daemon => Types::DaemonDetail
119 120 121 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 119 def wait(params = {}) @waiter.wait(client: @client, params: params) end |