Class: Aws::ECS::Waiters::DaemonTaskDefinitionActive

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ecs/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ DaemonTaskDefinitionActive

Returns a new instance of DaemonTaskDefinitionActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 8
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


242
243
# File 'lib/aws-sdk-ecs/waiters.rb', line 242

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



280
281
282
# File 'lib/aws-sdk-ecs/waiters.rb', line 280

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeDaemonTaskDefinitionResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :daemon_task_definition (required, String)

    The family for the latest ACTIVE revision, family and revision (family:revision) for a specific revision in the family, or full Amazon Resource Name (ARN) of the daemon task definition to describe.

Returns:



275
# File 'lib/aws-sdk-ecs/waiters.rb', line 275

def wait: (