Class: Aws::ECS::Waiters::DaemonTaskDefinitionDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ecs/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ DaemonTaskDefinitionDeleted

Returns a new instance of DaemonTaskDefinitionDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 8
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/aws-sdk-ecs/waiters.rb', line 292

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 8,
    delay: 15,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_daemon_task_definition,
      acceptors: [{
        "matcher" => "path",
        "argument" => "daemon_task_definition.status",
        "state" => "success",
        "expected" => "DELETED"
      }]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



316
317
318
# File 'lib/aws-sdk-ecs/waiters.rb', line 316

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeDaemonTaskDefinitionResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :daemon_task_definition (required, String)

    The ‘family` for the latest `ACTIVE` revision, `family` and `revision` (`family:revision`) for a specific revision in the family, or full Amazon Resource Name (ARN) of the daemon task definition to describe.

Returns:



311
312
313
# File 'lib/aws-sdk-ecs/waiters.rb', line 311

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end