Class: Aws::ECS::Waiters::TasksStopped

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-ecs/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ TasksStopped

Returns a new instance of TasksStopped.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 100
  • :delay (Integer) — default: 6
  • :before_attempt (Proc)
  • :before_wait (Proc)


478
479
# File 'lib/aws-sdk-ecs/waiters.rb', line 478

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



502
503
504
# File 'lib/aws-sdk-ecs/waiters.rb', line 502

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeTasksResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :cluster (String)

    The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task or tasks to describe. If you do not specify a cluster, the default cluster is assumed.

  • :tasks (required, Array<String>)

    A list of up to 100 task IDs or full ARN entries.

  • :include (Array<String>)

    Specifies whether you want to see the resource tags for the task. If TAGS is specified, the tags are included in the response. If this field is omitted, tags aren't included in the response.

Returns:



497
# File 'lib/aws-sdk-ecs/waiters.rb', line 497

def wait: (