Class: Aws::ECS::Types::CapacityProviderStrategyItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CapacityProviderStrategyItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass CapacityProviderStrategyItem data as a hash:
{
capacity_provider: "String", # required
weight: 1,
base: 1,
}
The details of a capacity provider strategy.
Instance Attribute Summary collapse
-
#base ⇒ Integer
The base value designates how many tasks, at a minimum, to run on the specified capacity provider.
-
#capacity_provider ⇒ String
The short name or full Amazon Resource Name (ARN) of the capacity provider.
-
#weight ⇒ Integer
The weight value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider.
Instance Attribute Details
#base ⇒ Integer
The base value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a base defined.
326 327 328 329 330 331 |
# File 'lib/aws-sdk-ecs/types.rb', line 326 class CapacityProviderStrategyItem < Struct.new( :capacity_provider, :weight, :base) include Aws::Structure end |
#capacity_provider ⇒ String
The short name or full Amazon Resource Name (ARN) of the capacity provider.
326 327 328 329 330 331 |
# File 'lib/aws-sdk-ecs/types.rb', line 326 class CapacityProviderStrategyItem < Struct.new( :capacity_provider, :weight, :base) include Aws::Structure end |
#weight ⇒ Integer
The weight value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider.
For example, if you have a strategy that contains two capacity providers and both have a weight of 1, then when the base is satisfied, the tasks will be split evenly across the two capacity providers. Using that same logic, if you specify a weight of 1 for capacityProviderA and a weight of 4 for capacityProviderB, then for every one task that is run using capacityProviderA, four tasks would use capacityProviderB.
326 327 328 329 330 331 |
# File 'lib/aws-sdk-ecs/types.rb', line 326 class CapacityProviderStrategyItem < Struct.new( :capacity_provider, :weight, :base) include Aws::Structure end |