Class: Aws::ECS::Types::CapacityReservationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CapacityReservationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The Capacity Reservation configurations to be used when using the RESERVED capacity option type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reservation_group_arn ⇒ String
The ARN of the Capacity Reservation resource group in which to run the instance.
-
#reservation_preference ⇒ String
The preference on when capacity reservations should be used.
Instance Attribute Details
#reservation_group_arn ⇒ String
The ARN of the Capacity Reservation resource group in which to run the instance.
704 705 706 707 708 709 |
# File 'lib/aws-sdk-ecs/types.rb', line 704 class CapacityReservationRequest < Struct.new( :reservation_group_arn, :reservation_preference) SENSITIVE = [] include Aws::Structure end |
#reservation_preference ⇒ String
The preference on when capacity reservations should be used.
Valid values are:
-
RESERVATIONS_ONLY- Exclusively launch instances into capacity reservations that match the instance requirements configured for the capacity provider. If none exist, instances will fail to provision. -
RESERVATIONS_FIRST- Prefer to launch instances into a capacity reservation if any exist that match the instance requirements configured for the capacity provider. If none exist, fall back to launching instances On-Demand. -
RESERVATIONS_EXCLUDED- Avoid using capacity reservations and launch exclusively On-Demand.
704 705 706 707 708 709 |
# File 'lib/aws-sdk-ecs/types.rb', line 704 class CapacityReservationRequest < Struct.new( :reservation_group_arn, :reservation_preference) SENSITIVE = [] include Aws::Structure end |