Class: Aws::ECS::Types::ClusterContainsContainerInstancesException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ClusterContainsContainerInstancesException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
You can’t delete a cluster that has registered container instances. First, deregister the container instances before you can delete the cluster. For more information, see [DeregisterContainerInstance].
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeregisterContainerInstance.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Message that describes the cause of the exception.
Instance Attribute Details
#message ⇒ String
Message that describes the cause of the exception.
1044 1045 1046 1047 1048 |
# File 'lib/aws-sdk-ecs/types.rb', line 1044 class ClusterContainsContainerInstancesException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |