Class: Aws::ECS::Types::CreateDaemonResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The Unix timestamp for the time when the daemon was created.

Returns:

  • (Time)


3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-ecs/types.rb', line 3104

class CreateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_arnString

The Amazon Resource Name (ARN) of the daemon.

Returns:

  • (String)


3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-ecs/types.rb', line 3104

class CreateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_arnString

The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.

Returns:

  • (String)


3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-ecs/types.rb', line 3104

class CreateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the daemon.

Returns:

  • (String)


3104
3105
3106
3107
3108
3109
3110
3111
# File 'lib/aws-sdk-ecs/types.rb', line 3104

class CreateDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end