Class: Aws::ECS::Types::CreateDaemonResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateDaemonResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The Unix timestamp for the time when the daemon was created.
-
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
-
#deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the initial daemon deployment.
-
#status ⇒ String
The status of the daemon.
Instance Attribute Details
#created_at ⇒ Time
The Unix timestamp for the time when the daemon was created.
3104 3105 3106 3107 3108 3109 3110 3111 |
# File 'lib/aws-sdk-ecs/types.rb', line 3104 class CreateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
3104 3105 3106 3107 3108 3109 3110 3111 |
# File 'lib/aws-sdk-ecs/types.rb', line 3104 class CreateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the initial daemon deployment. This deployment places daemon tasks on each container instance of the specified capacity providers.
3104 3105 3106 3107 3108 3109 3110 3111 |
# File 'lib/aws-sdk-ecs/types.rb', line 3104 class CreateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon.
3104 3105 3106 3107 3108 3109 3110 3111 |
# File 'lib/aws-sdk-ecs/types.rb', line 3104 class CreateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |