Class: Aws::ECS::Types::CreateManagedInstancesProviderConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The configuration for creating a Amazon ECS Managed Instances provider. This specifies how Amazon ECS should manage Amazon EC2 instances, including the infrastructure role, instance launch template, and whether to propagate tags from the capacity provider to the instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_repair_configurationTypes::AutoRepairConfiguration

The auto repair configuration for the Amazon ECS Managed Instances capacity provider. Use this to enable or disable automatic replacement of container instances that are detected as unhealthy.



3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-ecs/types.rb', line 3325

class CreateManagedInstancesProviderConfiguration < Struct.new(
  :infrastructure_role_arn,
  :instance_launch_template,
  :propagate_tags,
  :infrastructure_optimization,
  :auto_repair_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_optimizationTypes::InfrastructureOptimization

Defines how Amazon ECS Managed Instances optimizes the infrastastructure in your capacity provider. Provides control over the delay between when EC2 instances become idle or underutilized and when Amazon ECS optimizes them.



3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-ecs/types.rb', line 3325

class CreateManagedInstancesProviderConfiguration < Struct.new(
  :infrastructure_role_arn,
  :instance_launch_template,
  :propagate_tags,
  :infrastructure_optimization,
  :auto_repair_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_role_arnString

The Amazon Resource Name (ARN) of the infrastructure role that Amazon ECS uses to manage instances on your behalf. This role must have permissions to launch, terminate, and manage Amazon EC2 instances, as well as access to other Amazon Web Services services required for Amazon ECS Managed Instances functionality.

For more information, see [Amazon ECS infrastructure IAM role] in the *Amazon ECS Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/infrastructure_IAM_role.html

Returns:

  • (String)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-ecs/types.rb', line 3325

class CreateManagedInstancesProviderConfiguration < Struct.new(
  :infrastructure_role_arn,
  :instance_launch_template,
  :propagate_tags,
  :infrastructure_optimization,
  :auto_repair_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#instance_launch_templateTypes::InstanceLaunchTemplate

The launch template configuration that specifies how Amazon ECS should launch Amazon EC2 instances. This includes the instance profile, network configuration, storage settings, and instance requirements for attribute-based instance type selection.

For more information, see [Store instance launch parameters in Amazon EC2 launch templates] in the *Amazon EC2 User Guide*.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html



3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-ecs/types.rb', line 3325

class CreateManagedInstancesProviderConfiguration < Struct.new(
  :infrastructure_role_arn,
  :instance_launch_template,
  :propagate_tags,
  :infrastructure_optimization,
  :auto_repair_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#propagate_tagsString

Specifies whether to propagate tags from the capacity provider to the Amazon ECS Managed Instances. When enabled, tags applied to the capacity provider are automatically applied to all instances launched by this provider.

Returns:

  • (String)


3325
3326
3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-ecs/types.rb', line 3325

class CreateManagedInstancesProviderConfiguration < Struct.new(
  :infrastructure_role_arn,
  :instance_launch_template,
  :propagate_tags,
  :infrastructure_optimization,
  :auto_repair_configuration)
  SENSITIVE = []
  include Aws::Structure
end