Class: Aws::ECS::Types::CreateServiceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateServiceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service ⇒ Types::Service
The full description of your service following the create call.
Instance Attribute Details
#service ⇒ Types::Service
The full description of your service following the create call.
A service will return either a ‘capacityProviderStrategy` or `launchType` parameter, but not both, depending where one was specified when it was created.
If a service is using the ‘ECS` deployment controller, the `deploymentController` and `taskSets` parameters will not be returned.
if the service uses the ‘CODE_DEPLOY` deployment controller, the `deploymentController`, `taskSets` and `deployments` parameters will be returned, however the `deployments` parameter will be an empty list.
The response includes a ‘lifecycleHookDetails` field, which is an empty array when the service is created or updated. The values are populated when a lifecycle hook executes and are available as part of the service deployment details ([DescribeServiceDeployments]).
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServiceDeployments.html
3876 3877 3878 3879 3880 |
# File 'lib/aws-sdk-ecs/types.rb', line 3876 class CreateServiceResponse < Struct.new( :service) SENSITIVE = [] include Aws::Structure end |