Class: Aws::ECS::Types::CreateServiceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateServiceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Instance Attribute Summary collapse
-
#service ⇒ Types::Service
The full description of your service following the create call.
Instance Attribute Details
#service ⇒ Types::Service
The full description of your service following the create call.
If a service is using the ECS deployment controller, the deploymentController and taskSets parameters will not be returned.
If the service is using the CODE_DEPLOY deployment controller, the deploymentController, taskSets and deployments parameters will be returned, however the deployments parameter will be an empty list.
2758 2759 2760 2761 |
# File 'lib/aws-sdk-ecs/types.rb', line 2758 class CreateServiceResponse < Struct.new( :service) include Aws::Structure end |