Class: Aws::ECS::Types::CreateServiceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateServiceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service ⇒ Types::Service
The full description of your service following the create call.
Instance Attribute Details
#service ⇒ Types::Service
The full description of your service following the create call.
A service will return either a capacityProviderStrategy or launchType parameter, but not both, depending where one was specified when it was created.
If a service is using the ECS deployment controller, the deploymentController and taskSets parameters will not be returned.
if the service uses the CODE_DEPLOY deployment controller, the deploymentController, taskSets and deployments parameters will be returned, however the deployments parameter will be an empty list.
3530 3531 3532 3533 3534 |
# File 'lib/aws-sdk-ecs/types.rb', line 3530 class CreateServiceResponse < Struct.new( :service) SENSITIVE = [] include Aws::Structure end |