Class: Aws::ECS::Types::CreateTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass CreateTaskSetRequest data as a hash:
{
service: "String", # required
cluster: "String", # required
external_id: "String",
task_definition: "String", # required
network_configuration: {
awsvpc_configuration: {
subnets: ["String"], # required
security_groups: ["String"],
assign_public_ip: "ENABLED", # accepts ENABLED, DISABLED
},
},
load_balancers: [
{
target_group_arn: "String",
load_balancer_name: "String",
container_name: "String",
container_port: 1,
},
],
service_registries: [
{
registry_arn: "String",
port: 1,
container_name: "String",
container_port: 1,
},
],
launch_type: "EC2", # accepts EC2, FARGATE
capacity_provider_strategy: [
{
capacity_provider: "String", # required
weight: 1,
base: 1,
},
],
platform_version: "String",
scale: {
value: 1.0,
unit: "PERCENT", # accepts PERCENT
},
client_token: "String",
}
Instance Attribute Summary collapse
-
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy to use for the task set.
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.
-
#external_id ⇒ String
An optional non-unique tag that identifies this task set in external systems.
-
#launch_type ⇒ String
The launch type that new tasks in the task set will use.
-
#load_balancers ⇒ Array<Types::LoadBalancer>
A load balancer object representing the load balancer to use with the task set.
-
#network_configuration ⇒ Types::NetworkConfiguration
An object representing the network configuration for a task or service.
-
#platform_version ⇒ String
The platform version that the tasks in the task set should use.
-
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service to create the task set in.
-
#service_registries ⇒ Array<Types::ServiceRegistry>
The details of the service discovery registries to assign to this task set.
-
#task_definition ⇒ String
The task definition for the tasks in the task set to use.
Instance Attribute Details
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy to use for the task set.
A capacity provider strategy consists of one or more capacity providers along with the base and weight to assign to them. A capacity provider must be associated with the cluster to be used in a capacity provider strategy. The PutClusterCapacityProviders API is used to associate a capacity provider with a cluster. Only capacity providers with an ACTIVE or UPDATING status can be used.
If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used.
If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProvider API operation.
To use a AWS Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The AWS Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used.
The PutClusterCapacityProviders API operation is used to update the list of available capacity providers for a cluster after the cluster is created.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 32 ASCII characters are allowed.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#external_id ⇒ String
An optional non-unique tag that identifies this task set in external systems. If the task set is associated with a service discovery registry, the tasks in this task set will have the ECS_TASK_SET_EXTERNAL_ID AWS Cloud Map attribute set to the provided value.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#launch_type ⇒ String
The launch type that new tasks in the task set will use. For more information, see [Amazon ECS Launch Types] in the *Amazon Elastic Container Service Developer Guide*.
If a launchType is specified, the capacityProviderStrategy parameter must be omitted.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#load_balancers ⇒ Array<Types::LoadBalancer>
A load balancer object representing the load balancer to use with the task set. The supported load balancer types are either an Application Load Balancer or a Network Load Balancer.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
An object representing the network configuration for a task or service.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#platform_version ⇒ String
The platform version that the tasks in the task set should use. A platform version is specified only for tasks using the Fargate launch type. If one isn’t specified, the LATEST platform version is used by default.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service to create the task set in.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#service_registries ⇒ Array<Types::ServiceRegistry>
The details of the service discovery registries to assign to this task set. For more information, see [Service Discovery].
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |
#task_definition ⇒ String
The task definition for the tasks in the task set to use.
2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 |
# File 'lib/aws-sdk-ecs/types.rb', line 2914 class CreateTaskSetRequest < Struct.new( :service, :cluster, :external_id, :task_definition, :network_configuration, :load_balancers, :service_registries, :launch_type, :capacity_provider_strategy, :platform_version, :scale, :client_token) include Aws::Structure end |