Class: Aws::ECS::Types::CreateTaskSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::CreateTaskSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Instance Attribute Summary collapse
-
#task_set ⇒ Types::TaskSet
Information about a set of Amazon ECS tasks in either an AWS CodeDeploy or an
EXTERNALdeployment.
Instance Attribute Details
#task_set ⇒ Types::TaskSet
Information about a set of Amazon ECS tasks in either an AWS CodeDeploy or an EXTERNAL deployment. An Amazon ECS task set includes details such as the desired number of tasks, how many tasks are running, and whether the task set serves production traffic.
2939 2940 2941 2942 |
# File 'lib/aws-sdk-ecs/types.rb', line 2939 class CreateTaskSetResponse < Struct.new( :task_set) include Aws::Structure end |