Class: Aws::ECS::Types::DaemonContainerDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

A container definition for a daemon task. Daemon container definitions describe the containers that run as part of a daemon task on container instances managed by capacity providers.

Constant Summary collapse

SENSITIVE =
[:repository_credentials, :environment]

Instance Attribute Summary collapse

Instance Attribute Details

#commandArray<String>

The command that’s passed to the container.

Returns:

  • (Array<String>)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#cpuInteger

The number of ‘cpu` units reserved for the container.

Returns:

  • (Integer)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#depends_onArray<Types::ContainerDependency>

The dependencies defined for container startup and shutdown. A container can contain multiple dependencies on other containers in a task definition.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#entry_pointArray<String>

The entry point that’s passed to the container.

Returns:

  • (Array<String>)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#environmentArray<Types::KeyValuePair>

The environment variables to pass to a container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#environment_filesArray<Types::EnvironmentFile>

A list of files containing the environment variables to pass to a container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#essentialBoolean

If the ‘essential` parameter of a container is marked as `true`, and that container fails or stops for any reason, all other containers that are part of the task are stopped.

Returns:

  • (Boolean)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#firelens_configurationTypes::FirelensConfiguration

The FireLens configuration for the container. This is used to specify and configure a log router for container logs.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#health_checkTypes::HealthCheck

The container health check command and associated configuration parameters for the container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#imageString

The image used to start the container. This string is passed directly to the Docker daemon. Images in the Docker Hub registry are available by default. Other repositories are specified with either ‘ repository-url/image:tag ` or ` repository-url/image@digest `.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#interactiveBoolean

When this parameter is ‘true`, you can deploy containerized applications that require `stdin` or a `tty` to be allocated.

Returns:

  • (Boolean)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#linux_parametersTypes::DaemonLinuxParameters

Linux-specific modifications that are applied to the container configuration, such as Linux kernel capabilities.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#log_configurationTypes::LogConfiguration

The log configuration specification for the container.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#memoryInteger

The amount (in MiB) of memory to present to the container. If the container attempts to exceed the memory specified here, the container is killed.

Returns:

  • (Integer)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#memory_reservationInteger

The soft limit (in MiB) of memory to reserve for the container.

Returns:

  • (Integer)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#mount_pointsArray<Types::MountPoint>

The mount points for data volumes in your container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#nameString

The name of the container. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#privilegedBoolean

When this parameter is true, the container is given elevated privileges on the host container instance (similar to the ‘root` user).

Returns:

  • (Boolean)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#pseudo_terminalBoolean

When this parameter is ‘true`, a TTY is allocated.

Returns:

  • (Boolean)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#readonly_root_filesystemBoolean

When this parameter is true, the container is given read-only access to its root file system.

Returns:

  • (Boolean)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#repository_credentialsTypes::RepositoryCredentials

The private repository authentication credentials to use.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#restart_policyTypes::ContainerRestartPolicy

The restart policy for the container. When you set up a restart policy, Amazon ECS can restart the container without needing to replace the task.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#secretsArray<Types::Secret>

The secrets to pass to the container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#start_timeoutInteger

Time duration (in seconds) to wait before giving up on resolving dependencies for a container.

Returns:

  • (Integer)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#stop_timeoutInteger

Time duration (in seconds) to wait before the container is forcefully killed if it doesn’t exit normally on its own.

Returns:

  • (Integer)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#system_controlsArray<Types::SystemControl>

A list of namespaced kernel parameters to set in the container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#ulimitsArray<Types::Ulimit>

A list of ‘ulimits` to set in the container.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#userString

The user to use inside the container.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end

#working_directoryString

The working directory to run commands inside the container in.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/aws-sdk-ecs/types.rb', line 4237

class DaemonContainerDefinition < Struct.new(
  :name,
  :image,
  :memory,
  :memory_reservation,
  :repository_credentials,
  :health_check,
  :cpu,
  :essential,
  :entry_point,
  :command,
  :working_directory,
  :environment_files,
  :environment,
  :secrets,
  :readonly_root_filesystem,
  :mount_points,
  :log_configuration,
  :firelens_configuration,
  :privileged,
  :user,
  :ulimits,
  :linux_parameters,
  :depends_on,
  :start_timeout,
  :stop_timeout,
  :system_controls,
  :interactive,
  :pseudo_terminal,
  :restart_policy)
  SENSITIVE = [:repository_credentials, :environment]
  include Aws::Structure
end