Class: Aws::ECS::Types::DaemonContainerDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonContainerDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
A container definition for a daemon task. Daemon container definitions describe the containers that run as part of a daemon task on container instances managed by capacity providers.
Constant Summary collapse
- SENSITIVE =
[:repository_credentials, :environment]
Instance Attribute Summary collapse
-
#command ⇒ Array<String>
The command that’s passed to the container.
-
#cpu ⇒ Integer
The number of ‘cpu` units reserved for the container.
-
#depends_on ⇒ Array<Types::ContainerDependency>
The dependencies defined for container startup and shutdown.
-
#entry_point ⇒ Array<String>
The entry point that’s passed to the container.
-
#environment ⇒ Array<Types::KeyValuePair>
The environment variables to pass to a container.
-
#environment_files ⇒ Array<Types::EnvironmentFile>
A list of files containing the environment variables to pass to a container.
-
#essential ⇒ Boolean
If the ‘essential` parameter of a container is marked as `true`, and that container fails or stops for any reason, all other containers that are part of the task are stopped.
-
#firelens_configuration ⇒ Types::FirelensConfiguration
The FireLens configuration for the container.
-
#health_check ⇒ Types::HealthCheck
The container health check command and associated configuration parameters for the container.
-
#image ⇒ String
The image used to start the container.
-
#interactive ⇒ Boolean
When this parameter is ‘true`, you can deploy containerized applications that require `stdin` or a `tty` to be allocated.
-
#linux_parameters ⇒ Types::DaemonLinuxParameters
Linux-specific modifications that are applied to the container configuration, such as Linux kernel capabilities.
-
#log_configuration ⇒ Types::LogConfiguration
The log configuration specification for the container.
-
#memory ⇒ Integer
The amount (in MiB) of memory to present to the container.
-
#memory_reservation ⇒ Integer
The soft limit (in MiB) of memory to reserve for the container.
-
#mount_points ⇒ Array<Types::MountPoint>
The mount points for data volumes in your container.
-
#name ⇒ String
The name of the container.
-
#privileged ⇒ Boolean
When this parameter is true, the container is given elevated privileges on the host container instance (similar to the ‘root` user).
-
#pseudo_terminal ⇒ Boolean
When this parameter is ‘true`, a TTY is allocated.
-
#readonly_root_filesystem ⇒ Boolean
When this parameter is true, the container is given read-only access to its root file system.
-
#repository_credentials ⇒ Types::RepositoryCredentials
The private repository authentication credentials to use.
-
#restart_policy ⇒ Types::ContainerRestartPolicy
The restart policy for the container.
-
#secrets ⇒ Array<Types::Secret>
The secrets to pass to the container.
-
#start_timeout ⇒ Integer
Time duration (in seconds) to wait before giving up on resolving dependencies for a container.
-
#stop_timeout ⇒ Integer
Time duration (in seconds) to wait before the container is forcefully killed if it doesn’t exit normally on its own.
-
#system_controls ⇒ Array<Types::SystemControl>
A list of namespaced kernel parameters to set in the container.
-
#ulimits ⇒ Array<Types::Ulimit>
A list of ‘ulimits` to set in the container.
-
#user ⇒ String
The user to use inside the container.
-
#working_directory ⇒ String
The working directory to run commands inside the container in.
Instance Attribute Details
#command ⇒ Array<String>
The command that’s passed to the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#cpu ⇒ Integer
The number of ‘cpu` units reserved for the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#depends_on ⇒ Array<Types::ContainerDependency>
The dependencies defined for container startup and shutdown. A container can contain multiple dependencies on other containers in a task definition.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#entry_point ⇒ Array<String>
The entry point that’s passed to the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#environment ⇒ Array<Types::KeyValuePair>
The environment variables to pass to a container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#environment_files ⇒ Array<Types::EnvironmentFile>
A list of files containing the environment variables to pass to a container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#essential ⇒ Boolean
If the ‘essential` parameter of a container is marked as `true`, and that container fails or stops for any reason, all other containers that are part of the task are stopped.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#firelens_configuration ⇒ Types::FirelensConfiguration
The FireLens configuration for the container. This is used to specify and configure a log router for container logs.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#health_check ⇒ Types::HealthCheck
The container health check command and associated configuration parameters for the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#image ⇒ String
The image used to start the container. This string is passed directly to the Docker daemon. Images in the Docker Hub registry are available by default. Other repositories are specified with either ‘ repository-url/image:tag ` or ` repository-url/image@digest `.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#interactive ⇒ Boolean
When this parameter is ‘true`, you can deploy containerized applications that require `stdin` or a `tty` to be allocated.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#linux_parameters ⇒ Types::DaemonLinuxParameters
Linux-specific modifications that are applied to the container configuration, such as Linux kernel capabilities.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#log_configuration ⇒ Types::LogConfiguration
The log configuration specification for the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#memory ⇒ Integer
The amount (in MiB) of memory to present to the container. If the container attempts to exceed the memory specified here, the container is killed.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#memory_reservation ⇒ Integer
The soft limit (in MiB) of memory to reserve for the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#mount_points ⇒ Array<Types::MountPoint>
The mount points for data volumes in your container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#name ⇒ String
The name of the container. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#privileged ⇒ Boolean
When this parameter is true, the container is given elevated privileges on the host container instance (similar to the ‘root` user).
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#pseudo_terminal ⇒ Boolean
When this parameter is ‘true`, a TTY is allocated.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#readonly_root_filesystem ⇒ Boolean
When this parameter is true, the container is given read-only access to its root file system.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#repository_credentials ⇒ Types::RepositoryCredentials
The private repository authentication credentials to use.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#restart_policy ⇒ Types::ContainerRestartPolicy
The restart policy for the container. When you set up a restart policy, Amazon ECS can restart the container without needing to replace the task.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#secrets ⇒ Array<Types::Secret>
The secrets to pass to the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#start_timeout ⇒ Integer
Time duration (in seconds) to wait before giving up on resolving dependencies for a container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#stop_timeout ⇒ Integer
Time duration (in seconds) to wait before the container is forcefully killed if it doesn’t exit normally on its own.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#system_controls ⇒ Array<Types::SystemControl>
A list of namespaced kernel parameters to set in the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#ulimits ⇒ Array<Types::Ulimit>
A list of ‘ulimits` to set in the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#user ⇒ String
The user to use inside the container.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |
#working_directory ⇒ String
The working directory to run commands inside the container in.
4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 |
# File 'lib/aws-sdk-ecs/types.rb', line 4237 class DaemonContainerDefinition < Struct.new( :name, :image, :memory, :memory_reservation, :repository_credentials, :health_check, :cpu, :essential, :entry_point, :command, :working_directory, :environment_files, :environment, :secrets, :readonly_root_filesystem, :mount_points, :log_configuration, :firelens_configuration, :privileged, :user, :ulimits, :linux_parameters, :depends_on, :start_timeout, :stop_timeout, :system_controls, :interactive, :pseudo_terminal, :restart_policy) SENSITIVE = [:repository_credentials, :environment] include Aws::Structure end |