Class: Aws::ECS::Types::DaemonDeployment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about a daemon deployment. A daemon deployment orchestrates the progressive rollout of daemon task updates across container instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarmsTypes::DaemonDeploymentAlarms

The CloudWatch alarms that determine when a daemon deployment fails.



4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#circuit_breakerTypes::DaemonCircuitBreaker

The circuit breaker configuration that determines when a daemon deployment has failed.



4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The Amazon Resource Name (ARN) of the cluster that hosts the daemon.

Returns:

  • (String)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time the daemon deployment was created. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_deployment_arnString

The Amazon Resource Name (ARN) of the daemon deployment.

Returns:

  • (String)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configurationTypes::DaemonDeploymentConfiguration

The deployment configuration used for this daemon deployment.



4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#finished_atTime

The time the daemon deployment finished. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#rollbackTypes::DaemonRollback

The rollback options for the daemon deployment.



4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#source_daemon_revisionsArray<Types::DaemonDeploymentRevisionDetail>

The currently deployed daemon revisions that are being replaced.



4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The time the daemon deployment started. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the daemon deployment.

Returns:

  • (String)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the daemon deployment is in the current status.

Returns:

  • (String)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The time the daemon deployment stopped. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end

#target_daemon_revisionTypes::DaemonDeploymentRevisionDetail

The daemon revision being deployed.



4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
4465
# File 'lib/aws-sdk-ecs/types.rb', line 4448

class DaemonDeployment < Struct.new(
  :daemon_deployment_arn,
  :cluster_arn,
  :status,
  :status_reason,
  :target_daemon_revision,
  :source_daemon_revisions,
  :circuit_breaker,
  :alarms,
  :rollback,
  :deployment_configuration,
  :created_at,
  :started_at,
  :stopped_at,
  :finished_at)
  SENSITIVE = []
  include Aws::Structure
end