Class: Aws::ECS::Types::DaemonDeployment
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonDeployment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Information about a daemon deployment. A daemon deployment orchestrates the progressive rollout of daemon task updates across container instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarms ⇒ Types::DaemonDeploymentAlarms
The CloudWatch alarms that determine when a daemon deployment fails.
-
#circuit_breaker ⇒ Types::DaemonCircuitBreaker
The circuit breaker configuration that determines when a daemon deployment has failed.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that hosts the daemon.
-
#created_at ⇒ Time
The time the daemon deployment was created.
-
#daemon_deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment.
-
#deployment_configuration ⇒ Types::DaemonDeploymentConfiguration
The deployment configuration used for this daemon deployment.
-
#finished_at ⇒ Time
The time the daemon deployment finished.
-
#rollback ⇒ Types::DaemonRollback
The rollback options for the daemon deployment.
-
#source_daemon_revisions ⇒ Array<Types::DaemonDeploymentRevisionDetail>
The currently deployed daemon revisions that are being replaced.
-
#started_at ⇒ Time
The time the daemon deployment started.
-
#status ⇒ String
The status of the daemon deployment.
-
#status_reason ⇒ String
Information about why the daemon deployment is in the current status.
-
#stopped_at ⇒ Time
The time the daemon deployment stopped.
-
#target_daemon_revision ⇒ Types::DaemonDeploymentRevisionDetail
The daemon revision being deployed.
Instance Attribute Details
#alarms ⇒ Types::DaemonDeploymentAlarms
The CloudWatch alarms that determine when a daemon deployment fails.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#circuit_breaker ⇒ Types::DaemonCircuitBreaker
The circuit breaker configuration that determines when a daemon deployment has failed.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that hosts the daemon.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The time the daemon deployment was created. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#daemon_deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#deployment_configuration ⇒ Types::DaemonDeploymentConfiguration
The deployment configuration used for this daemon deployment.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
The time the daemon deployment finished. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#rollback ⇒ Types::DaemonRollback
The rollback options for the daemon deployment.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#source_daemon_revisions ⇒ Array<Types::DaemonDeploymentRevisionDetail>
The currently deployed daemon revisions that are being replaced.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time the daemon deployment started. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon deployment.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Information about why the daemon deployment is in the current status.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The time the daemon deployment stopped. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |
#target_daemon_revision ⇒ Types::DaemonDeploymentRevisionDetail
The daemon revision being deployed.
4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 4378 4379 4380 |
# File 'lib/aws-sdk-ecs/types.rb', line 4363 class DaemonDeployment < Struct.new( :daemon_deployment_arn, :cluster_arn, :status, :status_reason, :target_daemon_revision, :source_daemon_revisions, :circuit_breaker, :alarms, :rollback, :deployment_configuration, :created_at, :started_at, :stopped_at, :finished_at) SENSITIVE = [] include Aws::Structure end |