Class: Aws::ECS::Types::DaemonDeploymentCapacityProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about a capacity provider during a daemon deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the capacity provider.

Returns:

  • (String)


4427
4428
4429
4430
4431
4432
4433
# File 'lib/aws-sdk-ecs/types.rb', line 4427

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#draining_instance_countInteger

The number of instances being drained on this capacity provider during the deployment.

Returns:

  • (Integer)


4427
4428
4429
4430
4431
4432
4433
# File 'lib/aws-sdk-ecs/types.rb', line 4427

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end

#running_instance_countInteger

The number of instances running daemon tasks on this capacity provider.

Returns:

  • (Integer)


4427
4428
4429
4430
4431
4432
4433
# File 'lib/aws-sdk-ecs/types.rb', line 4427

class DaemonDeploymentCapacityProvider < Struct.new(
  :arn,
  :running_instance_count,
  :draining_instance_count)
  SENSITIVE = []
  include Aws::Structure
end