Class: Aws::ECS::Types::DaemonTaskDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonTaskDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The details of a daemon task definition. A daemon task definition is a template that describes the containers that form a daemon. Daemons deploy cross-cutting software agents independently across your Amazon ECS infrastructure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_definitions ⇒ Array<Types::DaemonContainerDefinition>
A list of container definitions in JSON format that describe the containers that make up the daemon task.
-
#cpu ⇒ String
The number of CPU units used by the daemon task.
-
#daemon_task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the daemon task definition.
-
#delete_requested_at ⇒ Time
The Unix timestamp for the time when the daemon task definition delete was requested.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf.
-
#family ⇒ String
The name of a family that this daemon task definition is registered to.
-
#ipc_mode ⇒ String
The IPC namespace mode for the daemon.
-
#memory ⇒ String
The amount of memory (in MiB) used by the daemon task.
-
#pid_mode ⇒ String
The process namespace mode for the daemon.
-
#registered_at ⇒ Time
The Unix timestamp for the time when the daemon task definition was registered.
-
#registered_by ⇒ String
The principal that registered the daemon task definition.
-
#revision ⇒ Integer
The revision of the daemon task in a particular family.
-
#status ⇒ String
The status of the daemon task definition.
-
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the IAM role that grants containers in the daemon task permission to call Amazon Web Services APIs on your behalf.
-
#volumes ⇒ Array<Types::DaemonVolume>
The list of data volume definitions for the daemon task.
Instance Attribute Details
#container_definitions ⇒ Array<Types::DaemonContainerDefinition>
A list of container definitions in JSON format that describe the containers that make up the daemon task.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#cpu ⇒ String
The number of CPU units used by the daemon task.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#daemon_task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the daemon task definition.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#delete_requested_at ⇒ Time
The Unix timestamp for the time when the daemon task definition delete was requested.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#family ⇒ String
The name of a family that this daemon task definition is registered to.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#ipc_mode ⇒ String
The IPC namespace mode for the daemon. A value of ‘shared` means the daemon shares the IPC namespace with co-located tasks, allowing communication through POSIX shared memory, semaphores, and message queues. A value of `none` means the daemon has its own isolated IPC namespace.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The amount of memory (in MiB) used by the daemon task.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#pid_mode ⇒ String
The process namespace mode for the daemon. A value of ‘shared` means the daemon shares the PID namespace with co-located tasks, giving it visibility into application processes. A value of `none` means the daemon has its own isolated PID namespace.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#registered_at ⇒ Time
The Unix timestamp for the time when the daemon task definition was registered.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#registered_by ⇒ String
The principal that registered the daemon task definition.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Integer
The revision of the daemon task in a particular family. The revision is a version number of a daemon task definition in a family. When you register a daemon task definition for the first time, the revision is ‘1`. Each time that you register a new revision of a daemon task definition in the same family, the revision value always increases by one.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon task definition. The valid values are ‘ACTIVE`, `DELETE_IN_PROGRESS`, and `DELETED`.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the IAM role that grants containers in the daemon task permission to call Amazon Web Services APIs on your behalf.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::DaemonVolume>
The list of data volume definitions for the daemon task.
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 |
# File 'lib/aws-sdk-ecs/types.rb', line 4971 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by, :pid_mode, :ipc_mode) SENSITIVE = [] include Aws::Structure end |