Class: Aws::ECS::Types::DaemonTaskDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonTaskDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The details of a daemon task definition. A daemon task definition is a template that describes the containers that form a daemon. Daemons deploy cross-cutting software agents independently across your Amazon ECS infrastructure.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_definitions ⇒ Array<Types::DaemonContainerDefinition>
A list of container definitions in JSON format that describe the containers that make up the daemon task.
-
#cpu ⇒ String
The number of CPU units used by the daemon task.
-
#daemon_task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the daemon task definition.
-
#delete_requested_at ⇒ Time
The Unix timestamp for the time when the daemon task definition delete was requested.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf.
-
#family ⇒ String
The name of a family that this daemon task definition is registered to.
-
#memory ⇒ String
The amount of memory (in MiB) used by the daemon task.
-
#registered_at ⇒ Time
The Unix timestamp for the time when the daemon task definition was registered.
-
#registered_by ⇒ String
The principal that registered the daemon task definition.
-
#revision ⇒ Integer
The revision of the daemon task in a particular family.
-
#status ⇒ String
The status of the daemon task definition.
-
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the IAM role that grants containers in the daemon task permission to call Amazon Web Services APIs on your behalf.
-
#volumes ⇒ Array<Types::DaemonVolume>
The list of data volume definitions for the daemon task.
Instance Attribute Details
#container_definitions ⇒ Array<Types::DaemonContainerDefinition>
A list of container definitions in JSON format that describe the containers that make up the daemon task.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#cpu ⇒ String
The number of CPU units used by the daemon task.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#daemon_task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the daemon task definition.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#delete_requested_at ⇒ Time
The Unix timestamp for the time when the daemon task definition delete was requested.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#family ⇒ String
The name of a family that this daemon task definition is registered to.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The amount of memory (in MiB) used by the daemon task.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#registered_at ⇒ Time
The Unix timestamp for the time when the daemon task definition was registered.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#registered_by ⇒ String
The principal that registered the daemon task definition.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ Integer
The revision of the daemon task in a particular family. The revision is a version number of a daemon task definition in a family. When you register a daemon task definition for the first time, the revision is ‘1`. Each time that you register a new revision of a daemon task definition in the same family, the revision value always increases by one.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon task definition. The valid values are ‘ACTIVE`, `DELETE_IN_PROGRESS`, and `DELETED`.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the IAM role that grants containers in the daemon task permission to call Amazon Web Services APIs on your behalf.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::DaemonVolume>
The list of data volume definitions for the daemon task.
4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-ecs/types.rb', line 4895 class DaemonTaskDefinition < Struct.new( :daemon_task_definition_arn, :family, :revision, :task_role_arn, :execution_role_arn, :container_definitions, :volumes, :cpu, :memory, :status, :registered_at, :delete_requested_at, :registered_by) SENSITIVE = [] include Aws::Structure end |