Class: Aws::ECS::Types::DaemonVolume
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DaemonVolume
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
A data volume definition for a daemon task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#host ⇒ Types::HostVolumeProperties
The contents of the ‘host` parameter determine whether your bind mount host volume persists on the host container instance and where it’s stored.
-
#name ⇒ String
The name of the volume.
Instance Attribute Details
#host ⇒ Types::HostVolumeProperties
The contents of the ‘host` parameter determine whether your bind mount host volume persists on the host container instance and where it’s stored.
4964 4965 4966 4967 4968 4969 |
# File 'lib/aws-sdk-ecs/types.rb', line 4964 class DaemonVolume < Struct.new( :name, :host) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the volume. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.
4964 4965 4966 4967 4968 4969 |
# File 'lib/aws-sdk-ecs/types.rb', line 4964 class DaemonVolume < Struct.new( :name, :host) SENSITIVE = [] include Aws::Structure end |