Class: Aws::ECS::Types::DeleteAccountSettingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteAccountSettingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name to disable the account setting for.
-
#principal_arn ⇒ String
The Amazon Resource Name (ARN) of the principal.
Instance Attribute Details
#name ⇒ String
The resource name to disable the account setting for. If ‘serviceLongArnFormat` is specified, the ARN for your Amazon ECS services is affected. If `taskLongArnFormat` is specified, the ARN and resource ID for your Amazon ECS tasks is affected. If `containerInstanceLongArnFormat` is specified, the ARN and resource ID for your Amazon ECS container instances is affected. If `awsvpcTrunking` is specified, the ENI limit for your Amazon ECS container instances is affected.
5097 5098 5099 5100 5101 5102 |
# File 'lib/aws-sdk-ecs/types.rb', line 5097 class DeleteAccountSettingRequest < Struct.new( :name, :principal_arn) SENSITIVE = [] include Aws::Structure end |
#principal_arn ⇒ String
The Amazon Resource Name (ARN) of the principal. It can be a user, role, or the root user. If you specify the root user, it disables the account setting for all users, roles, and the root user of the account unless a user or role explicitly overrides these settings. If this field is omitted, the setting is changed only for the authenticated user.
In order to use this parameter, you must be the root user, or the principal.
5097 5098 5099 5100 5101 5102 |
# File 'lib/aws-sdk-ecs/types.rb', line 5097 class DeleteAccountSettingRequest < Struct.new( :name, :principal_arn) SENSITIVE = [] include Aws::Structure end |