Class: Aws::ECS::Types::DeleteAccountSettingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteAccountSettingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass DeleteAccountSettingRequest data as a hash:
{
name: "serviceLongArnFormat", # required, accepts serviceLongArnFormat, taskLongArnFormat, containerInstanceLongArnFormat, awsvpcTrunking, containerInsights
principal_arn: "String",
}
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name for which to disable the account setting.
-
#principal_arn ⇒ String
The ARN of the principal, which can be an IAM user, IAM role, or the root user.
Instance Attribute Details
#name ⇒ String
The resource name for which to disable the account setting. If serviceLongArnFormat is specified, the ARN for your Amazon ECS services is affected. If taskLongArnFormat is specified, the ARN and resource ID for your Amazon ECS tasks is affected. If containerInstanceLongArnFormat is specified, the ARN and resource ID for your Amazon ECS container instances is affected. If awsvpcTrunking is specified, the ENI limit for your Amazon ECS container instances is affected.
2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-ecs/types.rb', line 2974 class DeleteAccountSettingRequest < Struct.new( :name, :principal_arn) include Aws::Structure end |
#principal_arn ⇒ String
The ARN of the principal, which can be an IAM user, IAM role, or the root user. If you specify the root user, it disables the account setting for all IAM users, IAM roles, and the root user of the account unless an IAM user or role explicitly overrides these settings. If this field is omitted, the setting is changed only for the authenticated user.
2974 2975 2976 2977 2978 |
# File 'lib/aws-sdk-ecs/types.rb', line 2974 class DeleteAccountSettingRequest < Struct.new( :name, :principal_arn) include Aws::Structure end |