Class: Aws::ECS::Types::DeleteAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteAttributesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Types::Attribute>
The attributes to delete from your resource.
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that contains the resource to delete attributes.
Instance Attribute Details
#attributes ⇒ Array<Types::Attribute>
The attributes to delete from your resource. You can specify up to 10 attributes for each request. For custom attributes, specify the attribute name and target ID, but don’t specify the value. If you specify the target ID using the short form, you must also specify the target type.
3851 3852 3853 3854 3855 3856 |
# File 'lib/aws-sdk-ecs/types.rb', line 3851 class DeleteAttributesRequest < Struct.new( :cluster, :attributes) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that contains the resource to delete attributes. If you do not specify a cluster, the default cluster is assumed.
3851 3852 3853 3854 3855 3856 |
# File 'lib/aws-sdk-ecs/types.rb', line 3851 class DeleteAttributesRequest < Struct.new( :cluster, :attributes) SENSITIVE = [] include Aws::Structure end |