Class: Aws::ECS::Types::DeleteDaemonResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteDaemonResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The Unix timestamp for the time when the daemon was created.
-
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
-
#deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment that was triggered by the delete operation.
-
#status ⇒ String
The status of the daemon.
-
#updated_at ⇒ Time
The Unix timestamp for the time when the daemon was last updated.
Instance Attribute Details
#created_at ⇒ Time
The Unix timestamp for the time when the daemon was created.
5217 5218 5219 5220 5221 5222 5223 5224 5225 |
# File 'lib/aws-sdk-ecs/types.rb', line 5217 class DeleteDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
5217 5218 5219 5220 5221 5222 5223 5224 5225 |
# File 'lib/aws-sdk-ecs/types.rb', line 5217 class DeleteDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment that was triggered by the delete operation. This deployment drains existing daemon tasks from the container instances.
5217 5218 5219 5220 5221 5222 5223 5224 5225 |
# File 'lib/aws-sdk-ecs/types.rb', line 5217 class DeleteDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon. After you call ‘DeleteDaemon`, the status changes to `DELETE_IN_PROGRESS`.
5217 5218 5219 5220 5221 5222 5223 5224 5225 |
# File 'lib/aws-sdk-ecs/types.rb', line 5217 class DeleteDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The Unix timestamp for the time when the daemon was last updated.
5217 5218 5219 5220 5221 5222 5223 5224 5225 |
# File 'lib/aws-sdk-ecs/types.rb', line 5217 class DeleteDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |