Class: Aws::ECS::Types::DeleteDaemonResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The Unix timestamp for the time when the daemon was created.

Returns:

  • (Time)


5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-ecs/types.rb', line 5161

class DeleteDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#daemon_arnString

The Amazon Resource Name (ARN) of the daemon.

Returns:

  • (String)


5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-ecs/types.rb', line 5161

class DeleteDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_arnString

The Amazon Resource Name (ARN) of the daemon deployment that was triggered by the delete operation. This deployment drains existing daemon tasks from the container instances.

Returns:

  • (String)


5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-ecs/types.rb', line 5161

class DeleteDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the daemon. After you call ‘DeleteDaemon`, the status changes to `DELETE_IN_PROGRESS`.

Returns:

  • (String)


5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-ecs/types.rb', line 5161

class DeleteDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for the time when the daemon was last updated.

Returns:

  • (Time)


5161
5162
5163
5164
5165
5166
5167
5168
5169
# File 'lib/aws-sdk-ecs/types.rb', line 5161

class DeleteDaemonResponse < Struct.new(
  :daemon_arn,
  :status,
  :created_at,
  :updated_at,
  :deployment_arn)
  SENSITIVE = []
  include Aws::Structure
end