Class: Aws::ECS::Types::DeleteServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

<zonbook />

<xhtml />

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to delete. If you do not specify a cluster, the default cluster is assumed.

Returns:

  • (String)


5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-ecs/types.rb', line 5323

class DeleteServiceRequest < Struct.new(
  :cluster,
  :service,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

If ‘true`, allows you to delete a service even if it wasn’t scaled down to zero tasks. It’s only necessary to use this if the service uses the ‘REPLICA` scheduling strategy.

Returns:

  • (Boolean)


5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-ecs/types.rb', line 5323

class DeleteServiceRequest < Struct.new(
  :cluster,
  :service,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The name of the service to delete.

Returns:

  • (String)


5323
5324
5325
5326
5327
5328
5329
# File 'lib/aws-sdk-ecs/types.rb', line 5323

class DeleteServiceRequest < Struct.new(
  :cluster,
  :service,
  :force)
  SENSITIVE = []
  include Aws::Structure
end