Class: Aws::ECS::Types::DeleteServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass DeleteServiceRequest data as a hash:
{
cluster: "String",
service: "String", # required
force: false,
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to delete.
-
#force ⇒ Boolean
If
true, allows you to delete a service even if it has not been scaled down to zero tasks. -
#service ⇒ String
The name of the service to delete.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to delete. If you do not specify a cluster, the default cluster is assumed.
3097 3098 3099 3100 3101 3102 |
# File 'lib/aws-sdk-ecs/types.rb', line 3097 class DeleteServiceRequest < Struct.new( :cluster, :service, :force) include Aws::Structure end |
#force ⇒ Boolean
If true, allows you to delete a service even if it has not been scaled down to zero tasks. It is only necessary to use this if the service is using the REPLICA scheduling strategy.
3097 3098 3099 3100 3101 3102 |
# File 'lib/aws-sdk-ecs/types.rb', line 3097 class DeleteServiceRequest < Struct.new( :cluster, :service, :force) include Aws::Structure end |
#service ⇒ String
The name of the service to delete.
3097 3098 3099 3100 3101 3102 |
# File 'lib/aws-sdk-ecs/types.rb', line 3097 class DeleteServiceRequest < Struct.new( :cluster, :service, :force) include Aws::Structure end |