Class: Aws::ECS::Types::DeleteTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set found in to delete.
-
#force ⇒ Boolean
If ‘true`, you can delete a task set even if it hasn’t been scaled down to zero.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.
-
#task_set ⇒ String
The task set ID or full Amazon Resource Name (ARN) of the task set to delete.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set found in to delete.
5402 5403 5404 5405 5406 5407 5408 5409 |
# File 'lib/aws-sdk-ecs/types.rb', line 5402 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
If ‘true`, you can delete a task set even if it hasn’t been scaled down to zero.
5402 5403 5404 5405 5406 5407 5408 5409 |
# File 'lib/aws-sdk-ecs/types.rb', line 5402 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.
5402 5403 5404 5405 5406 5407 5408 5409 |
# File 'lib/aws-sdk-ecs/types.rb', line 5402 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) SENSITIVE = [] include Aws::Structure end |
#task_set ⇒ String
The task set ID or full Amazon Resource Name (ARN) of the task set to delete.
5402 5403 5404 5405 5406 5407 5408 5409 |
# File 'lib/aws-sdk-ecs/types.rb', line 5402 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) SENSITIVE = [] include Aws::Structure end |