Class: Aws::ECS::Types::DeleteTaskSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass DeleteTaskSetRequest data as a hash:

{
  cluster: "String", # required
  service: "String", # required
  task_set: "String", # required
  force: false,
}

Instance Attribute Summary collapse

Instance Attribute Details

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in to delete.

Returns:



3147
3148
3149
3150
3151
3152
3153
# File 'lib/aws-sdk-ecs/types.rb', line 3147

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  include Aws::Structure
end

#forceBoolean

If true, this allows you to delete a task set even if it hasn’t been scaled down to zero.

Returns:



3147
3148
3149
3150
3151
3152
3153
# File 'lib/aws-sdk-ecs/types.rb', line 3147

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  include Aws::Structure
end

#serviceString

The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.

Returns:



3147
3148
3149
3150
3151
3152
3153
# File 'lib/aws-sdk-ecs/types.rb', line 3147

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  include Aws::Structure
end

#task_setString

The task set ID or full Amazon Resource Name (ARN) of the task set to delete.

Returns:



3147
3148
3149
3150
3151
3152
3153
# File 'lib/aws-sdk-ecs/types.rb', line 3147

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  include Aws::Structure
end