Class: Aws::ECS::Types::DeleteTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeleteTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass DeleteTaskSetRequest data as a hash:
{
cluster: "String", # required
service: "String", # required
task_set: "String", # required
force: false,
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in to delete.
-
#force ⇒ Boolean
If
true, this allows you to delete a task set even if it hasn’t been scaled down to zero. -
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.
-
#task_set ⇒ String
The task set ID or full Amazon Resource Name (ARN) of the task set to delete.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in to delete.
3147 3148 3149 3150 3151 3152 3153 |
# File 'lib/aws-sdk-ecs/types.rb', line 3147 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) include Aws::Structure end |
#force ⇒ Boolean
If true, this allows you to delete a task set even if it hasn’t been scaled down to zero.
3147 3148 3149 3150 3151 3152 3153 |
# File 'lib/aws-sdk-ecs/types.rb', line 3147 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.
3147 3148 3149 3150 3151 3152 3153 |
# File 'lib/aws-sdk-ecs/types.rb', line 3147 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) include Aws::Structure end |
#task_set ⇒ String
The task set ID or full Amazon Resource Name (ARN) of the task set to delete.
3147 3148 3149 3150 3151 3152 3153 |
# File 'lib/aws-sdk-ecs/types.rb', line 3147 class DeleteTaskSetRequest < Struct.new( :cluster, :service, :task_set, :force) include Aws::Structure end |