Class: Aws::ECS::Types::DeleteTaskSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set found in to delete.



3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-ecs/types.rb', line 3990

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

If true, you can delete a task set even if it hasn’t been scaled down to zero.



3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-ecs/types.rb', line 3990

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.



3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-ecs/types.rb', line 3990

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#task_setString

The task set ID or full Amazon Resource Name (ARN) of the task set to delete.



3990
3991
3992
3993
3994
3995
3996
3997
# File 'lib/aws-sdk-ecs/types.rb', line 3990

class DeleteTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :force)
  SENSITIVE = []
  include Aws::Structure
end