Class: Aws::ECS::Types::DeploymentCircuitBreaker

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The deployment circuit breaker can only be used for services using the rolling update (ECS) deployment type.

The deployment circuit breaker determines whether a service deployment will fail if the service can't reach a steady state. If it is turned on, a service deployment will transition to a failed state and stop launching new tasks. You can also configure Amazon ECS to roll back your service to the last completed deployment after a failure. For more information, see Rolling update in the Amazon Elastic Container Service Developer Guide.

For more information about API failure reasons, see API failure reasons in the Amazon Elastic Container Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enableBoolean

Determines whether to use the deployment circuit breaker logic for the service.

Returns:

  • (Boolean)


5761
5762
5763
5764
5765
5766
5767
5768
# File 'lib/aws-sdk-ecs/types.rb', line 5761

class DeploymentCircuitBreaker < Struct.new(
  :enable,
  :rollback,
  :reset_on_healthy_task,
  :threshold_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#reset_on_healthy_taskBoolean

Determines whether the deployment circuit breaker resets its failure count when a task reaches a healthy state. When set to true, a healthy task resets the failure count to 0; when false, it doesn't.

Returns:

  • (Boolean)


5761
5762
5763
5764
5765
5766
5767
5768
# File 'lib/aws-sdk-ecs/types.rb', line 5761

class DeploymentCircuitBreaker < Struct.new(
  :enable,
  :rollback,
  :reset_on_healthy_task,
  :threshold_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#rollbackBoolean

Determines whether to configure Amazon ECS to roll back the service if a service deployment fails. If rollback is on, when a service deployment fails, the service is rolled back to the last deployment that completed successfully.

Returns:

  • (Boolean)


5761
5762
5763
5764
5765
5766
5767
5768
# File 'lib/aws-sdk-ecs/types.rb', line 5761

class DeploymentCircuitBreaker < Struct.new(
  :enable,
  :rollback,
  :reset_on_healthy_task,
  :threshold_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#threshold_configurationTypes::ThresholdConfiguration

The threshold configuration that controls when the deployment circuit breaker triggers. For more information, see ThresholdConfiguration.



5761
5762
5763
5764
5765
5766
5767
5768
# File 'lib/aws-sdk-ecs/types.rb', line 5761

class DeploymentCircuitBreaker < Struct.new(
  :enable,
  :rollback,
  :reset_on_healthy_task,
  :threshold_configuration)
  SENSITIVE = []
  include Aws::Structure
end