Class: Aws::ECS::Types::DeploymentLifecycleHook
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeploymentLifecycleHook
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
A deployment lifecycle hook runs custom logic or pauses the deployment at specific stages of the deployment process. You can use Lambda functions or pause hooks as hook targets.
For more information, see [Lifecycle hooks for Amazon ECS service deployments] in the Amazon Elastic Container Service Developer Guide.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-lifecycle-hooks.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hook_details ⇒ Hash, ...
Use this field to specify custom parameters that Amazon ECS passes to your Lambda function on each invocation.
-
#hook_target_arn ⇒ String
The Amazon Resource Name (ARN) of the hook target.
-
#lifecycle_stages ⇒ Array<String>
The lifecycle stages at which to run the hook.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that grants Amazon ECS permission to call Lambda functions on your behalf.
-
#target_type ⇒ String
The type of action the lifecycle hook performs.
-
#timeout_configuration ⇒ Types::DeploymentLifecycleHookTimeoutConfiguration
The timeout configuration for the lifecycle hook.
Instance Attribute Details
#hook_details ⇒ Hash, ...
Use this field to specify custom parameters that Amazon ECS passes to your Lambda function on each invocation. This field is not used for ‘PAUSE` hooks.
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/aws-sdk-ecs/types.rb', line 6232 class DeploymentLifecycleHook < Struct.new( :target_type, :hook_target_arn, :role_arn, :lifecycle_stages, :hook_details, :timeout_configuration) SENSITIVE = [] include Aws::Structure end |
#hook_target_arn ⇒ String
The Amazon Resource Name (ARN) of the hook target. For ‘AWS_LAMBDA` hooks, this is the Lambda function ARN. This field is not applicable for `PAUSE` hooks.
You must provide this parameter when configuring an ‘AWS_LAMBDA` lifecycle hook.
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/aws-sdk-ecs/types.rb', line 6232 class DeploymentLifecycleHook < Struct.new( :target_type, :hook_target_arn, :role_arn, :lifecycle_stages, :hook_details, :timeout_configuration) SENSITIVE = [] include Aws::Structure end |
#lifecycle_stages ⇒ Array<String>
The lifecycle stages at which to run the hook. Choose from these valid values:
-
RECONCILE_SERVICE
The reconciliation stage that only happens when you start a new service deployment with more than 1 service revision in an ACTIVE state.
You can use a lifecycle hook for this stage.
-
PRE_SCALE_UP
The green service revision has not started. The blue service revision is handling 100% of the production traffic. There is no test traffic.
You can use a lifecycle hook for this stage.
-
POST_SCALE_UP
The green service revision has started. The blue service revision is handling 100% of the production traffic. There is no test traffic.
You can use a lifecycle hook for this stage.
-
TEST_TRAFFIC_SHIFT
The blue and green service revisions are running. The blue service revision handles 100% of the production traffic. The green service revision is migrating from 0% to 100% of test traffic.
You can use a lifecycle hook for this stage.
-
POST_TEST_TRAFFIC_SHIFT
The test traffic shift is complete. The green service revision handles 100% of the test traffic.
You can use a lifecycle hook for this stage.
-
PRE_PRODUCTION_TRAFFIC_SHIFT
Occurs before production traffic shift. For linear and canary deployments, this stage is invoked before every traffic shift step.
You can use a lifecycle hook for this stage.
-
PRODUCTION_TRAFFIC_SHIFT
Production traffic is shifting to the green service revision. The green service revision is migrating from 0% to 100% of production traffic. For linear and canary deployments, this stage is invoked at every traffic shift step.
You can use a lifecycle hook for this stage.
-
POST_PRODUCTION_TRAFFIC_SHIFT
The production traffic shift is complete.
You can use a lifecycle hook for this stage.
<note markdown=“1”> ‘PAUSE` hooks cannot be configured at `TEST_TRAFFIC_SHIFT` or `PRODUCTION_TRAFFIC_SHIFT` stages. These stages are only valid for `AWS_LAMBDA` hooks.
</note>
You must provide this parameter when configuring a deployment lifecycle hook.
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/aws-sdk-ecs/types.rb', line 6232 class DeploymentLifecycleHook < Struct.new( :target_type, :hook_target_arn, :role_arn, :lifecycle_stages, :hook_details, :timeout_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that grants Amazon ECS permission to call Lambda functions on your behalf.
For more information, see [Permissions required for Lambda functions in Amazon ECS blue/green deployments] in the Amazon Elastic Container Service Developer Guide.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/blue-green-permissions.html
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/aws-sdk-ecs/types.rb', line 6232 class DeploymentLifecycleHook < Struct.new( :target_type, :hook_target_arn, :role_arn, :lifecycle_stages, :hook_details, :timeout_configuration) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The type of action the lifecycle hook performs. Valid values are:
-
‘AWS_LAMBDA` - Invokes a Lambda function at the specified lifecycle stage. This is the default value.
-
‘PAUSE` - Pauses the deployment at the specified lifecycle stage until you call `ContinueServiceDeployment` to continue or roll back.
This field is optional. If not specified, the default value is ‘AWS_LAMBDA`.
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/aws-sdk-ecs/types.rb', line 6232 class DeploymentLifecycleHook < Struct.new( :target_type, :hook_target_arn, :role_arn, :lifecycle_stages, :hook_details, :timeout_configuration) SENSITIVE = [] include Aws::Structure end |
#timeout_configuration ⇒ Types::DeploymentLifecycleHookTimeoutConfiguration
The timeout configuration for the lifecycle hook. This specifies how long Amazon ECS waits before taking the timeout action if the hook is not resolved.
6232 6233 6234 6235 6236 6237 6238 6239 6240 6241 |
# File 'lib/aws-sdk-ecs/types.rb', line 6232 class DeploymentLifecycleHook < Struct.new( :target_type, :hook_target_arn, :role_arn, :lifecycle_stages, :hook_details, :timeout_configuration) SENSITIVE = [] include Aws::Structure end |