Class: Aws::ECS::Types::DeploymentLifecycleHookDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DeploymentLifecycleHookDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The details of a deployment lifecycle hook that is active during a service deployment.
You can view lifecycle hook details by calling [DescribeServiceDeployments].
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServiceDeployments.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expires_at ⇒ Time
The time when the lifecycle hook times out.
-
#hook_id ⇒ String
The ID of the lifecycle hook.
-
#status ⇒ String
The status of the lifecycle hook.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) of the hook target.
-
#target_type ⇒ String
The type of action the lifecycle hook performs, such as ‘AWS_LAMBDA` or `PAUSE`.
-
#timeout_action ⇒ String
The action Amazon ECS takes when the lifecycle hook times out.
Instance Attribute Details
#expires_at ⇒ Time
The time when the lifecycle hook times out. If the hook has not been completed by this time, Amazon ECS takes the timeout action.
6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 |
# File 'lib/aws-sdk-ecs/types.rb', line 6231 class DeploymentLifecycleHookDetail < Struct.new( :hook_id, :target_type, :target_arn, :status, :expires_at, :timeout_action) SENSITIVE = [] include Aws::Structure end |
#hook_id ⇒ String
The ID of the lifecycle hook. Use this value when calling ‘ContinueServiceDeployment` to continue or roll back a paused deployment.
6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 |
# File 'lib/aws-sdk-ecs/types.rb', line 6231 class DeploymentLifecycleHookDetail < Struct.new( :hook_id, :target_type, :target_arn, :status, :expires_at, :timeout_action) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the lifecycle hook. Valid values depend on the hook type:
-
For ‘AWS_LAMBDA` hooks: `IN_PROGRESS`, `SUCCEEDED`, `FAILED`, and `TIMED_OUT`.
-
For ‘PAUSE` hooks: `AWAITING_ACTION`, `SUCCEEDED`, `FAILED`, and `TIMED_OUT`.
6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 |
# File 'lib/aws-sdk-ecs/types.rb', line 6231 class DeploymentLifecycleHookDetail < Struct.new( :hook_id, :target_type, :target_arn, :status, :expires_at, :timeout_action) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) of the hook target. For ‘AWS_LAMBDA` hooks, this is the Lambda function ARN. For `PAUSE` hooks, this field is not set.
6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 |
# File 'lib/aws-sdk-ecs/types.rb', line 6231 class DeploymentLifecycleHookDetail < Struct.new( :hook_id, :target_type, :target_arn, :status, :expires_at, :timeout_action) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
The type of action the lifecycle hook performs, such as ‘AWS_LAMBDA` or `PAUSE`.
6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 |
# File 'lib/aws-sdk-ecs/types.rb', line 6231 class DeploymentLifecycleHookDetail < Struct.new( :hook_id, :target_type, :target_arn, :status, :expires_at, :timeout_action) SENSITIVE = [] include Aws::Structure end |
#timeout_action ⇒ String
The action Amazon ECS takes when the lifecycle hook times out. Valid values are ‘CONTINUE` and `ROLLBACK`.
6231 6232 6233 6234 6235 6236 6237 6238 6239 6240 |
# File 'lib/aws-sdk-ecs/types.rb', line 6231 class DeploymentLifecycleHookDetail < Struct.new( :hook_id, :target_type, :target_arn, :status, :expires_at, :timeout_action) SENSITIVE = [] include Aws::Structure end |