Class: Aws::ECS::Types::DescribeCapacityProvidersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeCapacityProvidersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_providers ⇒ Array<Types::CapacityProvider>
The list of capacity providers.
-
#failures ⇒ Array<Types::Failure>
Any failures associated with the call.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureDescribeCapacityProvidersrequest.
Instance Attribute Details
#capacity_providers ⇒ Array<Types::CapacityProvider>
The list of capacity providers.
6529 6530 6531 6532 6533 6534 6535 |
# File 'lib/aws-sdk-ecs/types.rb', line 6529 class DescribeCapacityProvidersResponse < Struct.new( :capacity_providers, :failures, :next_token) SENSITIVE = [] include Aws::Structure end |
#failures ⇒ Array<Types::Failure>
Any failures associated with the call.
6529 6530 6531 6532 6533 6534 6535 |
# File 'lib/aws-sdk-ecs/types.rb', line 6529 class DescribeCapacityProvidersResponse < Struct.new( :capacity_providers, :failures, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future
DescribeCapacityProviders request. When the results of a
DescribeCapacityProviders request exceed maxResults, this value
can be used to retrieve the next page of results. This value is
null when there are no more results to return.
6529 6530 6531 6532 6533 6534 6535 |
# File 'lib/aws-sdk-ecs/types.rb', line 6529 class DescribeCapacityProvidersResponse < Struct.new( :capacity_providers, :failures, :next_token) SENSITIVE = [] include Aws::Structure end |