Class: Aws::ECS::Types::DescribeCapacityProvidersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_providersArray<Types::CapacityProvider>

The list of capacity providers.



5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-ecs/types.rb', line 5017

class DescribeCapacityProvidersResponse < Struct.new(
  :capacity_providers,
  :failures,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#failuresArray<Types::Failure>

Any failures associated with the call.



5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-ecs/types.rb', line 5017

class DescribeCapacityProvidersResponse < Struct.new(
  :capacity_providers,
  :failures,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value to include in a future DescribeCapacityProviders request. When the results of a DescribeCapacityProviders request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.



5017
5018
5019
5020
5021
5022
5023
# File 'lib/aws-sdk-ecs/types.rb', line 5017

class DescribeCapacityProvidersResponse < Struct.new(
  :capacity_providers,
  :failures,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end