Class: Aws::ECS::Types::DescribeExpressGatewayServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#includeArray<String>

Specifies additional information to include in the response. Valid values are ‘TAGS` to include resource tags associated with the Express service.

Returns:

  • (Array<String>)


6695
6696
6697
6698
6699
6700
# File 'lib/aws-sdk-ecs/types.rb', line 6695

class DescribeExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The Amazon Resource Name (ARN) of the Express service to describe. The ARN uniquely identifies the service within your Amazon Web Services account and region.

Returns:

  • (String)


6695
6696
6697
6698
6699
6700
# File 'lib/aws-sdk-ecs/types.rb', line 6695

class DescribeExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :include)
  SENSITIVE = []
  include Aws::Structure
end