Class: Aws::ECS::Types::DescribeExpressGatewayServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeExpressGatewayServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#include ⇒ Array<String>
Specifies additional information to include in the response.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to describe.
Instance Attribute Details
#include ⇒ Array<String>
Specifies additional information to include in the response. Valid values are ‘TAGS` to include resource tags associated with the Express service.
6695 6696 6697 6698 6699 6700 |
# File 'lib/aws-sdk-ecs/types.rb', line 6695 class DescribeExpressGatewayServiceRequest < Struct.new( :service_arn, :include) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to describe. The ARN uniquely identifies the service within your Amazon Web Services account and region.
6695 6696 6697 6698 6699 6700 |
# File 'lib/aws-sdk-ecs/types.rb', line 6695 class DescribeExpressGatewayServiceRequest < Struct.new( :service_arn, :include) SENSITIVE = [] include Aws::Structure end |