Class: Aws::ECS::Types::DescribeTaskDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeTaskDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass DescribeTaskDefinitionRequest data as a hash:
{
task_definition: "String", # required
include: ["TAGS"], # accepts TAGS
}
Instance Attribute Summary collapse
-
#include ⇒ Array<String>
Specifies whether to see the resource tags for the task definition.
-
#task_definition ⇒ String
The
familyfor the latestACTIVErevision,familyandrevision(family:revision) for a specific revision in the family, or full Amazon Resource Name (ARN) of the task definition to describe.
Instance Attribute Details
#include ⇒ Array<String>
Specifies whether to see the resource tags for the task definition. If TAGS is specified, the tags are included in the response. If this field is omitted, tags are not included in the response.
3771 3772 3773 3774 3775 |
# File 'lib/aws-sdk-ecs/types.rb', line 3771 class DescribeTaskDefinitionRequest < Struct.new( :task_definition, :include) include Aws::Structure end |
#task_definition ⇒ String
The family for the latest ACTIVE revision, family and revision (family:revision) for a specific revision in the family, or full Amazon Resource Name (ARN) of the task definition to describe.
3771 3772 3773 3774 3775 |
# File 'lib/aws-sdk-ecs/types.rb', line 3771 class DescribeTaskDefinitionRequest < Struct.new( :task_definition, :include) include Aws::Structure end |