Class: Aws::ECS::Types::DescribeTaskSetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.

Returns:

  • (String)


7025
7026
7027
7028
7029
7030
7031
7032
# File 'lib/aws-sdk-ecs/types.rb', line 7025

class DescribeTaskSetsRequest < Struct.new(
  :cluster,
  :service,
  :task_sets,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#includeArray<String>

Specifies whether to see the resource tags for the task set. If TAGS is specified, the tags are included in the response. If this field is omitted, tags aren't included in the response.

Returns:

  • (Array<String>)


7025
7026
7027
7028
7029
7030
7031
7032
# File 'lib/aws-sdk-ecs/types.rb', line 7025

class DescribeTaskSetsRequest < Struct.new(
  :cluster,
  :service,
  :task_sets,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The short name or full Amazon Resource Name (ARN) of the service that the task sets exist in.

Returns:

  • (String)


7025
7026
7027
7028
7029
7030
7031
7032
# File 'lib/aws-sdk-ecs/types.rb', line 7025

class DescribeTaskSetsRequest < Struct.new(
  :cluster,
  :service,
  :task_sets,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#task_setsArray<String>

The ID or full Amazon Resource Name (ARN) of task sets to describe.

Returns:

  • (Array<String>)


7025
7026
7027
7028
7029
7030
7031
7032
# File 'lib/aws-sdk-ecs/types.rb', line 7025

class DescribeTaskSetsRequest < Struct.new(
  :cluster,
  :service,
  :task_sets,
  :include)
  SENSITIVE = []
  include Aws::Structure
end