Class: Aws::ECS::Types::DescribeTaskSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeTaskSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
-
#include ⇒ Array<String>
Specifies whether to see the resource tags for the task set.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task sets exist in.
-
#task_sets ⇒ Array<String>
The ID or full Amazon Resource Name (ARN) of task sets to describe.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/aws-sdk-ecs/types.rb', line 6937 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets, :include) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Array<String>
Specifies whether to see the resource tags for the task set. If ‘TAGS` is specified, the tags are included in the response. If this field is omitted, tags aren’t included in the response.
6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/aws-sdk-ecs/types.rb', line 6937 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets, :include) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task sets exist in.
6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/aws-sdk-ecs/types.rb', line 6937 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets, :include) SENSITIVE = [] include Aws::Structure end |
#task_sets ⇒ Array<String>
The ID or full Amazon Resource Name (ARN) of task sets to describe.
6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/aws-sdk-ecs/types.rb', line 6937 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets, :include) SENSITIVE = [] include Aws::Structure end |