Class: Aws::ECS::Types::DescribeTaskSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeTaskSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass DescribeTaskSetsRequest data as a hash:
{
cluster: "String", # required
service: "String", # required
task_sets: ["String"],
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task sets exist in.
-
#task_sets ⇒ Array<String>
The ID or full Amazon Resource Name (ARN) of task sets to describe.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-ecs/types.rb', line 3845 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets) include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task sets exist in.
3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-ecs/types.rb', line 3845 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets) include Aws::Structure end |
#task_sets ⇒ Array<String>
The ID or full Amazon Resource Name (ARN) of task sets to describe.
3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-ecs/types.rb', line 3845 class DescribeTaskSetsRequest < Struct.new( :cluster, :service, :task_sets) include Aws::Structure end |