Class: Aws::ECS::Types::DescribeTasksRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task or tasks to describe. If you do not specify a cluster, the default cluster is assumed.

Returns:

  • (String)


7073
7074
7075
7076
7077
7078
7079
# File 'lib/aws-sdk-ecs/types.rb', line 7073

class DescribeTasksRequest < Struct.new(
  :cluster,
  :tasks,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#includeArray<String>

Specifies whether you want to see the resource tags for the task. If TAGS is specified, the tags are included in the response. If this field is omitted, tags aren't included in the response.

Returns:

  • (Array<String>)


7073
7074
7075
7076
7077
7078
7079
# File 'lib/aws-sdk-ecs/types.rb', line 7073

class DescribeTasksRequest < Struct.new(
  :cluster,
  :tasks,
  :include)
  SENSITIVE = []
  include Aws::Structure
end

#tasksArray<String>

A list of up to 100 task IDs or full ARN entries.

Returns:

  • (Array<String>)


7073
7074
7075
7076
7077
7078
7079
# File 'lib/aws-sdk-ecs/types.rb', line 7073

class DescribeTasksRequest < Struct.new(
  :cluster,
  :tasks,
  :include)
  SENSITIVE = []
  include Aws::Structure
end