Class: Aws::ECS::Types::DescribeTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::DescribeTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task or tasks to describe.
-
#include ⇒ Array<String>
Specifies whether you want to see the resource tags for the task.
-
#tasks ⇒ Array<String>
A list of up to 100 task IDs or full ARN entries.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task or tasks to describe. If you do not specify a cluster, the default cluster is assumed.
5449 5450 5451 5452 5453 5454 5455 |
# File 'lib/aws-sdk-ecs/types.rb', line 5449 class DescribeTasksRequest < Struct.new( :cluster, :tasks, :include) SENSITIVE = [] include Aws::Structure end |
#include ⇒ Array<String>
Specifies whether you want to see the resource tags for the task. If ‘TAGS` is specified, the tags are included in the response. If this field is omitted, tags aren’t included in the response.
5449 5450 5451 5452 5453 5454 5455 |
# File 'lib/aws-sdk-ecs/types.rb', line 5449 class DescribeTasksRequest < Struct.new( :cluster, :tasks, :include) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<String>
A list of up to 100 task IDs or full ARN entries.
5449 5450 5451 5452 5453 5454 5455 |
# File 'lib/aws-sdk-ecs/types.rb', line 5449 class DescribeTasksRequest < Struct.new( :cluster, :tasks, :include) SENSITIVE = [] include Aws::Structure end |