Class: Aws::ECS::Types::ECSExpressGatewayService

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Represents an Express service, which provides a simplified way to deploy containerized web applications on Amazon ECS with managed Amazon Web Services infrastructure. An Express service automatically provisions and manages Application Load Balancers, target groups, security groups, and auto-scaling policies.

Express services use a service revision architecture where each service can have multiple active configurations, enabling blue-green deployments and gradual rollouts. The service maintains a list of active configurations and manages the lifecycle of the underlying Amazon Web Services resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#active_configurationsArray<Types::ExpressGatewayServiceConfiguration>

The list of active service configurations for the Express service.



5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#clusterString

The short name or full ARN of the cluster that hosts the Express service.

Returns:

  • (String)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The Unix timestamp for when the Express service was created.

Returns:

  • (Time)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#current_deploymentString

The current deployment configuration for the Express service.

Returns:

  • (String)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_role_arnString

The ARN of the infrastructure role that manages Amazon Web Services resources for the Express service.

Returns:

  • (String)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN that identifies the Express service.

Returns:

  • (String)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

The name of the Express service.

Returns:

  • (String)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::ExpressGatewayServiceStatus

The current status of the Express service.



5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The metadata applied to the Express service.

Returns:



5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for when the Express service was last updated.

Returns:

  • (Time)


5705
5706
5707
5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
# File 'lib/aws-sdk-ecs/types.rb', line 5705

class ECSExpressGatewayService < Struct.new(
  :cluster,
  :service_name,
  :service_arn,
  :infrastructure_role_arn,
  :status,
  :current_deployment,
  :active_configurations,
  :tags,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end