Class: Aws::ECS::Types::ECSExpressGatewayService
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ECSExpressGatewayService
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Represents an Express service, which provides a simplified way to deploy containerized web applications on Amazon ECS with managed Amazon Web Services infrastructure. An Express service automatically provisions and manages Application Load Balancers, target groups, security groups, and auto-scaling policies.
Express services use a service revision architecture where each service can have multiple active configurations, enabling blue-green deployments and gradual rollouts. The service maintains a list of active configurations and manages the lifecycle of the underlying Amazon Web Services resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_configurations ⇒ Array<Types::ExpressGatewayServiceConfiguration>
The list of active service configurations for the Express service.
-
#cluster ⇒ String
The short name or full ARN of the cluster that hosts the Express service.
-
#created_at ⇒ Time
The Unix timestamp for when the Express service was created.
-
#current_deployment ⇒ String
The current deployment configuration for the Express service.
-
#infrastructure_role_arn ⇒ String
The ARN of the infrastructure role that manages Amazon Web Services resources for the Express service.
-
#service_arn ⇒ String
The ARN that identifies the Express service.
-
#service_name ⇒ String
The name of the Express service.
-
#status ⇒ Types::ExpressGatewayServiceStatus
The current status of the Express service.
-
#tags ⇒ Array<Types::Tag>
The metadata applied to the Express service.
-
#updated_at ⇒ Time
The Unix timestamp for when the Express service was last updated.
Instance Attribute Details
#active_configurations ⇒ Array<Types::ExpressGatewayServiceConfiguration>
The list of active service configurations for the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The short name or full ARN of the cluster that hosts the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix timestamp for when the Express service was created.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#current_deployment ⇒ String
The current deployment configuration for the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#infrastructure_role_arn ⇒ String
The ARN of the infrastructure role that manages Amazon Web Services resources for the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The ARN that identifies the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ExpressGatewayServiceStatus
The current status of the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata applied to the Express service.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The Unix timestamp for when the Express service was last updated.
5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/aws-sdk-ecs/types.rb', line 5669 class ECSExpressGatewayService < Struct.new( :cluster, :service_name, :service_arn, :infrastructure_role_arn, :status, :current_deployment, :active_configurations, :tags, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |