Class: Aws::ECS::Types::ExecuteCommandResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ExecuteCommandResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster.
-
#container_arn ⇒ String
The Amazon Resource Name (ARN) of the container.
-
#container_name ⇒ String
The name of the container.
-
#interactive ⇒ Boolean
Determines whether the execute command session is running in interactive mode.
-
#session ⇒ Types::Session
The details of the SSM session that was created for this instance of execute-command.
-
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task.
Instance Attribute Details
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/aws-sdk-ecs/types.rb', line 6066 class ExecuteCommandResponse < Struct.new( :cluster_arn, :container_arn, :container_name, :interactive, :session, :task_arn) SENSITIVE = [] include Aws::Structure end |
#container_arn ⇒ String
The Amazon Resource Name (ARN) of the container.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/aws-sdk-ecs/types.rb', line 6066 class ExecuteCommandResponse < Struct.new( :cluster_arn, :container_arn, :container_name, :interactive, :session, :task_arn) SENSITIVE = [] include Aws::Structure end |
#container_name ⇒ String
The name of the container.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/aws-sdk-ecs/types.rb', line 6066 class ExecuteCommandResponse < Struct.new( :cluster_arn, :container_arn, :container_name, :interactive, :session, :task_arn) SENSITIVE = [] include Aws::Structure end |
#interactive ⇒ Boolean
Determines whether the execute command session is running in interactive mode. Amazon ECS only supports initiating interactive sessions, so you must specify true for this value.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/aws-sdk-ecs/types.rb', line 6066 class ExecuteCommandResponse < Struct.new( :cluster_arn, :container_arn, :container_name, :interactive, :session, :task_arn) SENSITIVE = [] include Aws::Structure end |
#session ⇒ Types::Session
The details of the SSM session that was created for this instance of execute-command.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/aws-sdk-ecs/types.rb', line 6066 class ExecuteCommandResponse < Struct.new( :cluster_arn, :container_arn, :container_name, :interactive, :session, :task_arn) SENSITIVE = [] include Aws::Structure end |
#task_arn ⇒ String
The Amazon Resource Name (ARN) of the task.
6066 6067 6068 6069 6070 6071 6072 6073 6074 6075 |
# File 'lib/aws-sdk-ecs/types.rb', line 6066 class ExecuteCommandResponse < Struct.new( :cluster_arn, :container_arn, :container_name, :interactive, :session, :task_arn) SENSITIVE = [] include Aws::Structure end |