Class: Aws::ECS::Types::ExpressGatewayServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Represents a specific configuration revision of an Express service, containing all the settings and parameters for that revision.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpuString

The CPU allocation for tasks in this service revision.

Returns:

  • (String)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The Unix timestamp for when this service revision was created.

Returns:

  • (Time)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the task execution role for the service revision.

Returns:

  • (String)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathString

The health check path for this service revision.

Returns:

  • (String)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#ingress_pathsArray<Types::IngressPathSummary>

The entry point into this service revision.

Returns:



7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#memoryString

The memory allocation for tasks in this service revision.

Returns:

  • (String)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::ExpressGatewayServiceNetworkConfiguration

The network configuration for tasks in this service revision.



7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ExpressGatewayContainer

The primary container configuration for this service revision.



7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_targetTypes::ExpressGatewayScalingTarget

The auto-scaling configuration for this service revision.



7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#service_revision_arnString

The ARN of the service revision.

Returns:

  • (String)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The ARN of the task role for the service revision.

Returns:

  • (String)


7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
# File 'lib/aws-sdk-ecs/types.rb', line 7668

class ExpressGatewayServiceConfiguration < Struct.new(
  :service_revision_arn,
  :execution_role_arn,
  :task_role_arn,
  :cpu,
  :memory,
  :network_configuration,
  :health_check_path,
  :primary_container,
  :scaling_target,
  :ingress_paths,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end