Class: Aws::ECS::Types::ExpressGatewayServiceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ExpressGatewayServiceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Represents a specific configuration revision of an Express service, containing all the settings and parameters for that revision.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpu ⇒ String
The CPU allocation for tasks in this service revision.
-
#cpu_architecture ⇒ String
The CPU architecture that the tasks in this service revision run on.
-
#created_at ⇒ Time
The Unix timestamp for when this service revision was created.
-
#execution_role_arn ⇒ String
The ARN of the task execution role for the service revision.
-
#health_check_path ⇒ String
The health check path for this service revision.
-
#ingress_paths ⇒ Array<Types::IngressPathSummary>
The entry point into this service revision.
-
#memory ⇒ String
The memory allocation for tasks in this service revision.
-
#network_configuration ⇒ Types::ExpressGatewayServiceNetworkConfiguration
The network configuration for tasks in this service revision.
-
#primary_container ⇒ Types::ExpressGatewayContainer
The primary container configuration for this service revision.
-
#scaling_target ⇒ Types::ExpressGatewayScalingTarget
The auto-scaling configuration for this service revision.
-
#service_revision_arn ⇒ String
The ARN of the service revision.
-
#task_definition_arn ⇒ String
The ARN of the task definition used by this service revision.
-
#task_role_arn ⇒ String
The ARN of the task role for the service revision.
Instance Attribute Details
#cpu ⇒ String
The CPU allocation for tasks in this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#cpu_architecture ⇒ String
The CPU architecture that the tasks in this service revision run on. This is the architecture from the task definition that the service revision uses, so it reflects the default or the previously configured architecture when the request that created the revision didn't specify one.
Valid values:
-
X86_64- The x86 64-bit architecture. -
ARM64- The 64-bit ARM architecture.
This value isn't returned when the task definition for the service revision doesn't specify a runtime platform. Because the architecture comes from each service revision's own task definition, revisions of the same service can report different architectures.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix timestamp for when this service revision was created.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the task execution role for the service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#health_check_path ⇒ String
The health check path for this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#ingress_paths ⇒ Array<Types::IngressPathSummary>
The entry point into this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The memory allocation for tasks in this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::ExpressGatewayServiceNetworkConfiguration
The network configuration for tasks in this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ExpressGatewayContainer
The primary container configuration for this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#scaling_target ⇒ Types::ExpressGatewayScalingTarget
The auto-scaling configuration for this service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#service_revision_arn ⇒ String
The ARN of the service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#task_definition_arn ⇒ String
The ARN of the task definition used by this service revision. This is present for all Express services and reflects the task definition in use, whether managed by Amazon ECS or provided by the customer.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The ARN of the task role for the service revision.
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 |
# File 'lib/aws-sdk-ecs/types.rb', line 8098 class ExpressGatewayServiceConfiguration < Struct.new( :service_revision_arn, :execution_role_arn, :task_role_arn, :task_definition_arn, :cpu, :memory, :cpu_architecture, :network_configuration, :health_check_path, :primary_container, :scaling_target, :ingress_paths, :created_at) SENSITIVE = [] include Aws::Structure end |