Class: Aws::ECS::Types::ExpressGatewayServiceStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

An object that defines the status of Express service creation and information about the status of the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#status_codeString

The status of the Express service.

Returns:

  • (String)


7718
7719
7720
7721
7722
7723
# File 'lib/aws-sdk-ecs/types.rb', line 7718

class ExpressGatewayServiceStatus < Struct.new(
  :status_code,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the Express service is in the current status.

Returns:

  • (String)


7718
7719
7720
7721
7722
7723
# File 'lib/aws-sdk-ecs/types.rb', line 7718

class ExpressGatewayServiceStatus < Struct.new(
  :status_code,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end