Class: Aws::ECS::Types::FSxWindowsFileServerAuthorizationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The authorization configuration details for Amazon FSx for Windows File Server file system. See FSxWindowsFileServerVolumeConfiguration in the Amazon ECS API Reference.

For more information and the input format, see Amazon FSx for Windows File Server Volumes in the Amazon Elastic Container Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#credentials_parameterString

The authorization credential option to use. The authorization credential options can be provided using either the Amazon Resource Name (ARN) of an Secrets Manager secret or SSM Parameter Store parameter. The ARN refers to the stored credentials.

Returns:

  • (String)


8020
8021
8022
8023
8024
8025
# File 'lib/aws-sdk-ecs/types.rb', line 8020

class FSxWindowsFileServerAuthorizationConfig < Struct.new(
  :credentials_parameter,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#domainString

A fully qualified domain name hosted by an Directory Service Managed Microsoft AD (Active Directory) or self-hosted AD on Amazon EC2.

Returns:

  • (String)


8020
8021
8022
8023
8024
8025
# File 'lib/aws-sdk-ecs/types.rb', line 8020

class FSxWindowsFileServerAuthorizationConfig < Struct.new(
  :credentials_parameter,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end