Class: Aws::ECS::Types::InferenceAcceleratorOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Note:

When making an API call, you may pass InferenceAcceleratorOverride data as a hash:

{
  device_name: "String",
  device_type: "String",
}

Details on an Elastic Inference accelerator task override. This parameter is used to override the Elastic Inference accelerator specified in the task definition. For more information, see [Working with Amazon Elastic Inference on Amazon ECS] in the *Amazon Elastic Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-eia.html

Instance Attribute Summary collapse

Instance Attribute Details

#device_nameString

The Elastic Inference accelerator device name to override for the task. This parameter must match a deviceName specified in the task definition.

Returns:

  • (String)


4420
4421
4422
4423
4424
# File 'lib/aws-sdk-ecs/types.rb', line 4420

class InferenceAcceleratorOverride < Struct.new(
  :device_name,
  :device_type)
  include Aws::Structure
end

#device_typeString

The Elastic Inference accelerator type to use.

Returns:

  • (String)


4420
4421
4422
4423
4424
# File 'lib/aws-sdk-ecs/types.rb', line 4420

class InferenceAcceleratorOverride < Struct.new(
  :device_name,
  :device_type)
  include Aws::Structure
end