Class: Aws::ECS::Types::InferenceAcceleratorOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::InferenceAcceleratorOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass InferenceAcceleratorOverride data as a hash:
{
device_name: "String",
device_type: "String",
}
Details on an Elastic Inference accelerator task override. This parameter is used to override the Elastic Inference accelerator specified in the task definition. For more information, see [Working with Amazon Elastic Inference on Amazon ECS] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-eia.html
Instance Attribute Summary collapse
-
#device_name ⇒ String
The Elastic Inference accelerator device name to override for the task.
-
#device_type ⇒ String
The Elastic Inference accelerator type to use.
Instance Attribute Details
#device_name ⇒ String
The Elastic Inference accelerator device name to override for the task. This parameter must match a deviceName specified in the task definition.
4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-ecs/types.rb', line 4420 class InferenceAcceleratorOverride < Struct.new( :device_name, :device_type) include Aws::Structure end |
#device_type ⇒ String
The Elastic Inference accelerator type to use.
4420 4421 4422 4423 4424 |
# File 'lib/aws-sdk-ecs/types.rb', line 4420 class InferenceAcceleratorOverride < Struct.new( :device_name, :device_type) include Aws::Structure end |