Class: Aws::ECS::Types::InstanceLaunchTemplateUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::InstanceLaunchTemplateUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The updated launch template configuration for Amazon ECS Managed Instances. You can modify the instance profile, network configuration, storage settings, and instance requirements. Changes apply to new instances launched after the update.
For more information, see [Store instance launch parameters in Amazon EC2 launch templates] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_reservations ⇒ Types::CapacityReservationRequest
The updated capacity reservations specifications for Amazon ECS Managed Instances.
-
#ec2_instance_profile_arn ⇒ String
The updated Amazon Resource Name (ARN) of the instance profile.
-
#instance_metadata_tags_propagation ⇒ Boolean
Determines whether tags are propagated to the instance metadata service (IMDS) for Amazon EC2 instances launched by the Managed Instances capacity provider.
-
#instance_requirements ⇒ Types::InstanceRequirementsRequest
The updated instance requirements for attribute-based instance type selection.
-
#monitoring ⇒ String
CloudWatch provides two categories of monitoring: basic monitoring and detailed monitoring.
-
#network_configuration ⇒ Types::ManagedInstancesNetworkConfiguration
The updated network configuration for Amazon ECS Managed Instances.
-
#storage_configuration ⇒ Types::ManagedInstancesStorageConfiguration
The updated storage configuration for Amazon ECS Managed Instances.
Instance Attribute Details
#capacity_reservations ⇒ Types::CapacityReservationRequest
The updated capacity reservations specifications for Amazon ECS Managed Instances. Changes to capacity reservations settings apply to new instances launched after the update.
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#ec2_instance_profile_arn ⇒ String
The updated Amazon Resource Name (ARN) of the instance profile. The new instance profile must have the necessary permissions for your tasks.
For more information, see [Amazon ECS instance profile for Managed Instances] in the *Amazon ECS Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/managed-instances-instance-profile.html
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_tags_propagation ⇒ Boolean
Determines whether tags are propagated to the instance metadata service (IMDS) for Amazon EC2 instances launched by the Managed Instances capacity provider. When enabled, all tags associated with the instance are available through the instance metadata service. When disabled, tags are not propagated to IMDS.
Disable this setting if your tags contain characters that are not compatible with IMDS, such as /. IMDS requires tag keys to match the pattern ‘[0-9a-zA-Z-_+=,.@:]1,255`.
The default value is true.
For more information, see [Work with instance tags in instance metadata] in the *Amazon EC2 User Guide*.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#work-with-tags-in-IMDS
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#instance_requirements ⇒ Types::InstanceRequirementsRequest
The updated instance requirements for attribute-based instance type selection. Changes to instance requirements affect which instance types Amazon ECS selects for new instances.
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#monitoring ⇒ String
CloudWatch provides two categories of monitoring: basic monitoring and detailed monitoring. By default, your managed instance is configured for basic monitoring. You can optionally enable detailed monitoring to help you more quickly identify and act on operational issues. You can enable or turn off detailed monitoring at launch or when the managed instance is running or stopped. For more information, see [Detailed monitoring for Amazon ECS Managed Instances] in the Amazon ECS Developer Guide.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/detailed-monitoring-managed-instances.html
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::ManagedInstancesNetworkConfiguration
The updated network configuration for Amazon ECS Managed Instances. Changes to subnets and security groups affect new instances launched after the update.
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |
#storage_configuration ⇒ Types::ManagedInstancesStorageConfiguration
The updated storage configuration for Amazon ECS Managed Instances. Changes to storage settings apply to new instances launched after the update.
7205 7206 7207 7208 7209 7210 7211 7212 7213 7214 7215 |
# File 'lib/aws-sdk-ecs/types.rb', line 7205 class InstanceLaunchTemplateUpdate < Struct.new( :ec2_instance_profile_arn, :network_configuration, :storage_configuration, :instance_metadata_tags_propagation, :monitoring, :instance_requirements, :capacity_reservations) SENSITIVE = [] include Aws::Structure end |