Class: Aws::ECS::Types::ListContainerInstancesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListContainerInstancesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_instance_arns ⇒ Array<String>
The list of container instances with full ARN entries for each container instance associated with the specified cluster.
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListContainerInstancesrequest.
Instance Attribute Details
#container_instance_arns ⇒ Array<String>
The list of container instances with full ARN entries for each container instance associated with the specified cluster.
7951 7952 7953 7954 7955 7956 |
# File 'lib/aws-sdk-ecs/types.rb', line 7951 class ListContainerInstancesResponse < Struct.new( :container_instance_arns, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future ListContainerInstances request. When the results of a ListContainerInstances request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
7951 7952 7953 7954 7955 7956 |
# File 'lib/aws-sdk-ecs/types.rb', line 7951 class ListContainerInstancesResponse < Struct.new( :container_instance_arns, :next_token) SENSITIVE = [] include Aws::Structure end |