Class: Aws::ECS::Types::ListDaemonDeploymentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListDaemonDeploymentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Types::CreatedAt
An optional filter to narrow the
ListDaemonDeploymentsresults by creation time. -
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon to list deployments for.
-
#max_results ⇒ Integer
The maximum number of daemon deployment results that
ListDaemonDeploymentsreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListDaemonDeploymentsrequest indicating that more results are available to fulfill the request and further calls will be needed. -
#status ⇒ Array<String>
An optional filter to narrow the
ListDaemonDeploymentsresults by deployment status.
Instance Attribute Details
#created_at ⇒ Types::CreatedAt
An optional filter to narrow the ListDaemonDeployments results by
creation time. If you don't specify a time range, all deployments
are returned.
9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-ecs/types.rb', line 9879 class ListDaemonDeploymentsRequest < Struct.new( :daemon_arn, :status, :created_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon to list deployments for.
9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-ecs/types.rb', line 9879 class ListDaemonDeploymentsRequest < Struct.new( :daemon_arn, :status, :created_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of daemon deployment results that
ListDaemonDeployments returned in paginated output. When this
parameter is used, ListDaemonDeployments only returns maxResults
results in a single page along with a nextToken response element.
The remaining results of the initial request can be seen by sending
another ListDaemonDeployments request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then ListDaemonDeployments returns up to 20
results and a nextToken value if applicable.
9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-ecs/types.rb', line 9879 class ListDaemonDeploymentsRequest < Struct.new( :daemon_arn, :status, :created_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListDaemonDeployments
request indicating that more results are available to fulfill the
request and further calls will be needed. If maxResults was
provided, it's possible for the number of results to be fewer than
maxResults.
9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-ecs/types.rb', line 9879 class ListDaemonDeploymentsRequest < Struct.new( :daemon_arn, :status, :created_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Array<String>
An optional filter to narrow the ListDaemonDeployments results by
deployment status. If you don't specify a status, all deployments
are returned.
9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-ecs/types.rb', line 9879 class ListDaemonDeploymentsRequest < Struct.new( :daemon_arn, :status, :created_at, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |