Class: Aws::ECS::Types::ListDaemonTaskDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListDaemonTaskDefinitionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#family ⇒ String
The exact name of the daemon task definition family to filter results with.
-
#family_prefix ⇒ String
The full family name to filter the
ListDaemonTaskDefinitionsresults with. -
#max_results ⇒ Integer
The maximum number of daemon task definition results that
ListDaemonTaskDefinitionsreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListDaemonTaskDefinitionsrequest indicating that more results are available to fulfill the request and further calls will be needed. -
#revision ⇒ String
The revision filter to apply.
-
#sort ⇒ String
The order to sort the results.
-
#status ⇒ String
The daemon task definition status to filter the
ListDaemonTaskDefinitionsresults with.
Instance Attribute Details
#family ⇒ String
The exact name of the daemon task definition family to filter results with.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#family_prefix ⇒ String
The full family name to filter the ListDaemonTaskDefinitions
results with. Specifying a familyPrefix limits the listed daemon
task definitions to daemon task definition families that start with
the familyPrefix string.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of daemon task definition results that
ListDaemonTaskDefinitions returned in paginated output. When this
parameter is used, ListDaemonTaskDefinitions only returns
maxResults results in a single page along with a nextToken
response element. The remaining results of the initial request can
be seen by sending another ListDaemonTaskDefinitions request with
the returned nextToken value. This value can be between 1 and 100.
If this parameter isn't used, then ListDaemonTaskDefinitions
returns up to 100 results and a nextToken value if applicable.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListDaemonTaskDefinitions
request indicating that more results are available to fulfill the
request and further calls will be needed. If maxResults was
provided, it's possible for the number of results to be fewer than
maxResults.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ String
The revision filter to apply. Specify LAST_REGISTERED to return
only the last registered revision for each daemon task definition
family.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ String
The order to sort the results. Valid values are ASC and DESC. By
default (ASC), daemon task definitions are listed in ascending
order by family name and revision number.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The daemon task definition status to filter the
ListDaemonTaskDefinitions results with. By default, only ACTIVE
daemon task definitions are listed. If you set this parameter to
DELETE_IN_PROGRESS, only daemon task definitions that are in the
process of being deleted are listed. If you set this parameter to
ALL, all daemon task definitions are listed regardless of status.
9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 |
# File 'lib/aws-sdk-ecs/types.rb', line 9970 class ListDaemonTaskDefinitionsRequest < Struct.new( :family_prefix, :family, :revision, :status, :sort, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |