Class: Aws::ECS::Types::ListDaemonsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListDaemonsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the capacity providers to filter daemons by.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster to filter daemons by.
-
#max_results ⇒ Integer
The maximum number of daemon results that
ListDaemonsreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListDaemonsrequest indicating that more results are available to fulfill the request and further calls will be needed.
Instance Attribute Details
#capacity_provider_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the capacity providers to filter daemons by. Only daemons associated with the specified capacity providers are returned.
10040 10041 10042 10043 10044 10045 10046 10047 |
# File 'lib/aws-sdk-ecs/types.rb', line 10040 class ListDaemonsRequest < Struct.new( :cluster_arn, :capacity_provider_arns, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster to filter daemons by. If you do not specify a cluster, the default cluster is assumed.
10040 10041 10042 10043 10044 10045 10046 10047 |
# File 'lib/aws-sdk-ecs/types.rb', line 10040 class ListDaemonsRequest < Struct.new( :cluster_arn, :capacity_provider_arns, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of daemon results that ListDaemons returned in
paginated output. When this parameter is used, ListDaemons only
returns maxResults results in a single page along with a
nextToken response element. The remaining results of the initial
request can be seen by sending another ListDaemons request with
the returned nextToken value. This value can be between 1 and 100.
If this parameter isn't used, then ListDaemons returns up to 100
results and a nextToken value if applicable.
10040 10041 10042 10043 10044 10045 10046 10047 |
# File 'lib/aws-sdk-ecs/types.rb', line 10040 class ListDaemonsRequest < Struct.new( :cluster_arn, :capacity_provider_arns, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListDaemons request
indicating that more results are available to fulfill the request
and further calls will be needed. If maxResults was provided,
it's possible for the number of results to be fewer than
maxResults.
10040 10041 10042 10043 10044 10045 10046 10047 |
# File 'lib/aws-sdk-ecs/types.rb', line 10040 class ListDaemonsRequest < Struct.new( :cluster_arn, :capacity_provider_arns, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |