Class: Aws::ECS::Types::ListServiceDeploymentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListServiceDeploymentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The cluster that hosts the service.
-
#created_at ⇒ Types::CreatedAt
An optional filter you can use to narrow the results by the service creation date.
-
#max_results ⇒ Integer
The maximum number of service deployment results that
ListServiceDeploymentsreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListServiceDeploymentsrequest indicating that more results are available to fulfill the request and further calls are needed. -
#service ⇒ String
The ARN or name of the service.
-
#status ⇒ Array<String>
An optional filter you can use to narrow the results.
Instance Attribute Details
#cluster ⇒ String
The cluster that hosts the service. This can either be the cluster name or ARN. Starting April 15, 2023, Amazon Web Services will not onboard new customers to Amazon Elastic Inference (EI), and will help current customers migrate their workloads to options that offer better price and performance. If you don’t specify a cluster, default is used.
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 |
# File 'lib/aws-sdk-ecs/types.rb', line 8004 class ListServiceDeploymentsRequest < Struct.new( :service, :cluster, :status, :created_at, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Types::CreatedAt
An optional filter you can use to narrow the results by the service creation date. If you do not specify a value, the result includes all services created before the current time. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 |
# File 'lib/aws-sdk-ecs/types.rb', line 8004 class ListServiceDeploymentsRequest < Struct.new( :service, :cluster, :status, :created_at, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of service deployment results that ListServiceDeployments returned in paginated output. When this parameter is used, ListServiceDeployments only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListServiceDeployments request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then ListServiceDeployments returns up to 20 results and a nextToken value if applicable.
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 |
# File 'lib/aws-sdk-ecs/types.rb', line 8004 class ListServiceDeploymentsRequest < Struct.new( :service, :cluster, :status, :created_at, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListServiceDeployments request indicating that more results are available to fulfill the request and further calls are needed. If you provided maxResults, it’s possible the number of results is fewer than maxResults.
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 |
# File 'lib/aws-sdk-ecs/types.rb', line 8004 class ListServiceDeploymentsRequest < Struct.new( :service, :cluster, :status, :created_at, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The ARN or name of the service
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 |
# File 'lib/aws-sdk-ecs/types.rb', line 8004 class ListServiceDeploymentsRequest < Struct.new( :service, :cluster, :status, :created_at, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Array<String>
An optional filter you can use to narrow the results. If you do not specify a status, then all status values are included in the result.
8004 8005 8006 8007 8008 8009 8010 8011 8012 8013 |
# File 'lib/aws-sdk-ecs/types.rb', line 8004 class ListServiceDeploymentsRequest < Struct.new( :service, :cluster, :status, :created_at, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |