Class: Aws::ECS::Types::ListServicesByNamespaceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListServicesByNamespaceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListServicesByNamespacerequest. -
#service_arns ⇒ Array<String>
The list of full ARN entries for each service that’s associated with the specified namespace.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future ListServicesByNamespace request. When the results of a ListServicesByNamespace request exceed maxResults, this value can be used to retrieve the next page of results. When there are no more results to return, this value is null.
8118 8119 8120 8121 8122 8123 |
# File 'lib/aws-sdk-ecs/types.rb', line 8118 class ListServicesByNamespaceResponse < Struct.new( :service_arns, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arns ⇒ Array<String>
The list of full ARN entries for each service that’s associated with the specified namespace.
8118 8119 8120 8121 8122 8123 |
# File 'lib/aws-sdk-ecs/types.rb', line 8118 class ListServicesByNamespaceResponse < Struct.new( :service_arns, :next_token) SENSITIVE = [] include Aws::Structure end |