Class: Aws::ECS::Types::ListServicesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListServicesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster to use when filtering the
ListServicesresults. -
#launch_type ⇒ String
The launch type to use when filtering the
ListServicesresults. -
#max_results ⇒ Integer
The maximum number of service results that
ListServicesreturned in paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from aListServicesrequest indicating that more results are available to fulfill the request and further calls will be needed. -
#resource_management_type ⇒ String
The resourceManagementType type to use when filtering the
ListServicesresults. -
#scheduling_strategy ⇒ String
The scheduling strategy to use when filtering the
ListServicesresults.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster to use when filtering the ListServices results. If you do not specify a cluster, the default cluster is assumed.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-ecs/types.rb', line 8175 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#launch_type ⇒ String
The launch type to use when filtering the ListServices results.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-ecs/types.rb', line 8175 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of service results that ListServices returned in paginated output. When this parameter is used, ListServices only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListServices request with the returned nextToken value. This value can be between 1 and 100. If this parameter isn’t used, then ListServices returns up to 10 results and a nextToken value if applicable.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-ecs/types.rb', line 8175 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a ListServices request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.
<note markdown=“1”> This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
</note>
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-ecs/types.rb', line 8175 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#resource_management_type ⇒ String
The resourceManagementType type to use when filtering the ListServices results.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-ecs/types.rb', line 8175 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |
#scheduling_strategy ⇒ String
The scheduling strategy to use when filtering the ListServices results.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-ecs/types.rb', line 8175 class ListServicesRequest < Struct.new( :cluster, :next_token, :max_results, :launch_type, :scheduling_strategy, :resource_management_type) SENSITIVE = [] include Aws::Structure end |