Class: Aws::ECS::Types::ListServicesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListServicesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListServicesrequest. -
#service_arns ⇒ Array<String>
The list of full ARN entries for each service that’s associated with the specified cluster.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future ListServices request. When the results of a ListServices request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
8248 8249 8250 8251 8252 8253 |
# File 'lib/aws-sdk-ecs/types.rb', line 8248 class ListServicesResponse < Struct.new( :service_arns, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_arns ⇒ Array<String>
The list of full ARN entries for each service that’s associated with the specified cluster.
8248 8249 8250 8251 8252 8253 |
# File 'lib/aws-sdk-ecs/types.rb', line 8248 class ListServicesResponse < Struct.new( :service_arns, :next_token) SENSITIVE = [] include Aws::Structure end |