Class: Aws::ECS::Types::ListTaskDefinitionFamiliesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ListTaskDefinitionFamiliesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#families ⇒ Array<String>
The list of task definition family names that match the
ListTaskDefinitionFamiliesrequest. -
#next_token ⇒ String
The
nextTokenvalue to include in a futureListTaskDefinitionFamiliesrequest.
Instance Attribute Details
#families ⇒ Array<String>
The list of task definition family names that match the ListTaskDefinitionFamilies request.
8317 8318 8319 8320 8321 8322 |
# File 'lib/aws-sdk-ecs/types.rb', line 8317 class ListTaskDefinitionFamiliesResponse < Struct.new( :families, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value to include in a future ListTaskDefinitionFamilies request. When the results of a ListTaskDefinitionFamilies request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
8317 8318 8319 8320 8321 8322 |
# File 'lib/aws-sdk-ecs/types.rb', line 8317 class ListTaskDefinitionFamiliesResponse < Struct.new( :families, :next_token) SENSITIVE = [] include Aws::Structure end |