Class: Aws::ECS::Types::ManagedInstancesLocalStorageConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ManagedInstancesLocalStorageConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The local storage configuration for Amazon ECS Managed Instances. This defines how ECS uses and configures instance store volumes available on container instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#use_local_storage ⇒ Boolean
Use instance store volumes for data storage when available.
Instance Attribute Details
#use_local_storage ⇒ Boolean
Use instance store volumes for data storage when available. EBS volumes are not provisioned for data storage. If the container instance has multiple instance store volumes, a single data volume is created. Consider defining instance store requirements using the ‘localStorage`, `localStorageTypes` and `totalLocalStorageGB` properties.
10865 10866 10867 10868 10869 |
# File 'lib/aws-sdk-ecs/types.rb', line 10865 class ManagedInstancesLocalStorageConfiguration < Struct.new( :use_local_storage) SENSITIVE = [] include Aws::Structure end |