Class: Aws::ECS::Types::ManagedInstancesNetworkConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The network configuration for Amazon ECS Managed Instances. This specifies the VPC subnets and security groups that instances use for network connectivity. Amazon ECS Managed Instances support multiple network modes including awsvpc (instances receive ENIs for task isolation), host (instances share network namespace with tasks), and none (no external network connectivity), ensuring backward compatibility for migrating workloads from Fargate or Amazon EC2.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_groupsArray<String>

The list of security group IDs to apply to Amazon ECS Managed Instances. These security groups control the network traffic allowed to and from the instances.

Returns:

  • (Array<String>)


11150
11151
11152
11153
11154
11155
# File 'lib/aws-sdk-ecs/types.rb', line 11150

class ManagedInstancesNetworkConfiguration < Struct.new(
  :subnets,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#subnetsArray<String>

The list of subnet IDs where Amazon ECS can launch Amazon ECS Managed Instances. Instances are distributed across the specified subnets for high availability. All subnets must be in the same VPC.

Returns:

  • (Array<String>)


11150
11151
11152
11153
11154
11155
# File 'lib/aws-sdk-ecs/types.rb', line 11150

class ManagedInstancesNetworkConfiguration < Struct.new(
  :subnets,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end