Class: Aws::ECS::Types::ManagedTargetGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The target group associated with the Express service's Application Load Balancer. For more information about load balancer target groups, see CreateTargetGroup in the Elastic Load Balancing API Reference

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the target group.

Returns:

  • (String)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathString

The destination for health checks on the targets.

Returns:

  • (String)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_portInteger

The port the load balancer uses when performing health checks on targets.

Returns:

  • (Integer)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port on which the targets receive traffic.

Returns:

  • (Integer)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the target group.

Returns:

  • (String)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the target group is in the current status.

Returns:

  • (String)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp for when the target group was last updated.

Returns:

  • (Time)


11647
11648
11649
11650
11651
11652
11653
11654
11655
11656
11657
# File 'lib/aws-sdk-ecs/types.rb', line 11647

class ManagedTargetGroup < Struct.new(
  :arn,
  :status,
  :status_reason,
  :updated_at,
  :health_check_path,
  :health_check_port,
  :port)
  SENSITIVE = []
  include Aws::Structure
end