Class: Aws::ECS::Types::MemoryMiBRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The minimum and maximum amount of memory in mebibytes (MiB) for instance type selection. This ensures that selected instance types have adequate memory for your workloads.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maxInteger

The maximum amount of memory in MiB. Instance types with more memory than this value are excluded from selection.

Returns:

  • (Integer)


9723
9724
9725
9726
9727
9728
# File 'lib/aws-sdk-ecs/types.rb', line 9723

class MemoryMiBRequest < Struct.new(
  :min,
  :max)
  SENSITIVE = []
  include Aws::Structure
end

#minInteger

The minimum amount of memory in MiB. Instance types with less memory than this value are excluded from selection.

Returns:

  • (Integer)


9723
9724
9725
9726
9727
9728
# File 'lib/aws-sdk-ecs/types.rb', line 9723

class MemoryMiBRequest < Struct.new(
  :min,
  :max)
  SENSITIVE = []
  include Aws::Structure
end