Class: Aws::ECS::Types::MetricConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The configuration for a specific set of metrics to collect for a service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_namesArray<String>

The list of metric names to configure. The supported metric names are ‘CPUUtilization` and `MemoryUtilization`.

Returns:

  • (Array<String>)


11701
11702
11703
11704
11705
11706
# File 'lib/aws-sdk-ecs/types.rb', line 11701

class MetricConfiguration < Struct.new(
  :metric_names,
  :resolution_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#resolution_secondsInteger

The resolution, in seconds, at which to collect the metrics. The valid values are ‘20` and `60`.

Returns:

  • (Integer)


11701
11702
11703
11704
11705
11706
# File 'lib/aws-sdk-ecs/types.rb', line 11701

class MetricConfiguration < Struct.new(
  :metric_names,
  :resolution_seconds)
  SENSITIVE = []
  include Aws::Structure
end