Class: Aws::ECS::Types::MissingVersionException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Amazon ECS can’t determine the current version of the Amazon ECS container agent on the container instance and doesn’t have enough information to proceed with an update. This could be because the agent running on the container instance is a previous or custom version that doesn’t use our version information.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Message that describes the cause of the exception.

Returns:

  • (String)


11644
11645
11646
11647
11648
# File 'lib/aws-sdk-ecs/types.rb', line 11644

class MissingVersionException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end