Class: Aws::ECS::Types::MonitoringConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The optional monitoring configuration for a service, which defines the resolution for the service-level ‘CPUUtilization` and `MemoryUtilization` Amazon CloudWatch metrics. When not specified, Amazon ECS uses the default resolution of `60` seconds.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metric_configurationsArray<Types::MetricConfiguration>

The list of metric configurations for the service monitoring.

Returns:



11737
11738
11739
11740
11741
# File 'lib/aws-sdk-ecs/types.rb', line 11737

class MonitoringConfiguration < Struct.new(
  :metric_configurations)
  SENSITIVE = []
  include Aws::Structure
end