Class: Aws::ECS::Types::RegisterTaskDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::RegisterTaskDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass RegisterTaskDefinitionRequest data as a hash:
{
family: "String", # required
task_role_arn: "String",
execution_role_arn: "String",
network_mode: "bridge", # accepts bridge, host, awsvpc, none
container_definitions: [ # required
{
name: "String",
image: "String",
repository_credentials: {
credentials_parameter: "String", # required
},
cpu: 1,
memory: 1,
memory_reservation: 1,
links: ["String"],
port_mappings: [
{
container_port: 1,
host_port: 1,
protocol: "tcp", # accepts tcp, udp
},
],
essential: false,
entry_point: ["String"],
command: ["String"],
environment: [
{
name: "String",
value: "String",
},
],
environment_files: [
{
value: "String", # required
type: "s3", # required, accepts s3
},
],
mount_points: [
{
source_volume: "String",
container_path: "String",
read_only: false,
},
],
volumes_from: [
{
source_container: "String",
read_only: false,
},
],
linux_parameters: {
capabilities: {
add: ["String"],
drop: ["String"],
},
devices: [
{
host_path: "String", # required
container_path: "String",
permissions: ["read"], # accepts read, write, mknod
},
],
init_process_enabled: false,
shared_memory_size: 1,
tmpfs: [
{
container_path: "String", # required
size: 1, # required
mount_options: ["String"],
},
],
max_swap: 1,
swappiness: 1,
},
secrets: [
{
name: "String", # required
value_from: "String", # required
},
],
depends_on: [
{
container_name: "String", # required
condition: "START", # required, accepts START, COMPLETE, SUCCESS, HEALTHY
},
],
start_timeout: 1,
stop_timeout: 1,
hostname: "String",
user: "String",
working_directory: "String",
disable_networking: false,
privileged: false,
readonly_root_filesystem: false,
dns_servers: ["String"],
dns_search_domains: ["String"],
extra_hosts: [
{
hostname: "String", # required
ip_address: "String", # required
},
],
docker_security_options: ["String"],
interactive: false,
pseudo_terminal: false,
docker_labels: {
"String" => "String",
},
ulimits: [
{
name: "core", # required, accepts core, cpu, data, fsize, locks, memlock, msgqueue, nice, nofile, nproc, rss, rtprio, rttime, sigpending, stack
soft_limit: 1, # required
hard_limit: 1, # required
},
],
log_configuration: {
log_driver: "json-file", # required, accepts json-file, syslog, journald, gelf, fluentd, awslogs, splunk, awsfirelens
options: {
"String" => "String",
},
secret_options: [
{
name: "String", # required
value_from: "String", # required
},
],
},
health_check: {
command: ["String"], # required
interval: 1,
timeout: 1,
retries: 1,
start_period: 1,
},
system_controls: [
{
namespace: "String",
value: "String",
},
],
resource_requirements: [
{
value: "String", # required
type: "GPU", # required, accepts GPU, InferenceAccelerator
},
],
firelens_configuration: {
type: "fluentd", # required, accepts fluentd, fluentbit
options: {
"String" => "String",
},
},
},
],
volumes: [
{
name: "String",
host: {
source_path: "String",
},
docker_volume_configuration: {
scope: "task", # accepts task, shared
autoprovision: false,
driver: "String",
driver_opts: {
"String" => "String",
},
labels: {
"String" => "String",
},
},
efs_volume_configuration: {
file_system_id: "String", # required
root_directory: "String",
transit_encryption: "ENABLED", # accepts ENABLED, DISABLED
transit_encryption_port: 1,
authorization_config: {
access_point_id: "String",
iam: "ENABLED", # accepts ENABLED, DISABLED
},
},
fsx_windows_file_server_volume_configuration: {
file_system_id: "String", # required
root_directory: "String", # required
authorization_config: { # required
credentials_parameter: "String", # required
domain: "String", # required
},
},
},
],
placement_constraints: [
{
type: "memberOf", # accepts memberOf
expression: "String",
},
],
requires_compatibilities: ["EC2"], # accepts EC2, FARGATE
cpu: "String",
memory: "String",
tags: [
{
key: "TagKey",
value: "TagValue",
},
],
pid_mode: "host", # accepts host, task
ipc_mode: "host", # accepts host, task, none
proxy_configuration: {
type: "APPMESH", # accepts APPMESH
container_name: "String", # required
properties: [
{
name: "String",
value: "String",
},
],
},
inference_accelerators: [
{
device_name: "String", # required
device_type: "String", # required
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_definitions ⇒ Array<Types::ContainerDefinition>
A list of container definitions in JSON format that describe the different containers that make up your task.
-
#cpu ⇒ String
The number of CPU units used by the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make AWS API calls on your behalf.
-
#family ⇒ String
You must specify a
familyfor a task definition, which allows you to track multiple versions of the same task definition. -
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerators to use for the containers in the task.
-
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task.
-
#memory ⇒ String
The amount of memory (in MiB) used by the task.
-
#network_mode ⇒ String
The Docker networking mode to use for the containers in the task.
-
#pid_mode ⇒ String
The process namespace to use for the containers in the task.
-
#placement_constraints ⇒ Array<Types::TaskDefinitionPlacementConstraint>
An array of placement constraint objects to use for the task.
-
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration details for the App Mesh proxy.
-
#requires_compatibilities ⇒ Array<String>
The task launch type that Amazon ECS should validate the task definition against.
-
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task definition to help you categorize and organize them.
-
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the IAM role that containers in this task can assume.
-
#volumes ⇒ Array<Types::Volume>
A list of volume definitions in JSON format that containers in your task may use.
Instance Attribute Details
#container_definitions ⇒ Array<Types::ContainerDefinition>
A list of container definitions in JSON format that describe the different containers that make up your task.
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#cpu ⇒ String
The number of CPU units used by the task. It can be expressed as an integer using CPU units, for example 1024, or as a string using vCPUs, for example ‘1 vCPU` or `1 vcpu`, in a task definition. String values are converted to an integer indicating the CPU units when the task definition is registered.
<note markdown=“1”> Task-level CPU and memory parameters are ignored for Windows containers. We recommend specifying container-level resources for Windows containers.
</note>
If you are using the EC2 launch type, this field is optional. Supported values are between 128 CPU units (0.125 vCPUs) and 10240 CPU units (10 vCPUs).
If you are using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of supported values for the memory parameter:
-
256 (.25 vCPU) - Available
memoryvalues: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) -
512 (.5 vCPU) - Available
memoryvalues: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) -
1024 (1 vCPU) - Available
memoryvalues: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) -
2048 (2 vCPU) - Available
memoryvalues: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) -
4096 (4 vCPU) - Available
memoryvalues: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make AWS API calls on your behalf. The task execution IAM role is required depending on the requirements of your task. For more information, see [Amazon ECS task execution IAM role] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_execution_IAM_role.html
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#family ⇒ String
You must specify a family for a task definition, which allows you to track multiple versions of the same task definition. The family is used as a name for your task definition. Up to 255 letters (uppercase and lowercase), numbers, and hyphens are allowed.
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerators to use for the containers in the task.
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task. The valid values are host, task, or none. If host is specified, then all containers within the tasks that specified the host IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same IPC resources. If none is specified, then IPC resources within the containers of a task are private and not shared with other containers in a task or on the container instance. If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see [IPC settings] in the *Docker run reference*.
If the host IPC mode is used, be aware that there is a heightened risk of undesired IPC namespace expose. For more information, see [Docker security].
If you are setting namespaced kernel parameters using systemControls for the containers in the task, the following will apply to your IPC resource namespace. For more information, see
- System Controls][3
-
in the *Amazon Elastic Container Service
Developer Guide*.
-
For tasks that use the
hostIPC mode, IPC namespace relatedsystemControlsare not supported. -
For tasks that use the
taskIPC mode, IPC namespace relatedsystemControlswill apply to all containers within a task.
<note markdown=“1”> This parameter is not supported for Windows containers or tasks using the Fargate launch type.
</note>
[1]: docs.docker.com/engine/reference/run/#ipc-settings—ipc [2]: docs.docker.com/engine/security/security/ [3]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The amount of memory (in MiB) used by the task. It can be expressed as an integer using MiB, for example 1024, or as a string using GB, for example 1GB or ‘1 GB`, in a task definition. String values are converted to an integer indicating the MiB when the task definition is registered.
<note markdown=“1”> Task-level CPU and memory parameters are ignored for Windows containers. We recommend specifying container-level resources for Windows containers.
</note>
If using the EC2 launch type, this field is optional.
If using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of supported values for the cpu parameter:
-
512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available
cpuvalues: 256 (.25 vCPU) -
1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available
cpuvalues: 512 (.5 vCPU) -
2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available
cpuvalues: 1024 (1 vCPU) -
Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 2048 (2 vCPU)
-
-
Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 4096 (4 vCPU)
-
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#network_mode ⇒ String
The Docker networking mode to use for the containers in the task. The valid values are none, bridge, awsvpc, and host. If no network mode is specified, the default is bridge.
For Amazon ECS tasks on Fargate, the awsvpc network mode is required. For Amazon ECS tasks on Amazon EC2 instances, any network mode can be used. If the network mode is set to none, you cannot specify port mappings in your container definitions, and the tasks containers do not have external connectivity. The host and awsvpc network modes offer the highest networking performance for containers because they use the EC2 network stack instead of the virtualized network stack provided by the bridge mode.
With the host and awsvpc network modes, exposed container ports are mapped directly to the corresponding host port (for the host network mode) or the attached elastic network interface port (for the awsvpc network mode), so you cannot take advantage of dynamic host port mappings.
When using the host network mode, you should not run containers using the root user (UID 0). It is considered best practice to use a non-root user.
If the network mode is awsvpc, the task is allocated an elastic network interface, and you must specify a NetworkConfiguration value when you create a service or run a task with the task definition. For more information, see [Task Networking] in the *Amazon Elastic Container Service Developer Guide*.
<note markdown=“1”> Currently, only Amazon ECS-optimized AMIs, other Amazon Linux variants with the ecs-init package, or AWS Fargate infrastructure support the awsvpc network mode.
</note>
If the network mode is host, you cannot run multiple instantiations of the same task on a single container instance when port mappings are used.
Docker for Windows uses different network modes than Docker for Linux. When you register a task definition with Windows containers, you must not specify a network mode. If you use the console to register a task definition with Windows containers, you must choose the ‘<default>` network mode object.
For more information, see [Network settings] in the *Docker run reference*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html [2]: docs.docker.com/engine/reference/run/#network-settings
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#pid_mode ⇒ String
The process namespace to use for the containers in the task. The valid values are host or task. If host is specified, then all containers within the tasks that specified the host PID mode on the same container instance share the same process namespace with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same process namespace. If no value is specified, the default is a private namespace. For more information, see [PID settings] in the *Docker run reference*.
If the host PID mode is used, be aware that there is a heightened risk of undesired process namespace expose. For more information, see [Docker security].
<note markdown=“1”> This parameter is not supported for Windows containers or tasks using the Fargate launch type.
</note>
[1]: docs.docker.com/engine/reference/run/#pid-settings—pid [2]: docs.docker.com/engine/security/security/
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#placement_constraints ⇒ Array<Types::TaskDefinitionPlacementConstraint>
An array of placement constraint objects to use for the task. You can specify a maximum of 10 constraints per task (this limit includes constraints in the task definition and those specified at runtime).
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration details for the App Mesh proxy.
For tasks using the EC2 launch type, the container instances require at least version 1.26.0 of the container agent and at least version 1.26.0-1 of the ecs-init package to enable a proxy configuration. If your container instances are launched from the Amazon ECS-optimized AMI version 20190301 or later, then they contain the required versions of the container agent and ecs-init. For more information, see [Amazon ECS-optimized Linux AMI]
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#requires_compatibilities ⇒ Array<String>
The task launch type that Amazon ECS should validate the task definition against. This ensures that the task definition parameters are compatible with the specified launch type. If no value is specified, it defaults to EC2.
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The metadata that you apply to the task definition to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.
The following basic restrictions apply to tags:
-
Maximum number of tags per resource - 50
-
For each resource, each tag key must be unique, and each tag key can have only one value.
-
Maximum key length - 128 Unicode characters in UTF-8
-
Maximum value length - 256 Unicode characters in UTF-8
-
If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
-
Tag keys and values are case-sensitive.
-
Do not use
aws:,AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the IAM role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role. For more information, see [IAM Roles for Tasks] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
A list of volume definitions in JSON format that containers in your task may use.
7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 |
# File 'lib/aws-sdk-ecs/types.rb', line 7911 class RegisterTaskDefinitionRequest < Struct.new( :family, :task_role_arn, :execution_role_arn, :network_mode, :container_definitions, :volumes, :placement_constraints, :requires_compatibilities, :cpu, :memory, :tags, :pid_mode, :ipc_mode, :proxy_configuration, :inference_accelerators) SENSITIVE = [] include Aws::Structure end |