Method: Aws::ECS::Types::RunTaskResponse#tasks
- Defined in:
- lib/aws-sdk-ecs/types.rb
#tasks ⇒ Array<Types::Task>
A full description of the tasks that were run. The tasks that were successfully placed on your cluster are described here.
7487 7488 7489 7490 7491 |
# File 'lib/aws-sdk-ecs/types.rb', line 7487 class RunTaskResponse < Struct.new( :tasks, :failures) include Aws::Structure end |