Class: Aws::ECS::Types::RuntimePlatform

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about the platform for the Amazon ECS service or task.

For more information about RuntimePlatform, see RuntimePlatform in the Amazon Elastic Container Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_architectureString

The CPU architecture.

You can run your Linux tasks on an ARM-based platform by setting the value to ARM64. This option is available for tasks that run on Linux Amazon EC2 instance, Amazon ECS Managed Instances, or Linux containers on Fargate.

Returns:

  • (String)


14106
14107
14108
14109
14110
14111
# File 'lib/aws-sdk-ecs/types.rb', line 14106

class RuntimePlatform < Struct.new(
  :cpu_architecture,
  :operating_system_family)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system_familyString

The operating system.

Returns:

  • (String)


14106
14107
14108
14109
14110
14111
# File 'lib/aws-sdk-ecs/types.rb', line 14106

class RuntimePlatform < Struct.new(
  :cpu_architecture,
  :operating_system_family)
  SENSITIVE = []
  include Aws::Structure
end