Class: Aws::ECS::Types::RuntimePlatform
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::RuntimePlatform
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Information about the platform for the Amazon ECS service or task.
For more information about RuntimePlatform, see [RuntimePlatform] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html#runtime-platform
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpu_architecture ⇒ String
The CPU architecture.
-
#operating_system_family ⇒ String
The operating system.
Instance Attribute Details
#cpu_architecture ⇒ String
The CPU architecture.
You can run your Linux tasks on an ARM-based platform by setting the value to ARM64. This option is available for tasks that run on Linux Amazon EC2 instance, Amazon ECS Managed Instances, or Linux containers on Fargate.
11948 11949 11950 11951 11952 11953 |
# File 'lib/aws-sdk-ecs/types.rb', line 11948 class RuntimePlatform < Struct.new( :cpu_architecture, :operating_system_family) SENSITIVE = [] include Aws::Structure end |
#operating_system_family ⇒ String
The operating system.
11948 11949 11950 11951 11952 11953 |
# File 'lib/aws-sdk-ecs/types.rb', line 11948 class RuntimePlatform < Struct.new( :cpu_architecture, :operating_system_family) SENSITIVE = [] include Aws::Structure end |