Class: Aws::ECS::Types::RuntimePlatformOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::RuntimePlatformOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The runtime platform that Amazon ECS applies to a service revision. This value overrides the runtime platform specified in the task definition. You can't set this value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpu_architecture ⇒ String
The CPU architecture that tasks in this service revision run on.
Instance Attribute Details
#cpu_architecture ⇒ String
The CPU architecture that tasks in this service revision run on. This value might differ from the architecture declared in the task definition—for example, when Amazon ECS detects an architecture mismatch during an Amazon ECS Express deployment and runs tasks on a different architecture. You can't set this value.
Valid values:
-
X86_64- The x86 64-bit architecture. -
ARM64- The 64-bit ARM architecture.
14133 14134 14135 14136 14137 |
# File 'lib/aws-sdk-ecs/types.rb', line 14133 class RuntimePlatformOverride < Struct.new( :cpu_architecture) SENSITIVE = [] include Aws::Structure end |