Class: Aws::ECS::Types::ServiceConnectTestTrafficHeaderMatchRules

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The header matching rules for test traffic routing in Amazon ECS blue/green deployments. These rules determine how incoming requests are matched based on HTTP headers to route test traffic to the new service revision.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exactString

The exact value that the HTTP header must match for the test traffic routing rule to apply. This provides precise control over which requests are routed to the new service revision during blue/green deployments.

Returns:

  • (String)


14904
14905
14906
14907
14908
# File 'lib/aws-sdk-ecs/types.rb', line 14904

class ServiceConnectTestTrafficHeaderMatchRules < Struct.new(
  :exact)
  SENSITIVE = []
  include Aws::Structure
end