Class: Aws::ECS::Types::ServiceDeployment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Information about the service deployment.

Service deployments provide a comprehensive view of your deployments. For information about service deployments, see [View service history using Amazon ECS service deployments] in the Amazon Elastic Container Service Developer Guide .

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-deployment.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarmsTypes::ServiceDeploymentAlarms

The CloudWatch alarms that determine when a service deployment fails.



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_arnString

The ARN of the cluster that hosts the service.

Returns:

  • (String)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time the service deployment was created. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_circuit_breakerTypes::ServiceDeploymentCircuitBreaker

The circuit breaker configuration that determines a service deployment failed.



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configurationTypes::DeploymentConfiguration

Optional deployment parameters that control how many tasks run during a deployment and the ordering of stopping and starting tasks.



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#finished_atTime

The time the service deployment finished. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_hook_detailsArray<Types::DeploymentLifecycleHookDetail>

The details of the lifecycle hooks for the current service deployment.



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_stageString

The current lifecycle stage of the deployment. Possible values include:

  • RECONCILE_SERVICE

    The reconciliation stage that only happens when you start a new service deployment with more than 1 service revision in an ACTIVE state.

  • PRE_SCALE_UP

    The green service revision has not started. The blue service revision is handling 100% of the production traffic. There is no test traffic.

  • SCALE_UP

    The stage when the green service revision scales up to 100% and launches new tasks. The green service revision is not serving any traffic at this point.

  • POST_SCALE_UP

    The green service revision has started. The blue service revision is handling 100% of the production traffic. There is no test traffic.

  • TEST_TRAFFIC_SHIFT

    The blue and green service revisions are running. The blue service revision handles 100% of the production traffic. The green service revision is migrating from 0% to 100% of test traffic.

  • POST_TEST_TRAFFIC_SHIFT

    The test traffic shift is complete. The green service revision handles 100% of the test traffic.

  • PRODUCTION_TRAFFIC_SHIFT

    Production traffic is shifting to the green service revision. The green service revision is migrating from 0% to 100% of production traffic.

  • POST_PRODUCTION_TRAFFIC_SHIFT

    The production traffic shift is complete.

  • BAKE_TIME

    The stage when both blue and green service revisions are running simultaneously after the production traffic has shifted.

  • CLEAN_UP

    The stage when the blue service revision has completely scaled down to 0 running tasks. The green service revision is now the production service revision after this stage.

Returns:

  • (String)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#rollbackTypes::Rollback

The rollback options the service deployment uses when the deployment fails.

Returns:



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The ARN of the service for this service deployment.

Returns:

  • (String)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#service_deployment_arnString

The ARN of the service deployment.

Returns:

  • (String)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#source_service_revisionsArray<Types::ServiceRevisionSummary>

The currently deployed workload configuration.

Returns:



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The time the service deployment statred. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The service deployment state.

Returns:

  • (String)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Information about why the service deployment is in the current status. For example, the circuit breaker detected a failure.

Returns:

  • (String)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The time the service deployment stopped. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

The service deployment stops when any of the following actions happen:

  • A user manually stops the deployment

  • The rollback option is not in use for the failure detection mechanism (the circuit breaker or alarm-based) and the service fails.

Returns:

  • (Time)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#target_service_revisionTypes::ServiceRevisionSummary

The workload configuration being deployed.



15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time that the service deployment was last updated. The format is yyyy-MM-dd HH:mm:ss.SSSSSS.

Returns:

  • (Time)


15102
15103
15104
15105
15106
15107
15108
15109
15110
15111
15112
15113
15114
15115
15116
15117
15118
15119
15120
15121
15122
15123
# File 'lib/aws-sdk-ecs/types.rb', line 15102

class ServiceDeployment < Struct.new(
  :service_deployment_arn,
  :service_arn,
  :cluster_arn,
  :created_at,
  :started_at,
  :finished_at,
  :stopped_at,
  :updated_at,
  :source_service_revisions,
  :target_service_revision,
  :status,
  :status_reason,
  :lifecycle_stage,
  :lifecycle_hook_details,
  :deployment_configuration,
  :rollback,
  :deployment_circuit_breaker,
  :alarms)
  SENSITIVE = []
  include Aws::Structure
end