Class: Aws::ECS::Types::ServiceRevisionLoadBalancer
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ServiceRevisionLoadBalancer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The resolved load balancer configuration for a service revision. This includes information about which target groups serve traffic and which listener rules direct traffic to them.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#production_listener_rule ⇒ String
The Amazon Resource Name (ARN) of the production listener rule or listener that directs traffic to the target group associated with the service revision.
-
#target_group_arn ⇒ String
The Amazon Resource Name (ARN) of the target group associated with the service revision.
Instance Attribute Details
#production_listener_rule ⇒ String
The Amazon Resource Name (ARN) of the production listener rule or listener that directs traffic to the target group associated with the service revision.
15792 15793 15794 15795 15796 15797 |
# File 'lib/aws-sdk-ecs/types.rb', line 15792 class ServiceRevisionLoadBalancer < Struct.new( :target_group_arn, :production_listener_rule) SENSITIVE = [] include Aws::Structure end |
#target_group_arn ⇒ String
The Amazon Resource Name (ARN) of the target group associated with the service revision.
15792 15793 15794 15795 15796 15797 |
# File 'lib/aws-sdk-ecs/types.rb', line 15792 class ServiceRevisionLoadBalancer < Struct.new( :target_group_arn, :production_listener_rule) SENSITIVE = [] include Aws::Structure end |