Class: Aws::ECS::Types::ServiceRevisionOverrides
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ServiceRevisionOverrides
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Contains the runtime overrides that Amazon ECS automatically applies to a service revision when the effective runtime configuration differs from the task definition. This value is read-only.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#runtime_platform ⇒ Types::RuntimePlatformOverride
The runtime platform override that Amazon ECS automatically applies to the service revision.
Instance Attribute Details
#runtime_platform ⇒ Types::RuntimePlatformOverride
The runtime platform override that Amazon ECS automatically applies to the service revision. You can't set this value.
16024 16025 16026 16027 16028 |
# File 'lib/aws-sdk-ecs/types.rb', line 16024 class ServiceRevisionOverrides < Struct.new( :runtime_platform) SENSITIVE = [] include Aws::Structure end |