Class: Aws::ECS::Types::SubmitTaskStateChangeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::SubmitTaskStateChangeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Types::AttachmentStateChange>
Any attachments associated with the state change request.
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task.
-
#containers ⇒ Array<Types::ContainerStateChange>
Any containers that’s associated with the state change request.
-
#execution_stopped_at ⇒ Time
The Unix timestamp for the time when the task execution stopped.
-
#managed_agents ⇒ Array<Types::ManagedAgentStateChange>
The details for the managed agent that’s associated with the task.
-
#pull_started_at ⇒ Time
The Unix timestamp for the time when the container image pull started.
-
#pull_stopped_at ⇒ Time
The Unix timestamp for the time when the container image pull completed.
-
#reason ⇒ String
The reason for the state change request.
-
#status ⇒ String
The status of the state change request.
-
#task ⇒ String
The task ID or full ARN of the task in the state change request.
Instance Attribute Details
#attachments ⇒ Array<Types::AttachmentStateChange>
Any attachments associated with the state change request.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#containers ⇒ Array<Types::ContainerStateChange>
Any containers that’s associated with the state change request.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#execution_stopped_at ⇒ Time
The Unix timestamp for the time when the task execution stopped.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#managed_agents ⇒ Array<Types::ManagedAgentStateChange>
The details for the managed agent that’s associated with the task.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#pull_started_at ⇒ Time
The Unix timestamp for the time when the container image pull started.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#pull_stopped_at ⇒ Time
The Unix timestamp for the time when the container image pull completed.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason for the state change request.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the state change request.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |
#task ⇒ String
The task ID or full ARN of the task in the state change request.
16507 16508 16509 16510 16511 16512 16513 16514 16515 16516 16517 16518 16519 16520 |
# File 'lib/aws-sdk-ecs/types.rb', line 16507 class SubmitTaskStateChangeRequest < Struct.new( :cluster, :task, :status, :reason, :containers, :attachments, :managed_agents, :pull_started_at, :pull_stopped_at, :execution_stopped_at) SENSITIVE = [] include Aws::Structure end |