Class: Aws::ECS::Types::SystemControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::SystemControl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass SystemControl data as a hash:
{
namespace: "String",
value: "String",
}
A list of namespaced kernel parameters to set in the container. This parameter maps to Sysctls in the [Create a container] section of the [Docker Remote API] and the --sysctl option to [docker run].
It is not recommended that you specify network-related systemControls parameters for multiple containers in a single task that also uses either the awsvpc or host network mode for the following reasons:
-
For tasks that use the
awsvpcnetwork mode, if you setsystemControlsfor any container, it applies to all containers in the task. If you set differentsystemControlsfor multiple containers in a single task, the container that is started last determines whichsystemControlstake effect. -
For tasks that use the
hostnetwork mode, thesystemControlsparameter applies to the container instance’s kernel parameter as well as that of all containers of any tasks running on that container instance.
[1]: docs.docker.com/engine/api/v1.35/#operation/ContainerCreate [2]: docs.docker.com/engine/api/v1.35/ [3]: docs.docker.com/engine/reference/run/
Instance Attribute Summary collapse
-
#namespace ⇒ String
The namespaced kernel parameter for which to set a
value. -
#value ⇒ String
The value for the namespaced kernel parameter specified in
namespace.
Instance Attribute Details
#namespace ⇒ String
The namespaced kernel parameter for which to set a value.
8474 8475 8476 8477 8478 |
# File 'lib/aws-sdk-ecs/types.rb', line 8474 class SystemControl < Struct.new( :namespace, :value) include Aws::Structure end |
#value ⇒ String
The value for the namespaced kernel parameter specified in namespace.
8474 8475 8476 8477 8478 |
# File 'lib/aws-sdk-ecs/types.rb', line 8474 class SystemControl < Struct.new( :namespace, :value) include Aws::Structure end |