Class: Aws::ECS::Types::SystemControl
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::SystemControl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
A list of namespaced kernel parameters to set in the container. This parameter maps to Sysctls in the docker container create command and the --sysctl option to docker run. For example, you can configure net.ipv4.tcp_keepalive_time setting to maintain longer lived connections.
We don’t recommend that you specify network-related systemControls parameters for multiple containers in a single task that also uses either the awsvpc or host network mode. Doing this has the following disadvantages:
-
For tasks that use the
awsvpcnetwork mode including Fargate, if you setsystemControlsfor any container, it applies to all containers in the task. If you set differentsystemControlsfor multiple containers in a single task, the container that’s started last determines whichsystemControlstake effect. -
For tasks that use the
hostnetwork mode, the network namespacesystemControlsaren’t supported.
If you’re setting an IPC resource namespace to use for the containers in the task, the following conditions apply to your system controls. For more information, see [IPC mode].
-
For tasks that use the
hostIPC mode, IPC namespacesystemControlsaren’t supported. -
For tasks that use the
taskIPC mode, IPC namespacesystemControlsvalues apply to all containers within a task.
<note markdown=“1”> This parameter is not supported for Windows containers.
</note>
<note markdown=“1”> This parameter is only supported for tasks that are hosted on Fargate if the tasks are using platform version 1.4.0 or later (Linux). This isn’t supported for Windows containers on Fargate.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#namespace ⇒ String
The namespaced kernel parameter to set a
valuefor. -
#value ⇒ String
The namespaced kernel parameter to set a
valuefor.
Instance Attribute Details
#namespace ⇒ String
The namespaced kernel parameter to set a value for.
14250 14251 14252 14253 14254 14255 |
# File 'lib/aws-sdk-ecs/types.rb', line 14250 class SystemControl < Struct.new( :namespace, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The namespaced kernel parameter to set a value for.
Valid IPC namespace values: ‘“kernel.msgmax” | “kernel.msgmnb” | “kernel.msgmni” | “kernel.sem” | “kernel.shmall” | “kernel.shmmax” | “kernel.shmmni” | “kernel.shm_rmid_forced”`, and Sysctls that start with `“fs.mqueue.*”`
Valid network namespace values: Sysctls that start with ‘“net.*”`. Only namespaced Sysctls that exist within the container starting with “net.* are accepted.
All of these values are supported by Fargate.
14250 14251 14252 14253 14254 14255 |
# File 'lib/aws-sdk-ecs/types.rb', line 14250 class SystemControl < Struct.new( :namespace, :value) SENSITIVE = [] include Aws::Structure end |