Class: Aws::ECS::Types::TargetNotConnectedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The execute command cannot run. This error can be caused by any of the following configuration issues:

  • Incorrect IAM permissions

  • The SSM agent is not installed or is not running

  • There is an interface Amazon VPC endpoint for Amazon ECS, but there is not one for Systems Manager Session Manager

For information about how to troubleshoot the issues, see

Troubleshooting issues with ECS Exec][1

in the *Amazon Elastic

Container Service Developer Guide*.

[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-exec.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Message that describes the cause of the exception.

Returns:

  • (String)


16416
16417
16418
16419
16420
# File 'lib/aws-sdk-ecs/types.rb', line 16416

class TargetNotConnectedException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end