Class: Aws::ECS::Types::TaskDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The details of a task definition which describes the container and volume definitions of an Amazon Elastic Container Service task. You can specify which Docker images to use, the required resources, and other configurations related to launching the task definition through an Amazon ECS service or task.
Instance Attribute Summary collapse
-
#compatibilities ⇒ Array<String>
The launch type to use with your task.
-
#container_definitions ⇒ Array<Types::ContainerDefinition>
A list of container definitions in JSON format that describe the different containers that make up your task.
-
#cpu ⇒ String
The number of
cpuunits used by the task. -
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that containers in this task can assume.
-
#family ⇒ String
The name of a family that this task definition is registered to.
-
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerator associated with the task.
-
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task.
-
#memory ⇒ String
The amount (in MiB) of memory used by the task.
-
#network_mode ⇒ String
The Docker networking mode to use for the containers in the task.
-
#pid_mode ⇒ String
The process namespace to use for the containers in the task.
-
#placement_constraints ⇒ Array<Types::TaskDefinitionPlacementConstraint>
An array of placement constraint objects to use for tasks.
-
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration details for the App Mesh proxy.
-
#requires_attributes ⇒ Array<Types::Attribute>
The container instance attributes required by your task.
-
#requires_compatibilities ⇒ Array<String>
The launch type the task requires.
-
#revision ⇒ Integer
The revision of the task in a particular family.
-
#status ⇒ String
The status of the task definition.
-
#task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the task definition.
-
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants containers in the task permission to call AWS APIs on your behalf.
-
#volumes ⇒ Array<Types::Volume>
The list of volume definitions for the task.
Instance Attribute Details
#compatibilities ⇒ Array<String>
The launch type to use with your task. For more information, see
- Amazon ECS Launch Types][1
-
in the *Amazon Elastic Container
Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#container_definitions ⇒ Array<Types::ContainerDefinition>
A list of container definitions in JSON format that describe the different containers that make up your task. For more information about container definition parameters and defaults, see [Amazon ECS Task Definitions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_defintions.html
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#cpu ⇒ String
The number of cpu units used by the task. If you are using the EC2 launch type, this field is optional and any value can be used. If you are using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of valid values for the memory parameter:
-
256 (.25 vCPU) - Available
memoryvalues: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) -
512 (.5 vCPU) - Available
memoryvalues: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) -
1024 (1 vCPU) - Available
memoryvalues: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) -
2048 (2 vCPU) - Available
memoryvalues: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) -
4096 (4 vCPU) - Available
memoryvalues: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#family ⇒ String
The name of a family that this task definition is registered to. A family groups multiple versions of a task definition. Amazon ECS gives the first task definition that you registered to a family a revision number of 1. Amazon ECS gives sequential revision numbers to each task definition that you add.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#inference_accelerators ⇒ Array<Types::InferenceAccelerator>
The Elastic Inference accelerator associated with the task.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#ipc_mode ⇒ String
The IPC resource namespace to use for the containers in the task. The valid values are host, task, or none. If host is specified, then all containers within the tasks that specified the host IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same IPC resources. If none is specified, then IPC resources within the containers of a task are private and not shared with other containers in a task or on the container instance. If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see [IPC settings] in the *Docker run reference*.
If the host IPC mode is used, be aware that there is a heightened risk of undesired IPC namespace expose. For more information, see [Docker security].
If you are setting namespaced kernel parameters using systemControls for the containers in the task, the following will apply to your IPC resource namespace. For more information, see
- System Controls][3
-
in the *Amazon Elastic Container Service
Developer Guide*.
-
For tasks that use the
hostIPC mode, IPC namespace relatedsystemControlsare not supported. -
For tasks that use the
taskIPC mode, IPC namespace relatedsystemControlswill apply to all containers within a task.
<note markdown=“1”> This parameter is not supported for Windows containers or tasks using the Fargate launch type.
</note>
[1]: docs.docker.com/engine/reference/run/#ipc-settings—ipc [2]: docs.docker.com/engine/security/security/ [3]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#memory ⇒ String
The amount (in MiB) of memory used by the task.
If using the EC2 launch type, this field is optional and any value can be used. If a task-level memory value is specified then the container-level memory value is optional.
If using the Fargate launch type, this field is required and you must use one of the following values, which determines your range of valid values for the cpu parameter:
-
512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available
cpuvalues: 256 (.25 vCPU) -
1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available
cpuvalues: 512 (.5 vCPU) -
2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available
cpuvalues: 1024 (1 vCPU) -
Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 2048 (2 vCPU)
-
-
Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
-
Available
cpuvalues: 4096 (4 vCPU)
-
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#network_mode ⇒ String
The Docker networking mode to use for the containers in the task. The valid values are none, bridge, awsvpc, and host. The default Docker network mode is bridge. If you are using the Fargate launch type, the awsvpc network mode is required. If you are using the EC2 launch type, any network mode can be used. If the network mode is set to none, you cannot specify port mappings in your container definitions, and the tasks containers do not have external connectivity. The host and awsvpc network modes offer the highest networking performance for containers because they use the EC2 network stack instead of the virtualized network stack provided by the bridge mode.
With the host and awsvpc network modes, exposed container ports are mapped directly to the corresponding host port (for the host network mode) or the attached elastic network interface port (for the awsvpc network mode), so you cannot take advantage of dynamic host port mappings.
If the network mode is awsvpc, the task is allocated an elastic network interface, and you must specify a NetworkConfiguration value when you create a service or run a task with the task definition. For more information, see [Task Networking] in the *Amazon Elastic Container Service Developer Guide*.
<note markdown=“1”> Currently, only Amazon ECS-optimized AMIs, other Amazon Linux variants with the ecs-init package, or AWS Fargate infrastructure support the awsvpc network mode.
</note>
If the network mode is host, you cannot run multiple instantiations of the same task on a single container instance when port mappings are used.
Docker for Windows uses different network modes than Docker for Linux. When you register a task definition with Windows containers, you must not specify a network mode. If you use the console to register a task definition with Windows containers, you must choose the ‘<default>` network mode object.
For more information, see [Network settings] in the *Docker run reference*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html [2]: docs.docker.com/engine/reference/run/#network-settings
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#pid_mode ⇒ String
The process namespace to use for the containers in the task. The valid values are host or task. If host is specified, then all containers within the tasks that specified the host PID mode on the same container instance share the same process namespace with the host Amazon EC2 instance. If task is specified, all containers within the specified task share the same process namespace. If no value is specified, the default is a private namespace. For more information, see [PID settings] in the *Docker run reference*.
If the host PID mode is used, be aware that there is a heightened risk of undesired process namespace expose. For more information, see [Docker security].
<note markdown=“1”> This parameter is not supported for Windows containers or tasks using the Fargate launch type.
</note>
[1]: docs.docker.com/engine/reference/run/#pid-settings—pid [2]: docs.docker.com/engine/security/security/
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#placement_constraints ⇒ Array<Types::TaskDefinitionPlacementConstraint>
An array of placement constraint objects to use for tasks. This field is not valid if you are using the Fargate launch type for your task.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration details for the App Mesh proxy.
Your Amazon ECS container instances require at least version 1.26.0 of the container agent and at least version 1.26.0-1 of the ecs-init package to enable a proxy configuration. If your container instances are launched from the Amazon ECS-optimized AMI version 20190301 or later, then they contain the required versions of the container agent and ecs-init. For more information, see
- Amazon ECS-optimized Linux AMI][1
-
in the *Amazon Elastic Container
Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#requires_attributes ⇒ Array<Types::Attribute>
The container instance attributes required by your task. This field is not valid if you are using the Fargate launch type for your task.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#requires_compatibilities ⇒ Array<String>
The launch type the task requires. If no value is specified, it will default to EC2. Valid values include EC2 and FARGATE.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#revision ⇒ Integer
The revision of the task in a particular family. The revision is a version number of a task definition in a family. When you register a task definition for the first time, the revision is 1. Each time that you register a new revision of a task definition in the same family, the revision value always increases by one, even if you have deregistered previous revisions in this family.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#status ⇒ String
The status of the task definition.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#task_definition_arn ⇒ String
The full Amazon Resource Name (ARN) of the task definition.
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#task_role_arn ⇒ String
The short name or full Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants containers in the task permission to call AWS APIs on your behalf. For more information, see [Amazon ECS Task Role] in the *Amazon Elastic Container Service Developer Guide*.
IAM roles for tasks on Windows require that the -EnableTaskIAMRole option is set when you launch the Amazon ECS-optimized Windows AMI. Your containers must also run some configuration code in order to take advantage of the feature. For more information, see [Windows IAM Roles for Tasks] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_IAM_role.html [2]: docs.aws.amazon.com/AmazonECS/latest/developerguide/windows_task_IAM_roles.html
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |
#volumes ⇒ Array<Types::Volume>
The list of volume definitions for the task.
If your tasks are using the Fargate launch type, the host and sourcePath parameters are not supported.
For more information about volume definition parameters and defaults, see [Amazon ECS Task Definitions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definitions.html
9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/aws-sdk-ecs/types.rb', line 9207 class TaskDefinition < Struct.new( :task_definition_arn, :container_definitions, :family, :task_role_arn, :execution_role_arn, :network_mode, :revision, :volumes, :status, :requires_attributes, :placement_constraints, :compatibilities, :requires_compatibilities, :cpu, :memory, :inference_accelerators, :pid_mode, :ipc_mode, :proxy_configuration) include Aws::Structure end |