Class: Aws::ECS::Types::TaskEphemeralStorage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskEphemeralStorage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The amount of ephemeral storage to allocate for the task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
Specify an Key Management Service key ID to encrypt the ephemeral storage for the task.
-
#size_in_gi_b ⇒ Integer
The total amount, in GiB, of the ephemeral storage to set for the task.
Instance Attribute Details
#kms_key_id ⇒ String
Specify an Key Management Service key ID to encrypt the ephemeral storage for the task.
15205 15206 15207 15208 15209 15210 |
# File 'lib/aws-sdk-ecs/types.rb', line 15205 class TaskEphemeralStorage < Struct.new( :size_in_gi_b, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#size_in_gi_b ⇒ Integer
The total amount, in GiB, of the ephemeral storage to set for the task. The minimum supported value is 20 GiB and the maximum supported value is 200 GiB.
15205 15206 15207 15208 15209 15210 |
# File 'lib/aws-sdk-ecs/types.rb', line 15205 class TaskEphemeralStorage < Struct.new( :size_in_gi_b, :kms_key_id) SENSITIVE = [] include Aws::Structure end |