Class: Aws::ECS::Types::TaskEphemeralStorage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

The amount of ephemeral storage to allocate for the task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_idString

Specify an Key Management Service key ID to encrypt the ephemeral storage for the task.

Returns:

  • (String)


17203
17204
17205
17206
17207
17208
# File 'lib/aws-sdk-ecs/types.rb', line 17203

class TaskEphemeralStorage < Struct.new(
  :size_in_gi_b,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#size_in_gi_bInteger

The total amount, in GiB, of the ephemeral storage to set for the task. The minimum supported value is 20 GiB and the maximum supported value is 200 GiB.

Returns:

  • (Integer)


17203
17204
17205
17206
17207
17208
# File 'lib/aws-sdk-ecs/types.rb', line 17203

class TaskEphemeralStorage < Struct.new(
  :size_in_gi_b,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end