Class: Aws::ECS::Types::TaskManagedEBSVolumeTerminationPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskManagedEBSVolumeTerminationPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The termination policy for the Amazon EBS volume when the task exits. For more information, see [Amazon ECS volume termination policy].
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volume-types
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Indicates whether the volume should be deleted on when the task stops.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Indicates whether the volume should be deleted on when the task stops. If a value of true is specified, Amazon ECS deletes the Amazon EBS volume on your behalf when the task goes into the STOPPED state. If no value is specified, the default value is true is used. When set to false, Amazon ECS leaves the volume in your account.
15443 15444 15445 15446 15447 |
# File 'lib/aws-sdk-ecs/types.rb', line 15443 class TaskManagedEBSVolumeTerminationPolicy < Struct.new( :delete_on_termination) SENSITIVE = [] include Aws::Structure end |