Class: Aws::ECS::Types::TaskOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The overrides that are associated with a task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_overrides ⇒ Array<Types::ContainerOverride>
One or more container overrides that are sent to a task.
-
#cpu ⇒ String
The CPU override for the task.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The ephemeral storage setting override for the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role override for the task.
-
#inference_accelerator_overrides ⇒ Array<Types::InferenceAcceleratorOverride>
The Elastic Inference accelerator override for the task.
-
#memory ⇒ String
The memory override for the task.
-
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that containers in this task can assume.
Instance Attribute Details
#container_overrides ⇒ Array<Types::ContainerOverride>
One or more container overrides that are sent to a task.
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#cpu ⇒ String
The CPU override for the task.
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The ephemeral storage setting override for the task.
<note markdown=“1”> This parameter is only supported for tasks hosted on Fargate that use the following platform versions:
* Linux platform version `1.4.0` or later.
-
Windows platform version ‘1.0.0` or later.
</note>
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role override for the task. For more information, see [Amazon ECS task execution IAM role] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task_execution_IAM_role.html
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#inference_accelerator_overrides ⇒ Array<Types::InferenceAcceleratorOverride>
The Elastic Inference accelerator override for the task.
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The memory override for the task.
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role. For more information, see [IAM Role for Tasks] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html
17544 17545 17546 17547 17548 17549 17550 17551 17552 17553 17554 |
# File 'lib/aws-sdk-ecs/types.rb', line 17544 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |