Class: Aws::ECS::Types::TaskOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass TaskOverride data as a hash:
{
container_overrides: [
{
name: "String",
command: ["String"],
environment: [
{
name: "String",
value: "String",
},
],
cpu: 1,
memory: 1,
memory_reservation: 1,
resource_requirements: [
{
value: "String", # required
type: "GPU", # required, accepts GPU, InferenceAccelerator
},
],
},
],
cpu: "String",
inference_accelerator_overrides: [
{
device_name: "String",
device_type: "String",
},
],
execution_role_arn: "String",
memory: "String",
task_role_arn: "String",
}
The overrides associated with a task.
Instance Attribute Summary collapse
-
#container_overrides ⇒ Array<Types::ContainerOverride>
One or more container overrides sent to a task.
-
#cpu ⇒ String
The cpu override for the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that the Amazon ECS container agent and the Docker daemon can assume.
-
#inference_accelerator_overrides ⇒ Array<Types::InferenceAcceleratorOverride>
The Elastic Inference accelerator override for the task.
-
#memory ⇒ String
The memory override for the task.
-
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that containers in this task can assume.
Instance Attribute Details
#container_overrides ⇒ Array<Types::ContainerOverride>
One or more container overrides sent to a task.
9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-ecs/types.rb', line 9342 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn) include Aws::Structure end |
#cpu ⇒ String
The cpu override for the task.
9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-ecs/types.rb', line 9342 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn) include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role that the Amazon ECS container agent and the Docker daemon can assume.
9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-ecs/types.rb', line 9342 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn) include Aws::Structure end |
#inference_accelerator_overrides ⇒ Array<Types::InferenceAcceleratorOverride>
The Elastic Inference accelerator override for the task.
9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-ecs/types.rb', line 9342 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn) include Aws::Structure end |
#memory ⇒ String
The memory override for the task.
9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-ecs/types.rb', line 9342 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn) include Aws::Structure end |
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role.
9342 9343 9344 9345 9346 9347 9348 9349 9350 |
# File 'lib/aws-sdk-ecs/types.rb', line 9342 class TaskOverride < Struct.new( :container_overrides, :cpu, :inference_accelerator_overrides, :execution_role_arn, :memory, :task_role_arn) include Aws::Structure end |