Class: Aws::ECS::Types::TaskSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Information about a set of Amazon ECS tasks in either an AWS CodeDeploy or an EXTERNAL deployment. An Amazon ECS task set includes details such as the desired number of tasks, how many tasks are running, and whether the task set serves production traffic.
Instance Attribute Summary collapse
-
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy associated with the task set.
-
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that the service that hosts the task set exists in.
-
#computed_desired_count ⇒ Integer
The computed desired count for the task set.
-
#created_at ⇒ Time
The Unix timestamp for when the task set was created.
-
#external_id ⇒ String
The external ID associated with the task set.
-
#id ⇒ String
The ID of the task set.
-
#launch_type ⇒ String
The launch type the tasks in the task set are using.
-
#load_balancers ⇒ Array<Types::LoadBalancer>
Details on a load balancer that is used with a task set.
-
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for the task set.
-
#pending_count ⇒ Integer
The number of tasks in the task set that are in the
PENDINGstatus during a deployment. -
#platform_version ⇒ String
The platform version on which the tasks in the task set are running.
-
#running_count ⇒ Integer
The number of tasks in the task set that are in the
RUNNINGstatus during a deployment. -
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the service the task set exists in.
-
#service_registries ⇒ Array<Types::ServiceRegistry>
The details of the service discovery registries to assign to this task set.
-
#stability_status ⇒ String
The stability status, which indicates whether the task set has reached a steady state.
-
#stability_status_at ⇒ Time
The Unix timestamp for when the task set stability status was retrieved.
-
#started_by ⇒ String
The tag specified when a task set is started.
-
#status ⇒ String
The status of the task set.
-
#task_definition ⇒ String
The task definition the task set is using.
-
#task_set_arn ⇒ String
The Amazon Resource Name (ARN) of the task set.
-
#updated_at ⇒ Time
The Unix timestamp for when the task set was last updated.
Instance Attribute Details
#capacity_provider_strategy ⇒ Array<Types::CapacityProviderStrategyItem>
The capacity provider strategy associated with the task set.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#cluster_arn ⇒ String
The Amazon Resource Name (ARN) of the cluster that the service that hosts the task set exists in.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#computed_desired_count ⇒ Integer
The computed desired count for the task set. This is calculated by multiplying the service’s desiredCount by the task set’s scale percentage. The result is always rounded up. For example, if the computed desired count is 1.2, it rounds up to 2 tasks.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#created_at ⇒ Time
The Unix timestamp for when the task set was created.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#external_id ⇒ String
The external ID associated with the task set.
If a task set is created by an AWS CodeDeploy deployment, the externalId parameter contains the AWS CodeDeploy deployment ID.
If a task set is created for an external deployment and is associated with a service discovery registry, the externalId parameter contains the ECS_TASK_SET_EXTERNAL_ID AWS Cloud Map attribute.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#id ⇒ String
The ID of the task set.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#launch_type ⇒ String
The launch type the tasks in the task set are using. For more information, see [Amazon ECS Launch Types] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/launch_types.html
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#load_balancers ⇒ Array<Types::LoadBalancer>
Details on a load balancer that is used with a task set.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfiguration
The network configuration for the task set.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#pending_count ⇒ Integer
The number of tasks in the task set that are in the PENDING status during a deployment. A task in the PENDING state is preparing to enter the RUNNING state. A task set enters the PENDING status when it launches for the first time or when it is restarted after being in the STOPPED state.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#platform_version ⇒ String
The platform version on which the tasks in the task set are running. A platform version is only specified for tasks using the Fargate launch type. If one is not specified, the LATEST platform version is used by default. For more information, see [AWS Fargate Platform Versions] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#running_count ⇒ Integer
The number of tasks in the task set that are in the RUNNING status during a deployment. A task in the RUNNING state is running and ready for use.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the service the task set exists in.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#service_registries ⇒ Array<Types::ServiceRegistry>
The details of the service discovery registries to assign to this task set. For more information, see [Service Discovery].
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#stability_status ⇒ String
The stability status, which indicates whether the task set has reached a steady state. If the following conditions are met, the task set will be in STEADY_STATE:
-
The task
runningCountis equal to thecomputedDesiredCount. -
The
pendingCountis0. -
There are no tasks running on container instances in the
DRAININGstatus. -
All tasks are reporting a healthy status from the load balancers, service discovery, and container health checks.
If any of those conditions are not met, the stability status returns STABILIZING.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#stability_status_at ⇒ Time
The Unix timestamp for when the task set stability status was retrieved.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#started_by ⇒ String
The tag specified when a task set is started. If the task set is created by an AWS CodeDeploy deployment, the startedBy parameter is CODE_DEPLOY. For a task set created for an external deployment, the startedBy field isn’t used.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#status ⇒ String
The status of the task set. The following describes each state:
PRIMARY
: The task set is serving production traffic.
ACTIVE
: The task set is not serving production traffic.
DRAINING
: The tasks in the task set are being stopped and their
corresponding targets are being deregistered from their target
group.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#task_definition ⇒ String
The task definition the task set is using.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#task_set_arn ⇒ String
The Amazon Resource Name (ARN) of the task set.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |
#updated_at ⇒ Time
The Unix timestamp for when the task set was last updated.
9520 9521 9522 9523 9524 9525 9526 9527 9528 9529 9530 9531 9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 |
# File 'lib/aws-sdk-ecs/types.rb', line 9520 class TaskSet < Struct.new( :id, :task_set_arn, :service_arn, :cluster_arn, :started_by, :external_id, :status, :task_definition, :computed_desired_count, :pending_count, :running_count, :created_at, :updated_at, :launch_type, :capacity_provider_strategy, :platform_version, :network_configuration, :load_balancers, :service_registries, :scale, :stability_status, :stability_status_at) include Aws::Structure end |