Class: Aws::ECS::Types::TaskSetNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::TaskSetNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
The specified task set wasn’t found. You can view your available task sets with [DescribeTaskSets]. Task sets are specific to each cluster, service and Region.
[1]: docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTaskSets.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Message that describes the cause of the exception.
Instance Attribute Details
#message ⇒ String
Message that describes the cause of the exception.
17810 17811 17812 17813 17814 |
# File 'lib/aws-sdk-ecs/types.rb', line 17810 class TaskSetNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |