Class: Aws::ECS::Types::ThresholdConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::ThresholdConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Defines the failure threshold that the deployment circuit breaker uses
to monitor a deployment. The type and value together determine the
number of task failures that are tolerated before the circuit breaker
triggers.
By default, the threshold configuration uses a type of
BOUNDED_PERCENT with a value of 50.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
Determines how
valueis used to calculate the failure threshold. -
#value ⇒ Integer
The integer used to calculate the failure threshold.
Instance Attribute Details
#type ⇒ String
Determines how value is used to calculate the failure threshold.
For the percentage types (BOUNDED_PERCENT and
UNBOUNDED_PERCENT), value is multiplied by the latest service
desired count; for COUNT, value is used directly. The default is
BOUNDED_PERCENT.
18222 18223 18224 18225 18226 18227 |
# File 'lib/aws-sdk-ecs/types.rb', line 18222 class ThresholdConfiguration < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Integer
The integer used to calculate the failure threshold. When type is
COUNT, this is the failure threshold itself. When type is a
percentage type, this is the percentage that Amazon ECS multiplies
by the latest service desired count to calculate the failure
threshold.
18222 18223 18224 18225 18226 18227 |
# File 'lib/aws-sdk-ecs/types.rb', line 18222 class ThresholdConfiguration < Struct.new( :type, :value) SENSITIVE = [] include Aws::Structure end |