Class: Aws::ECS::Types::UpdateCapacityProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateCapacityProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_provider ⇒ Types::AutoScalingGroupProviderUpdate
An object that represent the parameters to update for the Auto Scaling group capacity provider.
-
#cluster ⇒ String
The name of the cluster that contains the capacity provider to update.
-
#managed_instances_provider ⇒ Types::UpdateManagedInstancesProviderConfiguration
The updated configuration for the Amazon ECS Managed Instances provider.
-
#name ⇒ String
The name of the capacity provider to update.
Instance Attribute Details
#auto_scaling_group_provider ⇒ Types::AutoScalingGroupProviderUpdate
An object that represent the parameters to update for the Auto Scaling group capacity provider.
16036 16037 16038 16039 16040 16041 16042 16043 |
# File 'lib/aws-sdk-ecs/types.rb', line 16036 class UpdateCapacityProviderRequest < Struct.new( :name, :cluster, :auto_scaling_group_provider, :managed_instances_provider) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ String
The name of the cluster that contains the capacity provider to update. Managed instances capacity providers are cluster-scoped and can only be updated within their associated cluster.
16036 16037 16038 16039 16040 16041 16042 16043 |
# File 'lib/aws-sdk-ecs/types.rb', line 16036 class UpdateCapacityProviderRequest < Struct.new( :name, :cluster, :auto_scaling_group_provider, :managed_instances_provider) SENSITIVE = [] include Aws::Structure end |
#managed_instances_provider ⇒ Types::UpdateManagedInstancesProviderConfiguration
The updated configuration for the Amazon ECS Managed Instances provider. You can modify the infrastructure role, instance launch template, and tag propagation settings. Changes take effect for new instances launched after the update.
16036 16037 16038 16039 16040 16041 16042 16043 |
# File 'lib/aws-sdk-ecs/types.rb', line 16036 class UpdateCapacityProviderRequest < Struct.new( :name, :cluster, :auto_scaling_group_provider, :managed_instances_provider) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the capacity provider to update.
16036 16037 16038 16039 16040 16041 16042 16043 |
# File 'lib/aws-sdk-ecs/types.rb', line 16036 class UpdateCapacityProviderRequest < Struct.new( :name, :cluster, :auto_scaling_group_provider, :managed_instances_provider) SENSITIVE = [] include Aws::Structure end |