Class: Aws::ECS::Types::UpdateClusterSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateClusterSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass UpdateClusterSettingsRequest data as a hash:
{
cluster: "String", # required
settings: [ # required
{
name: "containerInsights", # accepts containerInsights
value: "String",
},
],
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The name of the cluster to modify the settings for.
-
#settings ⇒ Array<Types::ClusterSetting>
The setting to use by default for a cluster.
Instance Attribute Details
#cluster ⇒ String
The name of the cluster to modify the settings for.
9675 9676 9677 9678 9679 |
# File 'lib/aws-sdk-ecs/types.rb', line 9675 class UpdateClusterSettingsRequest < Struct.new( :cluster, :settings) include Aws::Structure end |
#settings ⇒ Array<Types::ClusterSetting>
The setting to use by default for a cluster. This parameter is used to enable CloudWatch Container Insights for a cluster. If this value is specified, it will override the containerInsights value set with PutAccountSetting or PutAccountSettingDefault.
9675 9676 9677 9678 9679 |
# File 'lib/aws-sdk-ecs/types.rb', line 9675 class UpdateClusterSettingsRequest < Struct.new( :cluster, :settings) include Aws::Structure end |