Class: Aws::ECS::Types::UpdateDaemonRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateDaemonRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the capacity providers to associate with the daemon.
-
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon to update.
-
#daemon_task_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon task definition to use for the updated daemon.
-
#deployment_configuration ⇒ Types::DaemonDeploymentConfiguration
Optional deployment parameters that control how the daemon rolls out updates, including the drain percentage, alarm-based rollback, and bake time.
-
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to turn on Amazon ECS managed tags for the tasks in the daemon.
-
#enable_execute_command ⇒ Boolean
If ‘true`, the execute command functionality is turned on for all tasks in the daemon.
-
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the daemon to the daemon tasks.
Instance Attribute Details
#capacity_provider_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the capacity providers to associate with the daemon.
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon to update.
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#daemon_task_definition_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon task definition to use for the updated daemon.
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#deployment_configuration ⇒ Types::DaemonDeploymentConfiguration
Optional deployment parameters that control how the daemon rolls out updates, including the drain percentage, alarm-based rollback, and bake time.
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#enable_ecs_managed_tags ⇒ Boolean
Specifies whether to turn on Amazon ECS managed tags for the tasks in the daemon. For more information, see [Tagging your Amazon ECS resources] in the *Amazon Elastic Container Service Developer Guide*.
[1]: docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#enable_execute_command ⇒ Boolean
If ‘true`, the execute command functionality is turned on for all tasks in the daemon. If `false`, the execute command functionality is turned off.
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |
#propagate_tags ⇒ String
Specifies whether to propagate the tags from the daemon to the daemon tasks. If you don’t specify a value, the tags aren’t propagated. You can only propagate tags to daemon tasks during task creation.
18297 18298 18299 18300 18301 18302 18303 18304 18305 18306 18307 |
# File 'lib/aws-sdk-ecs/types.rb', line 18297 class UpdateDaemonRequest < Struct.new( :daemon_arn, :daemon_task_definition_arn, :capacity_provider_arns, :deployment_configuration, :propagate_tags, :enable_ecs_managed_tags, :enable_execute_command) SENSITIVE = [] include Aws::Structure end |