Class: Aws::ECS::Types::UpdateDaemonResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateDaemonResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The Unix timestamp for the time when the daemon was created.
-
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
-
#deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment that was triggered by the update.
-
#status ⇒ String
The status of the daemon.
-
#updated_at ⇒ Time
The Unix timestamp for the time when the daemon was last updated.
Instance Attribute Details
#created_at ⇒ Time
The Unix timestamp for the time when the daemon was created.
18332 18333 18334 18335 18336 18337 18338 18339 18340 |
# File 'lib/aws-sdk-ecs/types.rb', line 18332 class UpdateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#daemon_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon.
18332 18333 18334 18335 18336 18337 18338 18339 18340 |
# File 'lib/aws-sdk-ecs/types.rb', line 18332 class UpdateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#deployment_arn ⇒ String
The Amazon Resource Name (ARN) of the daemon deployment that was triggered by the update.
18332 18333 18334 18335 18336 18337 18338 18339 18340 |
# File 'lib/aws-sdk-ecs/types.rb', line 18332 class UpdateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the daemon.
18332 18333 18334 18335 18336 18337 18338 18339 18340 |
# File 'lib/aws-sdk-ecs/types.rb', line 18332 class UpdateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The Unix timestamp for the time when the daemon was last updated.
18332 18333 18334 18335 18336 18337 18338 18339 18340 |
# File 'lib/aws-sdk-ecs/types.rb', line 18332 class UpdateDaemonResponse < Struct.new( :daemon_arn, :status, :created_at, :updated_at, :deployment_arn) SENSITIVE = [] include Aws::Structure end |