Class: Aws::ECS::Types::UpdateExpressGatewayServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpuString

The number of CPU units used by the task.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the task execution role for the Express service.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathString

The path on the container for Application Load Balancer health checks.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#memoryString

The amount of memory (in MiB) used by the task.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::ExpressGatewayServiceNetworkConfiguration

The network configuration for the Express service tasks. By default, the network configuration for an Express service uses the default VPC.



18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ExpressGatewayContainer

The primary container configuration for the Express service.



18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_targetTypes::ExpressGatewayScalingTarget

The auto-scaling configuration for the Express service.



18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The Amazon Resource Name (ARN) of the Express service to update.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#task_definition_arnString

The Amazon Resource Name (ARN) of a task definition to use to update the Express Gateway service. This allows you to manage your own task definition, giving you more control over the service configuration such as adding sidecar containers.

The task definition must have a container named ‘Main` with a single TCP port mapping that includes a container port and port name. The task definition must also have `FARGATE` compatibility.

If you provide a task definition ARN, you cannot also specify ‘primaryContainer`, `taskRoleArn`, `cpu`, or `memory`.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The Amazon Resource Name (ARN) of the IAM role for containers in this task.

Returns:

  • (String)


18735
18736
18737
18738
18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
# File 'lib/aws-sdk-ecs/types.rb', line 18735

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target,
  :task_definition_arn)
  SENSITIVE = []
  include Aws::Structure
end