Class: Aws::ECS::Types::UpdateExpressGatewayServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateExpressGatewayServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpu ⇒ String
The number of CPU units used by the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role for the Express service.
-
#health_check_path ⇒ String
The path on the container for Application Load Balancer health checks.
-
#memory ⇒ String
The amount of memory (in MiB) used by the task.
-
#network_configuration ⇒ Types::ExpressGatewayServiceNetworkConfiguration
The network configuration for the Express service tasks.
-
#primary_container ⇒ Types::ExpressGatewayContainer
The primary container configuration for the Express service.
-
#scaling_target ⇒ Types::ExpressGatewayScalingTarget
The auto-scaling configuration for the Express service.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to update.
-
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for containers in this task.
Instance Attribute Details
#cpu ⇒ String
The number of CPU units used by the task.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role for the Express service.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#health_check_path ⇒ String
The path on the container for Application Load Balancer health checks.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The amount of memory (in MiB) used by the task.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::ExpressGatewayServiceNetworkConfiguration
The network configuration for the Express service tasks. By default, the network configuration for an Express service uses the default VPC.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ExpressGatewayContainer
The primary container configuration for the Express service.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#scaling_target ⇒ Types::ExpressGatewayScalingTarget
The auto-scaling configuration for the Express service.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to update.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for containers in this task.
18607 18608 18609 18610 18611 18612 18613 18614 18615 18616 18617 18618 18619 |
# File 'lib/aws-sdk-ecs/types.rb', line 18607 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |