Class: Aws::ECS::Types::UpdateExpressGatewayServiceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateExpressGatewayServiceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cpu ⇒ String
The number of CPU units used by the task.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role for the Express service.
-
#health_check_path ⇒ String
The path on the container for Application Load Balancer health checks.
-
#memory ⇒ String
The amount of memory (in MiB) used by the task.
-
#network_configuration ⇒ Types::ExpressGatewayServiceNetworkConfiguration
The network configuration for the Express service tasks.
-
#primary_container ⇒ Types::ExpressGatewayContainer
The primary container configuration for the Express service.
-
#scaling_target ⇒ Types::ExpressGatewayScalingTarget
The auto-scaling configuration for the Express service.
-
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to update.
-
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for containers in this task.
Instance Attribute Details
#cpu ⇒ String
The number of CPU units used by the task.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the task execution role for the Express service.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#health_check_path ⇒ String
The path on the container for Application Load Balancer health checks.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#memory ⇒ String
The amount of memory (in MiB) used by the task.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#network_configuration ⇒ Types::ExpressGatewayServiceNetworkConfiguration
The network configuration for the Express service tasks. By default, the network configuration for an Express service uses the default VPC.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#primary_container ⇒ Types::ExpressGatewayContainer
The primary container configuration for the Express service.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#scaling_target ⇒ Types::ExpressGatewayScalingTarget
The auto-scaling configuration for the Express service.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#service_arn ⇒ String
The Amazon Resource Name (ARN) of the Express service to update.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |
#task_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role for containers in this task.
18572 18573 18574 18575 18576 18577 18578 18579 18580 18581 18582 18583 18584 |
# File 'lib/aws-sdk-ecs/types.rb', line 18572 class UpdateExpressGatewayServiceRequest < Struct.new( :service_arn, :execution_role_arn, :health_check_path, :primary_container, :task_role_arn, :network_configuration, :cpu, :memory, :scaling_target) SENSITIVE = [] include Aws::Structure end |