Class: Aws::ECS::Types::UpdateExpressGatewayServiceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cpuString

The number of CPU units used by the task.

Returns:

  • (String)


16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the task execution role for the Express service.

Returns:

  • (String)


16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#health_check_pathString

The path on the container for Application Load Balancer health checks.

Returns:

  • (String)


16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#memoryString

The amount of memory (in MiB) used by the task.

Returns:

  • (String)


16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#network_configurationTypes::ExpressGatewayServiceNetworkConfiguration

The network configuration for the Express service tasks. By default, the network configuration for an Express service uses the default VPC.



16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#primary_containerTypes::ExpressGatewayContainer

The primary container configuration for the Express service.



16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_targetTypes::ExpressGatewayScalingTarget

The auto-scaling configuration for the Express service.



16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#service_arnString

The Amazon Resource Name (ARN) of the Express service to update.

Returns:

  • (String)


16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end

#task_role_arnString

The Amazon Resource Name (ARN) of the IAM role for containers in this task.

Returns:

  • (String)


16239
16240
16241
16242
16243
16244
16245
16246
16247
16248
16249
16250
16251
# File 'lib/aws-sdk-ecs/types.rb', line 16239

class UpdateExpressGatewayServiceRequest < Struct.new(
  :service_arn,
  :execution_role_arn,
  :health_check_path,
  :primary_container,
  :task_role_arn,
  :network_configuration,
  :cpu,
  :memory,
  :scaling_target)
  SENSITIVE = []
  include Aws::Structure
end