Class: Aws::ECS::Types::UpdateServicePrimaryTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateServicePrimaryTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
-
#primary_task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to set as the primary task set in the deployment.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
18796 18797 18798 18799 18800 18801 18802 |
# File 'lib/aws-sdk-ecs/types.rb', line 18796 class UpdateServicePrimaryTaskSetRequest < Struct.new( :cluster, :service, :primary_task_set) SENSITIVE = [] include Aws::Structure end |
#primary_task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to set as the primary task set in the deployment.
18796 18797 18798 18799 18800 18801 18802 |
# File 'lib/aws-sdk-ecs/types.rb', line 18796 class UpdateServicePrimaryTaskSetRequest < Struct.new( :cluster, :service, :primary_task_set) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
18796 18797 18798 18799 18800 18801 18802 |
# File 'lib/aws-sdk-ecs/types.rb', line 18796 class UpdateServicePrimaryTaskSetRequest < Struct.new( :cluster, :service, :primary_task_set) SENSITIVE = [] include Aws::Structure end |