Class: Aws::ECS::Types::UpdateServicePrimaryTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateServicePrimaryTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Note:
When making an API call, you may pass UpdateServicePrimaryTaskSetRequest data as a hash:
{
cluster: "String", # required
service: "String", # required
primary_task_set: "String", # required
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
-
#primary_task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to set as the primary task set in the deployment.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
9815 9816 9817 9818 9819 9820 |
# File 'lib/aws-sdk-ecs/types.rb', line 9815 class UpdateServicePrimaryTaskSetRequest < Struct.new( :cluster, :service, :primary_task_set) include Aws::Structure end |
#primary_task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to set as the primary task set in the deployment.
9815 9816 9817 9818 9819 9820 |
# File 'lib/aws-sdk-ecs/types.rb', line 9815 class UpdateServicePrimaryTaskSetRequest < Struct.new( :cluster, :service, :primary_task_set) include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
9815 9816 9817 9818 9819 9820 |
# File 'lib/aws-sdk-ecs/types.rb', line 9815 class UpdateServicePrimaryTaskSetRequest < Struct.new( :cluster, :service, :primary_task_set) include Aws::Structure end |