Class: Aws::ECS::Types::UpdateTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set is found in.
-
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set is found in.
-
#task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to update.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set is found in.
19237 19238 19239 19240 19241 19242 19243 19244 |
# File 'lib/aws-sdk-ecs/types.rb', line 19237 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) SENSITIVE = [] include Aws::Structure end |
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
19237 19238 19239 19240 19241 19242 19243 19244 |
# File 'lib/aws-sdk-ecs/types.rb', line 19237 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set is found in.
19237 19238 19239 19240 19241 19242 19243 19244 |
# File 'lib/aws-sdk-ecs/types.rb', line 19237 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) SENSITIVE = [] include Aws::Structure end |
#task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to update.
19237 19238 19239 19240 19241 19242 19243 19244 |
# File 'lib/aws-sdk-ecs/types.rb', line 19237 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) SENSITIVE = [] include Aws::Structure end |