Class: Aws::ECS::Types::UpdateTaskSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clusterString

The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set is found in.



16846
16847
16848
16849
16850
16851
16852
16853
# File 'lib/aws-sdk-ecs/types.rb', line 16846

class UpdateTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :scale)
  SENSITIVE = []
  include Aws::Structure
end

#scaleTypes::Scale

A floating-point percentage of the desired number of tasks to place and keep running in the task set.



16846
16847
16848
16849
16850
16851
16852
16853
# File 'lib/aws-sdk-ecs/types.rb', line 16846

class UpdateTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :scale)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The short name or full Amazon Resource Name (ARN) of the service that the task set is found in.



16846
16847
16848
16849
16850
16851
16852
16853
# File 'lib/aws-sdk-ecs/types.rb', line 16846

class UpdateTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :scale)
  SENSITIVE = []
  include Aws::Structure
end

#task_setString

The short name or full Amazon Resource Name (ARN) of the task set to update.



16846
16847
16848
16849
16850
16851
16852
16853
# File 'lib/aws-sdk-ecs/types.rb', line 16846

class UpdateTaskSetRequest < Struct.new(
  :cluster,
  :service,
  :task_set,
  :scale)
  SENSITIVE = []
  include Aws::Structure
end