Class: Aws::ECS::Types::UpdateTaskSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECS::Types::UpdateTaskSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecs/types.rb
Overview
When making an API call, you may pass UpdateTaskSetRequest data as a hash:
{
cluster: "String", # required
service: "String", # required
task_set: "String", # required
scale: { # required
value: 1.0,
unit: "PERCENT", # accepts PERCENT
},
}
Instance Attribute Summary collapse
-
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
-
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
-
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
-
#task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to update.
Instance Attribute Details
#cluster ⇒ String
The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
10010 10011 10012 10013 10014 10015 10016 |
# File 'lib/aws-sdk-ecs/types.rb', line 10010 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) include Aws::Structure end |
#scale ⇒ Types::Scale
A floating-point percentage of the desired number of tasks to place and keep running in the task set.
10010 10011 10012 10013 10014 10015 10016 |
# File 'lib/aws-sdk-ecs/types.rb', line 10010 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) include Aws::Structure end |
#service ⇒ String
The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
10010 10011 10012 10013 10014 10015 10016 |
# File 'lib/aws-sdk-ecs/types.rb', line 10010 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) include Aws::Structure end |
#task_set ⇒ String
The short name or full Amazon Resource Name (ARN) of the task set to update.
10010 10011 10012 10013 10014 10015 10016 |
# File 'lib/aws-sdk-ecs/types.rb', line 10010 class UpdateTaskSetRequest < Struct.new( :cluster, :service, :task_set, :scale) include Aws::Structure end |