Class: Aws::ECS::Waiters::DaemonTaskDefinitionActive
- Inherits:
-
Object
- Object
- Aws::ECS::Waiters::DaemonTaskDefinitionActive
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-ecs/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DaemonTaskDefinitionActive
constructor
A new instance of DaemonTaskDefinitionActive.
-
#wait(params = {}) ⇒ Types::DescribeDaemonTaskDefinitionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DaemonTaskDefinitionActive
Returns a new instance of DaemonTaskDefinitionActive.
242 243 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 242
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
280 281 282 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 280 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeDaemonTaskDefinitionResponse
Returns a response object which responds to the following methods:
- #daemon_task_definition => Types::DaemonTaskDefinition
275 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 275
def wait: (
|