Class: Aws::ECS::Waiters::DaemonTaskDefinitionActive
- Inherits:
-
Object
- Object
- Aws::ECS::Waiters::DaemonTaskDefinitionActive
- Defined in:
- lib/aws-sdk-ecs/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DaemonTaskDefinitionActive
constructor
A new instance of DaemonTaskDefinitionActive.
-
#wait(params = {}) ⇒ Types::DescribeDaemonTaskDefinitionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DaemonTaskDefinitionActive
Returns a new instance of DaemonTaskDefinitionActive.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 242 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 8, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :describe_daemon_task_definition, acceptors: [ { "matcher" => "path", "argument" => "daemon_task_definition.status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "daemon_task_definition.status", "state" => "failure", "expected" => "DELETE_IN_PROGRESS" }, { "matcher" => "path", "argument" => "daemon_task_definition.status", "state" => "failure", "expected" => "DELETED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
280 281 282 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 280 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeDaemonTaskDefinitionResponse
Returns a response object which responds to the following methods:
-
#daemon_task_definition => Types::DaemonTaskDefinition
275 276 277 |
# File 'lib/aws-sdk-ecs/waiters.rb', line 275 def wait(params = {}) @waiter.wait(client: @client, params: params) end |