Class: Aws::ECS::Waiters::TasksRunning

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-ecs/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ TasksRunning

Returns a new instance of TasksRunning.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 100
  • :delay (Integer) — default: 6
  • :before_attempt (Proc)
  • :before_wait (Proc)


428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/aws-sdk-ecs/waiters.rb', line 428

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 100,
    delay: 6,
    poller: Aws::Waiters::Poller.new(
      operation_name: :describe_tasks,
      acceptors: [
        {
          "matcher" => "pathAny",
          "argument" => "tasks[].last_status",
          "state" => "failure",
          "expected" => "STOPPED"
        },
        {
          "matcher" => "pathAny",
          "argument" => "failures[].reason",
          "state" => "failure",
          "expected" => "MISSING"
        },
        {
          "matcher" => "pathAll",
          "argument" => "tasks[].last_status",
          "state" => "success",
          "expected" => "RUNNING"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



466
467
468
# File 'lib/aws-sdk-ecs/waiters.rb', line 466

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeTasksResponse

Returns a response object which responds to the following methods:

  • #tasks => Array<Types::Task>

  • #failures => Array<Types::Failure>

Options Hash (params):

  • :cluster (String)

    The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task or tasks to describe. If you do not specify a cluster, the default cluster is assumed.

  • :tasks (required, Array<String>)

    A list of up to 100 task IDs or full ARN entries.

  • :include (Array<String>)

    Specifies whether you want to see the resource tags for the task. If ‘TAGS` is specified, the tags are included in the response. If this field is omitted, tags aren’t included in the response.

Returns:



461
462
463
# File 'lib/aws-sdk-ecs/waiters.rb', line 461

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end